@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _COMMAND_LINE_H_
-#define _COMMAND_LINE_H_
+#ifndef COMMAND_LINE_H
+#define COMMAND_LINE_H
 
 #include <string>
 
@@ -25,7 +25,8 @@ std::vector<std::pair<std::string, std::string> >
 GetShortcutsUsage(const std::string &ctrl = "");
 std::vector<std::pair<std::string, std::string> > GetMouseUsage();
 void PrintUsage(const std::string &name);
-void PrintInfo();
+std::vector<std::string> GetBuildInfo();
+void PrintBuildInfo();
 void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError);
 
 #endif
