@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 // This file contains a bunch of functions that depend on OS-dependent
 // features and/or system calls
@@ -54,6 +54,7 @@
 #include <iostream>
 #include <fstream>
 #include <sys/timeb.h>
+#include <wchar.h>
 #endif
 
 #include "GmshMessage.h"
@@ -259,7 +260,10 @@ static void setwbuf(int i, const char *f)
   // all strings in Gmsh are supposed to be UTF8-encoded, which is natively
   // supported by Mac and Linux. Windows does not support UTF-8, but UTF-16
   // (through wchar_t), so we need to convert.
-  if(i < 0 || i > 2) return;
+  if(i < 0 || i > 2) {
+    Msg::Error("Wrong buffer index in setwbuf");
+    return;
+  }
   size_t l = strlen(f);
   unsigned int wn = utf8toUtf16(f, (unsigned int)l, NULL, 0) + 1;
   wbuf[i] = (wchar_t *)realloc(wbuf[i], sizeof(wchar_t) * wn);
@@ -280,45 +284,34 @@ FILE *Fopen(const char *f, const char *mode)
 #endif
 }
 
-const char *GetEnvironmentVar(const char *var)
+std::string GetEnvironmentVar(const std::string &var)
 {
 #if defined(WIN32) && !defined(__CYGWIN__)
-  // Should probably use the Unicode version
-  const char *tmp = getenv(var);
+  setwbuf(0, var.c_str());
+  const wchar_t *wtmp = _wgetenv(wbuf[0]);
+  if(!wtmp) return "";
+  char tmp[MAX_PATH];
+  utf8FromUtf16(tmp, MAX_PATH, wtmp, wcslen(wtmp));
   // Don't accept top dir or anything partially expanded like
-  // c:\Documents and Settings\%USERPROFILE%, etc.
-  if(!tmp || !strcmp(tmp, "/") || strstr(tmp, "%") || strstr(tmp, "$"))
-    return 0;
+  // Settings\%USERPROFILE%, etc.
+  if(!strcmp(tmp, "/") || strstr(tmp, "%") || strstr(tmp, "$"))
+    return "";
   else
-    return tmp;
+    return std::string(tmp);
 #else
-  return getenv(var);
+  const char *tmp = getenv(var.c_str());
+  if(!tmp) return "";
+  return std::string(tmp);
 #endif
 }
 
-void SetEnvironmentVar(const char *var, const char *val)
+void SetEnvironmentVar(const std::string &var, const std::string &val)
 {
 #if defined(WIN32) && !defined(__CYGWIN__)
-  // should probably use Unicode version here
-  _putenv((std::string(var) + "=" + std::string(val)).c_str());
+  setwbuf(0, (var + "=" + val).c_str());
+  _wputenv(wbuf[0]);
 #else
-  setenv(var, val, 1);
-#endif
-}
-
-double GetTimeInSeconds()
-{
-#if defined(WIN32) && !defined(__CYGWIN__)
-  FILETIME ft;
-  GetSystemTimeAsFileTime(&ft);
-  double t = 1.e-7 * 4294967296. * (double)ft.dwHighDateTime +
-             1.e-7 * (double)ft.dwLowDateTime;
-  return t;
-#else
-  struct timeval tp;
-  gettimeofday(&tp, (struct timezone *)0);
-  double t = (double)tp.tv_sec + 1.e-6 * (double)tp.tv_usec;
-  return t;
+  setenv(var.c_str(), val.c_str(), 1);
 #endif
 }
 
@@ -653,28 +646,6 @@ int SystemCall(const std::string &command, bool blocking)
   return SystemCallExe("", command, blocking);
 }
 
-std::string GetCurrentWorkdir()
-{
-  char path[1024];
-
-#if defined(WIN32) && !defined(__CYGWIN__)
-  // should use Unicode version
-  if(!_getcwd(path, sizeof(path))) return "";
-#else
-  if(!getcwd(path, sizeof(path))) return "";
-#endif
-
-  std::string str(path);
-  // match the convention of SplitFileName that delivers directory path
-  // ending with a directory separator
-#if defined(WIN32)
-  str.append("\\");
-#else
-  str.append("/");
-#endif
-  return str;
-}
-
 void RedirectIOToConsole()
 {
 #if defined(WIN32) && !defined(__CYGWIN__)
