@@ -1,18 +1,17 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _OS_H_
-#define _OS_H_
+#ifndef OS_H
+#define OS_H
 
 #include <string>
 #include <stdio.h>
 
 FILE *Fopen(const char *f, const char *mode);
-const char *GetEnvironmentVar(const char *var);
-void SetEnvironmentVar(const char *var, const char *val);
-double GetTimeInSeconds();
+std::string GetEnvironmentVar(const std::string &var);
+void SetEnvironmentVar(const std::string &var, const std::string &val);
 void SleepInSeconds(double s);
 void CheckResources();
 double Cpu();
@@ -31,7 +30,6 @@ void CreatePath(const std::string &fullPath);
 int SystemCall(const std::string &command, bool blocking = false);
 int SystemCallExe(const std::string &exe, const std::string &argsOrCommand,
                   bool blocking = false);
-std::string GetCurrentWorkdir();
 void RedirectIOToConsole();
 void UnzipFile(const std::string &fileName, const std::string &prependDir = "");
 
