@@ -37,6 +37,7 @@ std::string opt_general_background_image_filename(OPT_ARGS_STR);
 std::string opt_general_display(OPT_ARGS_STR);
 std::string opt_general_version(OPT_ARGS_STR);
 std::string opt_general_build_options(OPT_ARGS_STR);
+std::string opt_general_build_info(OPT_ARGS_STR);
 std::string opt_general_filename(OPT_ARGS_STR);
 std::string opt_general_executable_filename(OPT_ARGS_STR);
 std::string opt_general_default_filename(OPT_ARGS_STR);
@@ -161,8 +162,8 @@ double opt_general_polygon_offset_always(OPT_ARGS_NUM);
 double opt_general_polygon_offset_factor(OPT_ARGS_NUM);
 double opt_general_polygon_offset_units(OPT_ARGS_NUM);
 double opt_general_system_menu_bar(OPT_ARGS_NUM);
+double opt_general_native_file_chooser(OPT_ARGS_NUM);
 double opt_general_show_module_menu(OPT_ARGS_NUM);
-double opt_general_meshdiscrete(OPT_ARGS_NUM);
 double opt_general_message_size(OPT_ARGS_NUM);
 double opt_general_message_fontsize(OPT_ARGS_NUM);
 double opt_general_detached_menu(OPT_ARGS_NUM);
@@ -234,6 +235,7 @@ double opt_general_nopopup(OPT_ARGS_NUM);
 double opt_general_non_modal_windows(OPT_ARGS_NUM);
 double opt_general_terminal(OPT_ARGS_NUM);
 double opt_general_tooltips(OPT_ARGS_NUM);
+double opt_general_input_scrolling(OPT_ARGS_NUM);
 double opt_general_confirm_overwrite(OPT_ARGS_NUM);
 double opt_general_orthographic(OPT_ARGS_NUM);
 double opt_general_mouse_selection(OPT_ARGS_NUM);
@@ -397,6 +399,8 @@ double opt_geometry_occ_fix_degenerated(OPT_ARGS_NUM);
 double opt_geometry_occ_fix_small_edges(OPT_ARGS_NUM);
 double opt_geometry_occ_fix_small_faces(OPT_ARGS_NUM);
 double opt_geometry_occ_sew_faces(OPT_ARGS_NUM);
+double opt_geometry_occ_make_solids(OPT_ARGS_NUM);
+double opt_geometry_occ_union_unify(OPT_ARGS_NUM);
 double opt_geometry_occ_parallel(OPT_ARGS_NUM);
 double opt_geometry_occ_boolean_preserve_numbering(OPT_ARGS_NUM);
 double opt_geometry_occ_scaling(OPT_ARGS_NUM);
@@ -484,6 +488,9 @@ double opt_mesh_partition_num(OPT_ARGS_NUM);
 double opt_mesh_partition_metis_algorithm(OPT_ARGS_NUM);
 double opt_mesh_partition_metis_edge_matching(OPT_ARGS_NUM);
 double opt_mesh_partition_metis_refinement_algorithm(OPT_ARGS_NUM);
+double opt_mesh_partition_metis_max_load_imbalance(OPT_ARGS_NUM);
+double opt_mesh_partition_metis_objective(OPT_ARGS_NUM);
+double opt_mesh_partition_metis_min_conn(OPT_ARGS_NUM);
 double opt_mesh_partition_hex_weight(OPT_ARGS_NUM);
 double opt_mesh_partition_pri_weight(OPT_ARGS_NUM);
 double opt_mesh_partition_pyr_weight(OPT_ARGS_NUM);
@@ -502,11 +509,15 @@ double opt_mesh_cross_field_closest_point(OPT_ARGS_NUM);
 double opt_mesh_bdf_field_format(OPT_ARGS_NUM);
 double opt_mesh_stl_remove_duplicate_triangles(OPT_ARGS_NUM);
 double opt_mesh_stl_one_solid_per_surface(OPT_ARGS_NUM);
+double opt_mesh_stl_linear_deflection(OPT_ARGS_NUM);
+double opt_mesh_stl_angular_deflection(OPT_ARGS_NUM);
 double opt_mesh_boundary_layer_fan_points(OPT_ARGS_NUM);
 double opt_mesh_nb_smoothing(OPT_ARGS_NUM);
 double opt_mesh_algo2d(OPT_ARGS_NUM);
 double opt_mesh_algo3d(OPT_ARGS_NUM);
+double opt_mesh_algo_switch_on_failure(OPT_ARGS_NUM);
 double opt_mesh_algo_recombine(OPT_ARGS_NUM);
+double opt_mesh_max_retries(OPT_ARGS_NUM);
 double opt_mesh_recombine_all(OPT_ARGS_NUM);
 double opt_mesh_recombine_optimize_topology(OPT_ARGS_NUM);
 double opt_mesh_recombine3d_all(OPT_ARGS_NUM);
@@ -516,6 +527,7 @@ double opt_mesh_flexible_transfinite(OPT_ARGS_NUM);
 double opt_mesh_algo_subdivide(OPT_ARGS_NUM);
 double opt_mesh_mesh_only_visible(OPT_ARGS_NUM);
 double opt_mesh_min_circ_points(OPT_ARGS_NUM);
+double opt_mesh_min_elements_2pi(OPT_ARGS_NUM);
 double opt_mesh_allow_swap_edge_angle(OPT_ARGS_NUM);
 double opt_mesh_min_curv_points(OPT_ARGS_NUM);
 double opt_mesh_order(OPT_ARGS_NUM);
@@ -526,13 +538,17 @@ double opt_mesh_ho_threshold_min(OPT_ARGS_NUM);
 double opt_mesh_ho_threshold_max(OPT_ARGS_NUM);
 double opt_mesh_ho_poisson(OPT_ARGS_NUM);
 double opt_mesh_ho_prim_surf_mesh(OPT_ARGS_NUM);
+double opt_mesh_ho_dist_cad(OPT_ARGS_NUM);
 double opt_mesh_ho_iter_max(OPT_ARGS_NUM);
 double opt_mesh_ho_pass_max(OPT_ARGS_NUM);
 double opt_mesh_second_order_experimental(OPT_ARGS_NUM);
 double opt_mesh_second_order_linear(OPT_ARGS_NUM);
 double opt_mesh_second_order_incomplete(OPT_ARGS_NUM);
 double opt_mesh_cgns_import_order(OPT_ARGS_NUM);
+double opt_mesh_cgns_import_ignore_bc(OPT_ARGS_NUM);
+double opt_mesh_cgns_import_ignore_solution(OPT_ARGS_NUM);
 double opt_mesh_cgns_construct_topology(OPT_ARGS_NUM);
+double opt_mesh_cgns_export_cpex0045(OPT_ARGS_NUM);
 double opt_mesh_dual(OPT_ARGS_NUM);
 double opt_mesh_voronoi(OPT_ARGS_NUM);
 double opt_mesh_draw_skin_only(OPT_ARGS_NUM);
@@ -542,6 +558,9 @@ double opt_mesh_save_parametric(OPT_ARGS_NUM);
 double opt_mesh_save_topology(OPT_ARGS_NUM);
 double opt_mesh_save_groups_of_nodes(OPT_ARGS_NUM);
 double opt_mesh_color_carousel(OPT_ARGS_NUM);
+double opt_mesh_compound_classify(OPT_ARGS_NUM);
+double opt_mesh_compound_lc_factor(OPT_ARGS_NUM);
+double opt_mesh_random_seed(OPT_ARGS_NUM);
 double opt_mesh_switch_elem_tags(OPT_ARGS_NUM);
 double opt_mesh_zone_definition(OPT_ARGS_NUM);
 double opt_mesh_nb_nodes(OPT_ARGS_NUM);
@@ -556,6 +575,7 @@ double opt_mesh_cpu_time(OPT_ARGS_NUM);
 double opt_mesh_clip(OPT_ARGS_NUM);
 double opt_mesh_ignore_periodicity(OPT_ARGS_NUM);
 double opt_mesh_preserve_numbering_msh2(OPT_ARGS_NUM);
+double opt_mesh_max_iter_delaunay_3d(OPT_ARGS_NUM);
 double opt_mesh_max_num_threads_1d(OPT_ARGS_NUM);
 double opt_mesh_max_num_threads_2d(OPT_ARGS_NUM);
 double opt_mesh_max_num_threads_3d(OPT_ARGS_NUM);
@@ -581,6 +601,7 @@ double opt_post_anim_delay(OPT_ARGS_NUM);
 double opt_post_anim_cycle(OPT_ARGS_NUM);
 double opt_post_anim_step(OPT_ARGS_NUM);
 double opt_post_combine_remove_orig(OPT_ARGS_NUM);
+double opt_post_combine_copy_options(OPT_ARGS_NUM);
 double opt_post_plugins(OPT_ARGS_NUM);
 double opt_post_nb_views(OPT_ARGS_NUM);
 double opt_post_file_format(OPT_ARGS_NUM);
@@ -759,6 +780,9 @@ double opt_print_x3d_compatibility(OPT_ARGS_NUM);
 double opt_print_x3d_transparency(OPT_ARGS_NUM);
 double opt_print_x3d_remove_inner_borders(OPT_ARGS_NUM);
 double opt_print_x3d_precision(OPT_ARGS_NUM);
+double opt_print_x3d_surfaces(OPT_ARGS_NUM);
+double opt_print_x3d_edges(OPT_ARGS_NUM);
+double opt_print_x3d_vertices(OPT_ARGS_NUM);
 
 // COLORS
 
