@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "GmshConfig.h"
 #if !defined(HAVE_NO_STDINT_H)
@@ -51,9 +51,9 @@ public:
   }
   int NonBlockingWait(double waitint, double timeout, int socket)
   {
-    double start = GetTimeInSeconds();
+    double start = TimeOfDay();
     while(1) {
-      if(timeout > 0 && GetTimeInSeconds() - start > timeout)
+      if(timeout > 0 && TimeOfDay() - start > timeout)
         return 2; // timeout
       if(_client->getPid() < 0 ||
          (_client->getExecutable().empty() && !CTX::instance()->solver.listen))
@@ -139,7 +139,7 @@ public:
       }
       else {
         std::vector<std::string> cl = onelabUtils::getCommandLine(_client);
-        for(unsigned int i = 0; i < cl.size(); i++) args.append(" " + cl[i]);
+        for(std::size_t i = 0; i < cl.size(); i++) args.append(" " + cl[i]);
       }
       args.append(" " + _client->getSocketSwitch() + " \"" +
                   _client->getName() + "\" %s");
@@ -216,7 +216,7 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
   // receive a message on the associated GmshServer; 'master' is only used when
   // creating subclients with GMSH_CONNECT.
 
-  double timer = GetTimeInSeconds();
+  double timer = TimeOfDay();
 
   if(!getGmshServer()) {
     Msg::Error("Abnormal server termination (no valid server)");
@@ -251,7 +251,7 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
     if(getFather()) {
       std::string reply = getName(); // reply is dummy
       getFather()->getGmshServer()->SendMessage(GmshSocket::GMSH_STOP,
-                                                reply.size(), &reply[0]);
+                                                (int)reply.size(), &reply[0]);
     }
     break;
   case GmshSocket::GMSH_PARAMETER:
@@ -357,13 +357,13 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
       Msg::Error("Unknown ONELAB parameter type in query: %s", ptype.c_str());
 
     if(reply.size()) {
-      getGmshServer()->SendMessage(GmshSocket::GMSH_PARAMETER, reply.size(),
-                                   &reply[0]);
+      getGmshServer()->SendMessage(GmshSocket::GMSH_PARAMETER,
+                                   (int)reply.size(), &reply[0]);
     }
     else {
       reply = name;
       getGmshServer()->SendMessage(GmshSocket::GMSH_PARAMETER_NOT_FOUND,
-                                   reply.size(), &reply[0]);
+                                   (int)reply.size(), &reply[0]);
     }
   } break;
   case GmshSocket::GMSH_PARAMETER_QUERY_ALL: {
@@ -391,12 +391,12 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
     else
       Msg::Error("Unknown ONELAB parameter type in query: %s", ptype.c_str());
 
-    for(unsigned int i = 0; i < replies.size(); i++)
+    for(std::size_t i = 0; i < replies.size(); i++)
       getGmshServer()->SendMessage(GmshSocket::GMSH_PARAMETER_QUERY_ALL,
-                                   replies[i].size(), &replies[i][0]);
+                                   (int)replies[i].size(), &replies[i][0]);
     reply = "Sent all ONELAB " + ptype + "s";
     getGmshServer()->SendMessage(GmshSocket::GMSH_PARAMETER_QUERY_END,
-                                 reply.size(), &reply[0]);
+                                 (int)reply.size(), &reply[0]);
   } break;
   case GmshSocket::GMSH_PARAMETER_CLEAR:
     clear(message == "*" ? "" : message);
@@ -415,7 +415,9 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
     break;
   case GmshSocket::GMSH_MERGE_FILE:
     if(CTX::instance()->solver.autoMergeFile) {
-      unsigned int n = PView::list.size();
+#if defined(HAVE_FLTK)
+      std::size_t n = PView::list.size();
+#endif
       bool changedBeforeMerge = onelab::server::instance()->getChanged("Gmsh");
       MergePostProcessingFile(message, CTX::instance()->solver.autoShowViews,
                               CTX::instance()->solver.autoShowLastStep, true);
@@ -440,11 +442,13 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
 #endif
     break;
   case GmshSocket::GMSH_SPEED_TEST:
-    Msg::Info("got %d Mb message in %g seconds", length / 1024 / 1024,
-              GetTimeInSeconds() - timer);
+    Msg::Info("Got %d Mb message in %g seconds", length / 1024 / 1024,
+              TimeOfDay() - timer);
     break;
   case GmshSocket::GMSH_VERTEX_ARRAY: {
+#if defined(HAVE_FLTK)
     int n = PView::list.size();
+#endif
     PView::fillVertexArray(this, length, &message[0], swap);
 #if defined(HAVE_FLTK)
     if(FlGui::available())
@@ -488,8 +492,8 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
     reply =
       onelab::server::instance()->getChanged(clientName) ? "true" : "false";
 #endif
-    getGmshServer()->SendMessage(GmshSocket::GMSH_OLPARSE, reply.size(),
-                                 &reply[0]);
+    getGmshServer()->SendMessage(GmshSocket::GMSH_OLPARSE,
+                                 (int)reply.size(), &reply[0]);
   } break;
   case GmshSocket::GMSH_CLIENT_CHANGED: {
     std::string::size_type first = 0;
@@ -499,7 +503,7 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
       std::string reply =
         onelab::server::instance()->getChanged(name) ? "true" : "false";
       getGmshServer()->SendMessage(GmshSocket::GMSH_CLIENT_CHANGED,
-                                   reply.size(), &reply[0]);
+                                   (int)reply.size(), &reply[0]);
     }
     else if(command == "set") {
       std::string changed = onelab::parameter::getNextToken(message, first);
@@ -588,7 +592,7 @@ new_connection:
         }
       }
     }
-    for(unsigned int i = 0; i < toDelete.size(); i++) {
+    for(std::size_t i = 0; i < toDelete.size(); i++) {
       removeClient(toDelete[i]);
       delete toDelete[i];
     }
@@ -624,7 +628,7 @@ new_connection:
       toDelete.push_back(c);
     }
   }
-  for(unsigned int i = 0; i < toDelete.size(); i++) {
+  for(std::size_t i = 0; i < toDelete.size(); i++) {
     removeClient(toDelete[i]);
     delete toDelete[i];
   }
