@@ -1,11 +1,12 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _CLIPPING_WINDOW_H_
-#define _CLIPPING_WINDOW_H_
+#ifndef CLIPPING_WINDOW_H
+#define CLIPPING_WINDOW_H
 
+#include <FL/Fl.H>
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Choice.H>
 #include <FL/Fl_Multi_Browser.H>
@@ -26,6 +27,7 @@ public:
 
 public:
   clippingWindow(int deltaFontSize = 0);
+  ~clippingWindow() { Fl::delete_widget(win); }
   void resetBrowser();
   void show();
 };
