@@ -1,12 +1,13 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _FIELD_WINDOW_H_
-#define _FIELD_WINDOW_H_
+#ifndef FIELD_WINDOW_H
+#define FIELD_WINDOW_H
 
 #include <list>
+#include <FL/Fl.H>
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Hold_Browser.H>
 #include <FL/Fl_Help_View.H>
@@ -38,6 +39,7 @@ public:
 
 public:
   fieldWindow(int deltaFontSize = 0);
+  ~fieldWindow() { Fl::delete_widget(win); }
   void loadFieldViewList();
   void loadFieldList();
   void saveFieldOptions();
