@@ -1,11 +1,12 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _HIGHORDERTOOLS_WINDOW_H_
-#define _HIGHORDERTOOLS_WINDOW_H_
+#ifndef HIGHORDERTOOLS_WINDOW_H
+#define HIGHORDERTOOLS_WINDOW_H
 
+#include <FL/Fl.H>
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Box.H>
 #include <FL/Fl_Choice.H>
@@ -21,14 +22,15 @@ public:
   bool CAD, complete;
   int meshOrder;
   Fl_Window *win;
-  Fl_Box *box[20];
-  Fl_Check_Button *butt[20];
-  Fl_Value_Input *value[20];
-  Fl_Choice *choice[20];
-  Fl_Button *push[20];
+  Fl_Box *box;
+  Fl_Check_Button *butt[4];
+  Fl_Value_Input *value[12];
+  Fl_Choice *choice[4];
+  Fl_Button *push[2];
 
 public:
   highOrderToolsWindow(int deltaFontSize = 0);
+  ~highOrderToolsWindow() { Fl::delete_widget(win); }
   void show(bool redrawOnly);
 };
 
