@@ -1,15 +1,17 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _STATISTICS_WINDOW_H_
-#define _STATISTICS_WINDOW_H_
+#ifndef STATISTICS_WINDOW_H
+#define STATISTICS_WINDOW_H
 
+#include <FL/Fl.H>
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Output.H>
 #include <FL/Fl_Button.H>
 #include <FL/Fl_Group.H>
+#include <FL/Fl_Check_Button.H>
 
 class statisticsWindow {
 public:
@@ -18,10 +20,12 @@ public:
   Fl_Button *butt[8];
   Fl_Group *group[3];
   Fl_Box *memUsage;
+  Fl_Check_Button *visible;
   double quality[3][100];
 
 public:
   statisticsWindow(int deltaFontSize);
+  ~statisticsWindow() { Fl::delete_widget(win); }
   void compute(bool elementQuality);
   void show();
 };
