@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "GmshConfig.h"
 #if !defined(HAVE_NO_STDINT_H)
@@ -33,7 +33,7 @@ static void view_toggle_cb(Fl_Widget *w, void *data)
   viewButton *but = FlGui::instance()->onelab->getViewButton(num);
   if(but) {
     if(Fl::event_state(FL_SHIFT)) {
-      for(unsigned int i = 0; i < PView::list.size(); i++) {
+      for(std::size_t i = 0; i < PView::list.size(); i++) {
         if((int)i != num)
           opt_view_visible(i, GMSH_SET | GMSH_GUI, 0);
         else
@@ -86,13 +86,13 @@ static void view_reload_cb(Fl_Widget *w, void *data)
 
 static void view_reload_all_cb(Fl_Widget *w, void *data)
 {
-  for(unsigned int i = 0; i < PView::list.size(); i++) view_reload(i);
+  for(std::size_t i = 0; i < PView::list.size(); i++) view_reload(i);
   drawContext::global()->draw();
 }
 
 static void view_reload_visible_cb(Fl_Widget *w, void *data)
 {
-  for(unsigned int i = 0; i < PView::list.size(); i++)
+  for(std::size_t i = 0; i < PView::list.size(); i++)
     if(opt_view_visible(i, GMSH_GET, 0)) view_reload(i);
   drawContext::global()->draw();
 }
@@ -150,28 +150,24 @@ static void view_remove_cb(Fl_Widget *w, void *data)
   drawContext::global()->draw();
 }
 
-#if defined(HAVE_NATIVE_FILE_CHOOSER)
-#define TT "\t"
-#define NN "\n"
-#else
-#define TT " ("
-#define NN ")\t"
-#endif
-
 static void view_save_cb(Fl_Widget *w, void *data)
 {
   static const char *formats =
-    "Gmsh Parsed" TT "*.pos" NN "Gmsh Mesh-based" TT "*.pos" NN
-    "Gmsh Legacy ASCII" TT "*.pos" NN "Gmsh Legacy Binary" TT "*.pos" NN
-    "MED" TT "*.rmed" NN "STL Surface" TT "*.stl" NN "Generic TXT" TT
-    "*.txt" NN;
+    "Gmsh Parsed\t*.pos\nGmsh Mesh-based\t*.pos\n"
+    "Gmsh Legacy ASCII\t*.pos\nGmsh Legacy Binary\t*.pos\n"
+    "MED\t*.rmed\nSTL Surface\t*.stl\nGeneric TXT\t*.txt\n";
 
   PView *view = PView::list[(intptr_t)data];
  test:
   if(fileChooser(FILE_CHOOSER_CREATE, "Export", formats,
                  view->getData()->getFileName().c_str())) {
     std::string name = fileChooserGetName(1);
-    if(CTX::instance()->confirmOverwrite) {
+    bool confirmOverwrite = CTX::instance()->confirmOverwrite;
+#if defined(__APPLE__)
+    // handled directly by the native macOS file chooser
+    if(CTX::instance()->nativeFileChooser) confirmOverwrite = false;
+#endif
+    if(confirmOverwrite) {
       if(!StatFile(name))
         if(!fl_choice("File '%s' already exists.\n\nDo you want to replace it?",
                       "Cancel", "Replace", 0, name.c_str()))
@@ -191,9 +187,6 @@ static void view_save_cb(Fl_Widget *w, void *data)
   }
 }
 
-#undef TT
-#undef NN
-
 static void view_alias_with_options_cb(Fl_Widget *w, void *data)
 {
   const bool copyOptions = true;
@@ -204,42 +197,48 @@ static void view_alias_with_options_cb(Fl_Widget *w, void *data)
 
 static void view_combine_space_all_cb(Fl_Widget *w, void *data)
 {
-  PView::combine(false, 1, CTX::instance()->post.combineRemoveOrig);
+  PView::combine(false, 1, CTX::instance()->post.combineRemoveOrig,
+                 CTX::instance()->post.combineCopyOptions);
   FlGui::instance()->updateViews(true, true);
   drawContext::global()->draw();
 }
 
 static void view_combine_space_visible_cb(Fl_Widget *w, void *data)
 {
-  PView::combine(false, 0, CTX::instance()->post.combineRemoveOrig);
+  PView::combine(false, 0, CTX::instance()->post.combineRemoveOrig,
+                 CTX::instance()->post.combineCopyOptions);
   FlGui::instance()->updateViews(true, true);
   drawContext::global()->draw();
 }
 
 static void view_combine_space_by_name_cb(Fl_Widget *w, void *data)
 {
-  PView::combine(false, 2, CTX::instance()->post.combineRemoveOrig);
+  PView::combine(false, 2, CTX::instance()->post.combineRemoveOrig,
+                 CTX::instance()->post.combineCopyOptions);
   FlGui::instance()->updateViews(true, true);
   drawContext::global()->draw();
 }
 
 static void view_combine_time_all_cb(Fl_Widget *w, void *data)
 {
-  PView::combine(true, 1, CTX::instance()->post.combineRemoveOrig);
+  PView::combine(true, 1, CTX::instance()->post.combineRemoveOrig,
+                 CTX::instance()->post.combineCopyOptions);
   FlGui::instance()->updateViews(true, true);
   drawContext::global()->draw();
 }
 
 static void view_combine_time_visible_cb(Fl_Widget *w, void *data)
 {
-  PView::combine(true, 0, CTX::instance()->post.combineRemoveOrig);
+  PView::combine(true, 0, CTX::instance()->post.combineRemoveOrig,
+                 CTX::instance()->post.combineCopyOptions);
   FlGui::instance()->updateViews(true, true);
   drawContext::global()->draw();
 }
 
 static void view_combine_time_by_name_cb(Fl_Widget *w, void *data)
 {
-  PView::combine(true, 2, CTX::instance()->post.combineRemoveOrig);
+  PView::combine(true, 2, CTX::instance()->post.combineRemoveOrig,
+                 CTX::instance()->post.combineCopyOptions);
   FlGui::instance()->updateViews(true, true);
   drawContext::global()->draw();
 }
@@ -249,15 +248,12 @@ static void view_all_visible_cb(Fl_Widget *w, void *data)
   int mode = (intptr_t)data;
   std::string name;
   if(mode >= 0) name = PView::list[mode]->getData()->getName();
-  for(unsigned int i = 0; i < PView::list.size(); i++)
+  for(std::size_t i = 0; i < PView::list.size(); i++)
     opt_view_visible(i, GMSH_SET | GMSH_GUI,
-                     (mode == -1) ?
-                       1 :
-                       (mode == -2) ?
-                       0 :
-                       (mode == -3) ?
-                       !opt_view_visible(i, GMSH_GET, 0) :
-                       (name == PView::list[i]->getData()->getName()) ? 1 : 0);
+                     (mode == -1) ? 1 :
+                     (mode == -2) ? 0 :
+                     (mode == -3) ? !opt_view_visible(i, GMSH_GET, 0) :
+                     (name == PView::list[i]->getData()->getName()) ? 1 : 0);
   drawContext::global()->draw();
 }
 
