@@ -6,6 +6,7 @@
 #ifndef VISIBILITY_WINDOW_H
 #define VISIBILITY_WINDOW_H
 
+#include <FL/Fl.H>
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Choice.H>
 #include <FL/Fl_Browser.H>
@@ -26,9 +27,11 @@ public:
   Fl_Check_Button *butt[2];
   Fl_Button *push[2];
   Fl_Input *input[10];
+  Fl_Input *search;
 
 public:
   visibilityWindow(int deltaFontSize = 0);
+  ~visibilityWindow() { Fl::delete_widget(win); }
   void show(bool redrawOnly);
   void updatePerWindow(bool force = false);
 };
