@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 //
 // Contributed by Matti Pellikka <matti.pellikka@gmail.com>.
 
@@ -13,7 +13,7 @@
 #include "MHexahedron.h"
 #include "MPrism.h"
 
-bool Less_Cell::operator()(const Cell *c1, const Cell *c2) const
+bool CellPtrLessThan::operator()(const Cell *c1, const Cell *c2) const
 {
   // If cell complex is done use enumeration (same as vertex order)
   if(c1->getNum() != 0) return (c1->getNum() < c2->getNum());
@@ -35,7 +35,7 @@ bool equalVertices(const std::vector<MVertex *> &v1,
                    const std::vector<MVertex *> &v2)
 {
   if(v1.size() != v2.size()) return false;
-  for(unsigned int i = 0; i < v1.size(); i++)
+  for(std::size_t i = 0; i < v1.size(); i++)
     if(v1[i]->getNum() != v2[i]->getNum()) return false;
   return true;
 }
@@ -51,7 +51,7 @@ std::pair<Cell *, bool> Cell::createCell(MElement *element, int domain)
   cell->_immune = false;
   cell->_num = 0;
 
-  for(int i = 0; i < element->getNumPrimaryVertices(); i++)
+  for(std::size_t i = 0; i < element->getNumPrimaryVertices(); i++)
     cell->_v.push_back(element->getVertex(i));
 
   return std::make_pair(cell, cell->_sortVertexIndices());
@@ -78,7 +78,7 @@ Cell::Cell(MElement *element, int domain)
   _immune = false;
   _num = 0;
 
-  for(int i = 0; i < element->getNumPrimaryVertices(); i++)
+  for(std::size_t i = 0; i < element->getNumPrimaryVertices(); i++)
     _v.push_back(element->getVertex(i));
 
   _sortVertexIndices();
@@ -98,10 +98,10 @@ Cell::Cell(Cell *parent, int i)
 
 bool Cell::_sortVertexIndices()
 {
-  std::map<MVertex *, int, MVertexLessThanNum> si;
+  std::map<MVertex *, int, MVertexPtrLessThan> si;
 
   bool noinsert = false;
-  for(unsigned int i = 0; i < _v.size(); i++)
+  for(std::size_t i = 0; i < _v.size(); i++)
     noinsert = (!si.insert(std::make_pair(_v[i], i)).second || noinsert);
 
   if(noinsert == true) {
@@ -109,7 +109,7 @@ bool Cell::_sortVertexIndices()
     return false;
   }
 
-  std::map<MVertex *, int, MVertexLessThanNum>::iterator it;
+  std::map<MVertex *, int, MVertexPtrLessThan>::iterator it;
   for(it = si.begin(); it != si.end(); it++) _si.push_back(it->second);
 
   return true;
@@ -201,13 +201,13 @@ int Cell::findBdCellOrientation(Cell *cell, int i) const
 
   int perm = 1;
   if(equalVertices(v1, v2)) return perm;
-  while(std::next_permutation(v2.begin(), v2.end(), MVertexLessThanNum())) {
+  while(std::next_permutation(v2.begin(), v2.end(), MVertexPtrLessThan())) {
     perm *= -1;
     if(equalVertices(v1, v2)) return perm;
   }
   cell->getMeshVertices(v2);
   perm = 1;
-  while(std::prev_permutation(v2.begin(), v2.end(), MVertexLessThanNum())) {
+  while(std::prev_permutation(v2.begin(), v2.end(), MVertexPtrLessThan())) {
     perm *= -1;
     if(equalVertices(v1, v2)) return perm;
   }
@@ -486,7 +486,7 @@ int Cell::getTypeMSH() const
 bool Cell::hasVertex(int vertex) const
 {
   std::vector<int> v;
-  for(unsigned int i = 0; i < _v.size(); i++) {
+  for(std::size_t i = 0; i < _v.size(); i++) {
     v.push_back(_v[(int)_si[i]]->getNum());
   }
   std::vector<int>::const_iterator it = std::find(v.begin(), v.end(), vertex);
@@ -498,7 +498,7 @@ bool Cell::hasVertex(int vertex) const
 
 bool CombinedCell::hasVertex(int vertex) const
 {
-  for(std::map<Cell *, int, Less_Cell>::const_iterator cit = _cells.begin();
+  for(std::map<Cell *, int, CellPtrLessThan>::const_iterator cit = _cells.begin();
       cit != _cells.end(); cit++) {
     if(cit->first->hasVertex(vertex)) return true;
   }
@@ -510,7 +510,7 @@ void Cell::printCell()
   printf("%d-cell %d: \n", getDim(), getNum());
   printf("  Vertices:");
   for(int i = 0; i < this->getNumVertices(); i++) {
-    printf(" %d", this->getMeshVertex(i)->getNum());
+    printf(" %lu", this->getMeshVertex(i)->getNum());
   }
   printf(", in subdomain: %d, ", inSubdomain());
   printf("combined: %d. \n", isCombined());
@@ -533,13 +533,13 @@ void Cell::restoreCellBoundary()
     it->second.reset();
     if(it->second.get() == 0) toRemove.push_back(it->first);
   }
-  for(unsigned int i = 0; i < toRemove.size(); i++) _cbd.erase(toRemove[i]);
+  for(std::size_t i = 0; i < toRemove.size(); i++) _cbd.erase(toRemove[i]);
   toRemove.clear();
   for(biter it = firstBoundary(true); it != lastBoundary(); it++) {
     it->second.reset();
     if(it->second.get() == 0) toRemove.push_back(it->first);
   }
-  for(unsigned int i = 0; i < toRemove.size(); i++) _bd.erase(toRemove[i]);
+  for(std::size_t i = 0; i < toRemove.size(); i++) _bd.erase(toRemove[i]);
 }
 
 void Cell::addBoundaryCell(int orientation, Cell *cell, bool other)
@@ -676,7 +676,7 @@ int Cell::getCoboundarySize(bool orig)
   return size;
 }
 
-void Cell::getBoundary(std::map<Cell *, short int, Less_Cell> &boundary,
+void Cell::getBoundary(std::map<Cell *, short int, CellPtrLessThan> &boundary,
                        bool orig)
 {
   boundary.clear();
@@ -687,7 +687,7 @@ void Cell::getBoundary(std::map<Cell *, short int, Less_Cell> &boundary,
   }
 }
 
-void Cell::getCoboundary(std::map<Cell *, short int, Less_Cell> &coboundary,
+void Cell::getCoboundary(std::map<Cell *, short int, CellPtrLessThan> &coboundary,
                          bool orig)
 {
   coboundary.clear();
@@ -738,7 +738,7 @@ CombinedCell::CombinedCell(Cell *c1, Cell *c2, bool orMatch, bool co)
 
   // cells
   c1->getCells(_cells);
-  std::map<Cell *, int, Less_Cell> c2Cells;
+  std::map<Cell *, int, CellPtrLessThan> c2Cells;
   c2->getCells(c2Cells);
   for(citer cit = c2Cells.begin(); cit != c2Cells.end(); cit++) {
     if(!orMatch) (*cit).second = -1 * (*cit).second;
@@ -796,7 +796,7 @@ CombinedCell::CombinedCell(std::vector<Cell *> &cells)
   _immune = false;
 
   // cells
-  for(unsigned int i = 0; i < cells.size(); i++) {
+  for(std::size_t i = 0; i < cells.size(); i++) {
     Cell *c = cells.at(i);
     if(c->getImmune()) _immune = true;
     _cells[c] = 1;
