@@ -10,6 +10,7 @@
 #include <string>
 #include <vector>
 #include <map>
+#include "GmshDefines.h"
 #include "GEntity.h"
 #include "GPoint.h"
 #include "GEdgeLoop.h"
@@ -37,7 +38,7 @@ protected:
   GRegion *r1, *r2;
   mean_plane meanPlane;
   std::vector<GEdge *> embedded_edges;
-  std::set<GVertex *, GEntityLessThan> embedded_vertices;
+  std::set<GVertex *, GEntityPtrLessThan> embedded_vertices;
 
   BoundaryLayerColumns _columns;
 
@@ -61,7 +62,7 @@ public:
   virtual ~GFace();
 
   // delete mesh data
-  virtual void deleteMesh(bool onlyDeleteElements = false);
+  virtual void deleteMesh();
 
   // add/delete regions that are bounded by the face
   void addRegion(GRegion *r)
@@ -120,12 +121,16 @@ public:
 
   // direct access to embedded entities
   std::vector<GEdge *> &embeddedEdges() { return embedded_edges; }
-  std::set<GVertex *, GEntityLessThan> &embeddedVertices()
+  std::set<GVertex *, GEntityPtrLessThan> &embeddedVertices()
   {
     return embedded_vertices;
   }
 
-  std::vector<MVertex *> getEmbeddedMeshVertices() const;
+  // get embedded entities; if force is not set, don't return them if the face
+  // is part of a compound
+  std::vector<GVertex *> getEmbeddedVertices(bool force = false) const;
+  std::vector<GEdge *> getEmbeddedEdges(bool force = false) const;
+  std::vector<MVertex *> getEmbeddedMeshVertices(bool force = false) const;
 
   // vertices that bound the face
   virtual std::vector<GVertex *> vertices() const;
@@ -240,8 +245,14 @@ public:
                         double &z) const;
   void getMeanPlaneData(double plan[3][3]) const;
 
-  // number of types of elements
-  int getNumElementTypes() const { return 3; }
+  // types of elements
+  virtual void getElementTypes(std::vector<int> &types) const
+  {
+    types.clear();
+    types.push_back(TYPE_TRI);
+    types.push_back(TYPE_QUA);
+    types.push_back(TYPE_POLYG);
+  };
 
   // get total/by-type number of elements in the mesh
   std::size_t getNumMeshElements() const;
@@ -300,15 +311,35 @@ public:
     // reverse mesh orientation
     bool reverseMesh;
     // global mesh size constraint for the surface
-    double meshSize;
+    double meshSize, meshSizeFactor;
+    // do we force the meshing algorithm (if != 0)
+    int algorithm;
+    // do we force calculation of mesh size from boundary (if >= 0)
+    int meshSizeFromBoundary;
   } meshAttributes;
 
   int getMeshingAlgo() const;
-  void setMeshingAlgo(int) const;
-  void unsetMeshingAlgo() const;
-  int getCurvatureControlParameter() const;
-  void setCurvatureControlParameter(int);
-  virtual double getMeshSize() const { return meshAttributes.meshSize; }
+  void setMeshingAlgo(int val)
+  {
+    meshAttributes.algorithm = val;
+  }
+  void unsetMeshingAlgo()
+  {
+    meshAttributes.algorithm = 0;
+  }
+  int getMeshSizeFromBoundary() const;
+  void setMeshSizeFromBoundary(int val)
+  {
+    meshAttributes.meshSizeFromBoundary = val;
+  }
+  virtual double getMeshSize() const
+  {
+    return meshAttributes.meshSize;
+  }
+  virtual double getMeshSizeFactor() const
+  {
+    return meshAttributes.meshSizeFactor;
+  }
 
   struct {
     mutable GEntity::MeshGenerationStatus status;
@@ -327,6 +358,7 @@ public:
   std::vector<SPoint2> stl_vertices_uv;
   std::vector<SPoint3> stl_vertices_xyz;
   std::vector<SVector3> stl_normals;
+  std::vector<SVector3> stl_curvatures;
   std::vector<int> stl_triangles;
 
   // a vertex array containing a geometrical representation of the
@@ -347,6 +379,10 @@ public:
   std::vector<MQuadrangle *> quadrangles;
   std::vector<MPolygon *> polygons;
 
+  // when a compound of surfaces is created, we keep track of the compound
+  // surface
+  GFace *compoundSurface;
+
   void addTriangle(MTriangle *t) { triangles.push_back(t); }
   void addQuadrangle(MQuadrangle *q) { quadrangles.push_back(q); }
   void addPolygon(MPolygon *p) { polygons.push_back(p); }
@@ -361,7 +397,8 @@ public:
   std::vector<SVector3> storage3; // sizes and directions storage
   std::vector<double> storage4; // sizes and directions storage
 
-  virtual bool reorder(const int elementType, const std::vector<std::size_t> &ordering);
+  virtual bool reorder(const int elementType,
+                       const std::vector<std::size_t> &ordering);
 };
 
 #endif
