@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _GMODELIO_GEO_H_
-#define _GMODELIO_GEO_H_
+#ifndef GMODELIO_GEO_H
+#define GMODELIO_GEO_H
 
 class GModel;
 class ExtrudeParams;
@@ -34,6 +34,8 @@ private:
                 double ax, double ay, double az, double angle,
                 std::vector<std::pair<int, int> > &outDimTags,
                 ExtrudeParams *e = 0);
+  bool _addCompoundSpline(int &tag, const std::vector<int> &curveTags,
+                          int numPoints, bool bspline);
 
 public:
   GEO_Internals() { _allocateAll(); }
@@ -66,6 +68,10 @@ public:
   bool addBezier(int &tag, const std::vector<int> &pointTags);
   bool addBSpline(int &tag, const std::vector<int> &pointTags,
                   const std::vector<double> &seqknots = std::vector<double>());
+  bool addCompoundSpline(int &tag, const std::vector<int> &curveTags,
+                         int numPoints);
+  bool addCompoundBSpline(int &tag, const std::vector<int> &curveTags,
+                          int numPoints);
   bool addLineLoop(int &tag, const std::vector<int> &curveTags);
   bool addPlaneSurface(int &tag, const std::vector<int> &wireTags);
   bool addDiscreteSurface(int &tag);
@@ -139,6 +145,8 @@ public:
   void setRecombine(int dim, int tag, double angle);
   void setSmoothing(int tag, int val);
   void setReverseMesh(int dim, int tag, bool val = 1);
+  void setMeshAlgorithm(int dim, int tag, int val);
+  void setMeshSizeFromBoundary(int dim, int tag, int val);
 
   // synchronize internal CAD data with the given GModel
   void synchronize(GModel *model);
