@@ -137,7 +137,7 @@ int GModel::readUNV(const std::string &name)
             }
             vertices[i] = getMeshVertexByTag(n);
             if(!vertices[i]) {
-              Msg::Error("Wrong vertex index %d", n);
+              Msg::Error("Wrong node index %d", n);
               gmshclose(fp);
               return 0;
             }
@@ -296,7 +296,7 @@ int GModel::writeUNV(const std::string &name, bool saveAll,
 
   if(noPhysicalGroups()) saveAll = true;
 
-  indexMeshVertices(saveAll);
+  indexMeshVertices(saveAll, 0, false);
 
   std::vector<GEntity *> entities;
   getEntities(entities);
