@@ -232,6 +232,39 @@ static Vertex InterpolateBezier(Curve *Curve, double u, int derivee)
 // Uniform BSplines
 static Vertex InterpolateUBS(Curve *Curve, double u, int derivee)
 {
+#if 1 // bypass regression in Gmsh 4 for bsplines on geometry (see #685)
+  if(Curve->geometry){
+    bool periodic = (Curve->end == Curve->beg);
+    int NbControlPoints = List_Nbr(Curve->Control_Points);
+    int NbCurves = NbControlPoints + (periodic ? -1 : 1);
+    int iCurve = (int)floor(u * (double)NbCurves);
+    if(iCurve == NbCurves) iCurve -= 1; // u = 1
+    double t1 = (double)(iCurve) / (double)(NbCurves);
+    double t2 = (double)(iCurve + 1) / (double)(NbCurves);
+    double t = (u - t1) / (t2 - t1);
+    Vertex *v[4];
+    for(int i = 0; i < 4; i++) {
+      int k;
+      if(periodic) {
+        k = (iCurve - 1 + i) % (NbControlPoints - 1);
+        if(k < 0) k += NbControlPoints - 1;
+      }
+      else {
+        k = std::max(0, std::min(iCurve - 2 + i, NbControlPoints - 1));
+      }
+      List_Read(Curve->Control_Points, k, &v[i]);
+    }
+    SPoint2 pp = InterpolateCubicSpline(v, t, Curve->mat, t1, t2,
+                                        Curve->geometry, derivee);
+    SPoint3 pt = Curve->geometry->point(pp);
+    Vertex V;
+    V.Pos.X = pt.x();
+    V.Pos.Y = pt.y();
+    V.Pos.Z = pt.z();
+    return V;
+  }
+#endif
+
   // Mat for 2 control points (=> linear)
   static double mat2[4][4] = {
     {0, 0, 0, 0}, {0, 0, 0, 0}, {-1, 1, 0, 0}, {1, 0, 0, 0}};
@@ -295,10 +328,12 @@ static Vertex InterpolateUBS(Curve *Curve, double u, int derivee)
     else {
       k = std::min(iCurve + i, NbControlPoints - 1);
     }
-    if(k < NbControlPoints)
+
+    if(k >= 0 && k < NbControlPoints){
       List_Read(Curve->Control_Points, k, &v[i]);
+    }
     else {
-      Msg::Error("Wrong control point inedx in bspline");
+      Msg::Warning("Wrong control point index in bspline");
       Vertex V;
       return V;
     }
@@ -340,6 +375,7 @@ static Vertex InterpolateUBS(Curve *Curve, double u, int derivee)
     }
   }
 
+#if 0  // bypass regression in Gmsh 4 for bsplines on geometry (see #685)
   if(Curve->geometry) {
     SPoint2 pp =
       InterpolateCubicSpline(v, t, *matrix, t1, t2, Curve->geometry, derivee);
@@ -350,9 +386,8 @@ static Vertex InterpolateUBS(Curve *Curve, double u, int derivee)
     V.Pos.Z = pt.z();
     return V;
   }
-  else {
-    return InterpolateCubicSpline(v, t, *matrix, derivee, t1, t2);
-  }
+#endif
+  return InterpolateCubicSpline(v, t, *matrix, derivee, t1, t2);
 }
 
 // Non Uniform BSplines
@@ -645,7 +680,9 @@ Vertex InterpolateCurve(Curve *c, double u, int const derivee)
     Msg::Debug("Cannot interpolate discrete curve");
     break;
 
-  default: Msg::Error("Unknown curve type %d in interpolation", c->Typ); break;
+  default:
+    Msg::Error("Unknown curve type %d in interpolation", c->Typ);
+    break;
   }
   V.u = u;
   return V;
@@ -785,51 +822,6 @@ static void TransfiniteSph(Vertex S, Vertex center, Vertex *T)
   T->Pos.Z = center.Pos.Z + r * dirz;
 }
 
-bool IsRuledSurfaceASphere(Surface *s, SPoint3 &center, double &radius)
-{
-  if(s->Typ != MSH_SURF_REGL && s->Typ != MSH_SURF_TRIC) return false;
-  if(!List_Nbr(s->Generatrices)) return false;
-
-  bool isSphere = true;
-  Vertex *O = 0;
-  Curve *C[4] = {0, 0, 0, 0};
-  for(int i = 0; i < std::min(List_Nbr(s->Generatrices), 4); i++)
-    List_Read(s->Generatrices, i, &C[i]);
-
-  if(s->InSphereCenter) {
-    // it's on a sphere: get the center
-    O = s->InSphereCenter;
-  }
-  else {
-    // try to be intelligent (hum)
-    for(int i = 0; i < std::min(List_Nbr(s->Generatrices), 4); i++) {
-      if(C[i]->Typ != MSH_SEGM_CIRC && C[i]->Typ != MSH_SEGM_CIRC_INV) {
-        isSphere = false;
-      }
-      else if(isSphere) {
-        if(!i) {
-          List_Read(C[i]->Control_Points, 1, &O);
-          ((double *)center)[0] = O->Pos.X;
-          ((double *)center)[1] = O->Pos.Y;
-          ((double *)center)[2] = O->Pos.Z;
-        }
-        else {
-          Vertex *tmp;
-          List_Read(C[i]->Control_Points, 1, &tmp);
-          if(CompareVertex(&O, &tmp)) isSphere = false;
-        }
-      }
-    }
-  }
-  if(isSphere && C[0]) {
-    Vertex *p = C[0]->beg;
-    radius = std::sqrt((p->Pos.X - center.x()) + (p->Pos.Y - center.y()) +
-                       (p->Pos.Z - center.z()));
-  }
-
-  return isSphere;
-}
-
 static Vertex InterpolateRuledSurface(Surface *s, double u, double v)
 {
   Curve *C[4] = {0, 0, 0, 0};
@@ -839,8 +831,18 @@ static Vertex InterpolateRuledSurface(Surface *s, double u, double v)
     return Vertex(0., 0., 0.);
   }
 
-  for(int i = 0; i < std::min(List_Nbr(s->Generatrices), 4); i++)
+  for(int i = 0; i < std::min(List_Nbr(s->Generatrices), 4); i++) {
     List_Read(s->Generatrices, i, &C[i]);
+    if(C[i]->Typ == MSH_SEGM_BND_LAYER || C[i]->Typ == MSH_SEGM_DISCRETE) {
+      Msg::Error("Cannot interpolate ruled surface with discrete bounding curves");
+      return Vertex(0., 0., 0.);
+    }
+    if(!C[i]->beg || !C[i]->end) {
+      Msg::Error("Cannot interpolate ruled surface if bounding curves don't "
+                 "have end points");
+      return Vertex(0., 0., 0.);
+    }
+  }
 
   Vertex *O = 0;
   bool isSphere = true;
