@@ -1,17 +1,12 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 //
 // Contributed by Matti Pellikka <matti.pellikka@gmail.com>.
 
 #include "Homology.h"
 
-#if defined(HAVE_POST)
-#include "PView.h"
-#include "PViewOptions.h"
-#endif
-
 #if defined(HAVE_KBIPACK)
 
 Homology::Homology(GModel *model, const std::vector<int> &physicalDomain,
@@ -42,7 +37,7 @@ Homology::Homology(GModel *model, const std::vector<int> &physicalDomain,
     _getEntities(_imdomain, _immuneEntities);
   }
 
-  for(unsigned int i = 0; i < 4; i++) {
+  for(std::size_t i = 0; i < 4; i++) {
     _homologyComputed[i] = false;
     _cohomologyComputed[i] = false;
     _betti[i] = -1;
@@ -67,12 +62,12 @@ void Homology::_getEntities(const std::vector<int> &physicalGroups,
   _model->getPhysicalGroups(groups);
   std::map<int, std::vector<GEntity *> >::iterator it;
 
-  for(unsigned int i = 0; i < physicalGroups.size(); i++) {
+  for(std::size_t i = 0; i < physicalGroups.size(); i++) {
     for(int j = 0; j < 4; j++) {
       it = groups[j].find(physicalGroups.at(i));
       if(it != groups[j].end()) {
         std::vector<GEntity *> physicalGroup = (*it).second;
-        for(unsigned int k = 0; k < physicalGroup.size(); k++) {
+        for(std::size_t k = 0; k < physicalGroup.size(); k++) {
           entities.push_back(physicalGroup.at(k));
         }
       }
@@ -84,8 +79,8 @@ void Homology::_getElements(const std::vector<GEntity *> &entities,
                             std::vector<MElement *> &elements)
 {
   elements.clear();
-  for(unsigned int j = 0; j < entities.size(); j++) {
-    for(unsigned int i = 0; i < entities.at(j)->getNumMeshElements(); i++) {
+  for(std::size_t j = 0; j < entities.size(); j++) {
+    for(std::size_t i = 0; i < entities.at(j)->getNumMeshElements(); i++) {
       MElement *element = entities.at(j)->getMeshElement(i);
       elements.push_back(element);
     }
@@ -129,10 +124,10 @@ void Homology::_createCellComplex()
 
 void Homology::_deleteChains(std::vector<int> dim)
 {
-  for(unsigned int j = 0; j < dim.size(); j++) {
+  for(std::size_t j = 0; j < dim.size(); j++) {
     int d = dim.at(j);
     if(d < 0 || d > 3) continue;
-    for(unsigned int i = 0; i < _chains[d].size(); i++) {
+    for(std::size_t i = 0; i < _chains[d].size(); i++) {
       delete _chains[d].at(i);
     }
     _chains[d].clear();
@@ -142,10 +137,10 @@ void Homology::_deleteChains(std::vector<int> dim)
 
 void Homology::_deleteCochains(std::vector<int> dim)
 {
-  for(unsigned int j = 0; j < dim.size(); j++) {
+  for(std::size_t j = 0; j < dim.size(); j++) {
     int d = dim.at(j);
     if(d < 0 || d > 3) continue;
-    for(unsigned int i = 0; i < _cochains[d].size(); i++) {
+    for(std::size_t i = 0; i < _cochains[d].size(); i++) {
       delete _cochains[d].at(i);
     }
     _cochains[d].clear();
@@ -197,7 +192,7 @@ void Homology::findHomologyBasis(std::vector<int> dim)
             _cellComplex->getSize(3), _cellComplex->getSize(2),
             _cellComplex->getSize(1), _cellComplex->getSize(0));
 
-  Msg::StatusBar(true, "Computing homology space bases ...");
+  Msg::StatusBar(true, "Computing homology space bases...");
   t1 = Cpu();
   ChainComplex chainComplex = ChainComplex(_cellComplex);
   chainComplex.computeHomology();
@@ -212,7 +207,7 @@ void Homology::findHomologyBasis(std::vector<int> dim)
       std::string generator = convertInt(i);
 
       std::string name = "H_" + dimension + domain + generator;
-      std::map<Cell *, int, Less_Cell> chain;
+      std::map<Cell *, int, CellPtrLessThan> chain;
       chainComplex.getBasisChain(chain, i, j, 3, _smoothen);
       int torsion = chainComplex.getTorsion(j, i);
       if(!chain.empty()) {
@@ -239,7 +234,7 @@ void Homology::findHomologyBasis(std::vector<int> dim)
   Msg::StatusBar(false, "H_0: %d, H_1: %d, H_2: %d, H_3: %d", _betti[0],
                  _betti[1], _betti[2], _betti[3]);
 
-  for(unsigned int i = 0; i < dim.size(); i++) {
+  for(std::size_t i = 0; i < dim.size(); i++) {
     int d = dim.at(i);
     if(d >= 0 && d < 4) _homologyComputed[d] = true;
   }
@@ -301,7 +296,7 @@ void Homology::findCohomologyBasis(std::vector<int> dim)
       std::string generator = convertInt(i);
 
       std::string name = "H^" + dimension + domain + generator;
-      std::map<Cell *, int, Less_Cell> chain;
+      std::map<Cell *, int, CellPtrLessThan> chain;
       chainComplex.getBasisChain(chain, i, j, 3, false);
       int torsion = chainComplex.getTorsion(j, i);
       if(!chain.empty()) {
@@ -328,7 +323,7 @@ void Homology::findCohomologyBasis(std::vector<int> dim)
   Msg::StatusBar(false, "H^0: %d, H^1: %d, H^2: %d, H^3: %d", _betti[0],
                  _betti[1], _betti[2], _betti[3]);
 
-  for(unsigned int i = 0; i < dim.size(); i++) {
+  for(std::size_t i = 0; i < dim.size(); i++) {
     int d = dim.at(i);
     if(d >= 0 && d < 4) _cohomologyComputed[d] = true;
   }
@@ -346,7 +341,7 @@ bool Homology::isBettiComputed() const
 bool Homology::isHomologyComputed(std::vector<int> dim) const
 {
   bool computed = true;
-  for(unsigned int i = 0; i < dim.size(); i++) {
+  for(std::size_t i = 0; i < dim.size(); i++) {
     int d = dim.at(i);
     if(d < 0 || d > 3) continue;
     computed = computed && _homologyComputed[d];
@@ -357,7 +352,7 @@ bool Homology::isHomologyComputed(std::vector<int> dim) const
 bool Homology::isCohomologyComputed(std::vector<int> dim) const
 {
   bool computed = true;
-  for(unsigned int i = 0; i < dim.size(); i++) {
+  for(std::size_t i = 0; i < dim.size(); i++) {
     int d = dim.at(i);
     if(d < 0 || d > 3) continue;
     computed = computed && _cohomologyComputed[d];
@@ -369,7 +364,7 @@ void Homology::findCompatibleBasisPair(int master, std::vector<int> dim)
 {
   if(!this->isHomologyComputed(dim)) this->findHomologyBasis(dim);
   if(!this->isCohomologyComputed(dim)) this->findCohomologyBasis(dim);
-  for(unsigned int idim = 0; idim < dim.size(); idim++) {
+  for(std::size_t idim = 0; idim < dim.size(); idim++) {
     int d = dim.at(idim);
     if(d < 1 || d > 2) continue;
     int n = this->betti(d);
@@ -437,7 +432,7 @@ std::vector<int> Homology::_addToModel(int dim, bool co, bool post,
   if(dim < 0 || dim > 3) return physicals;
   int pgnum = -1;
   if(!co) {
-    for(unsigned int i = 0; i < _chains[dim].size(); i++) {
+    for(std::size_t i = 0; i < _chains[dim].size(); i++) {
       if(physicalNumRequest != -1)
         pgnum = physicalNumRequest + i;
       else
@@ -447,7 +442,7 @@ std::vector<int> Homology::_addToModel(int dim, bool co, bool post,
     }
   }
   else {
-    for(unsigned int i = 0; i < _cochains[dim].size(); i++) {
+    for(std::size_t i = 0; i < _cochains[dim].size(); i++) {
       if(physicalNumRequest != -1)
         pgnum = physicalNumRequest + i;
       else
@@ -510,7 +505,7 @@ void Homology::getHomologyBasis(int dim, std::vector<Chain<int> > &hom)
   if(!_homologyComputed[dim]) findHomologyBasis();
 
   hom.resize(_chains[dim].size());
-  for(unsigned int i = 0; i < _chains[dim].size(); i++)
+  for(std::size_t i = 0; i < _chains[dim].size(); i++)
     hom[i] = *_chains[dim].at(i);
 }
 
@@ -520,7 +515,7 @@ void Homology::getCohomologyBasis(int dim, std::vector<Chain<int> > &coh)
   if(!_cohomologyComputed[dim]) findCohomologyBasis();
 
   coh.resize(_cochains[dim].size());
-  for(unsigned int i = 0; i < _cochains[dim].size(); i++)
+  for(std::size_t i = 0; i < _cochains[dim].size(); i++)
     coh[i] = *_cochains[dim].at(i);
 }
 
@@ -582,7 +577,7 @@ int Homology::eulerCharacteristic()
   return _cellComplex->eulerCharacteristic();
 }
 
-void Homology::_createChain(std::map<Cell *, int, Less_Cell> &preChain,
+void Homology::_createChain(std::map<Cell *, int, CellPtrLessThan> &preChain,
                             const std::string &name, bool co)
 {
   Chain<int> *chain = new Chain<int>();
@@ -610,7 +605,7 @@ std::string Homology::_getDomainString(const std::vector<int> &domain,
   if(domain.empty())
     domainString += "0";
   else {
-    for(unsigned int i = 0; i < domain.size(); i++) {
+    for(std::size_t i = 0; i < domain.size(); i++) {
       std::string temp = convertInt(domain.at(i));
       domainString += temp;
       if(domain.size() - 1 > i) {
@@ -622,7 +617,7 @@ std::string Homology::_getDomainString(const std::vector<int> &domain,
 
   if(!subdomain.empty()) {
     domainString += ",{";
-    for(unsigned int i = 0; i < subdomain.size(); i++) {
+    for(std::size_t i = 0; i < subdomain.size(); i++) {
       std::string temp = convertInt(subdomain.at(i));
       domainString += temp;
       if(subdomain.size() - 1 > i) {
@@ -651,7 +646,7 @@ void Homology::storeCells(CellComplex *cellComplex, int dim)
   for(CellComplex::citer cit = cellComplex->firstCell(dim);
       cit != cellComplex->lastCell(dim); cit++) {
     Cell *cell = *cit;
-    std::map<Cell *, int, Less_Cell> cells;
+    std::map<Cell *, int, CellPtrLessThan> cells;
     cell->getCells(cells);
     for(Cell::citer it = cells.begin(); it != cells.end(); it++) {
       Cell *subCell = it->first;
