@@ -15,10 +15,10 @@
 // remove that when MElementCut is removed
 bool MEdge::isInside(MVertex *v) const
 {
-  double tol = MVertexLessThanLexicographic::getTolerance();
+  double tol = MVertexPtrLessThanLexicographic::getTolerance();
   MVertex *v0 = _v[0];
   MVertex *v1 = _v[1];
-  MVertexLessThanLexicographic lt;
+  MVertexPtrLessThanLexicographic lt;
   if(lt(v0, v1)) {
     v0 = _v[1];
     v1 = _v[0];
@@ -81,21 +81,22 @@ bool SortEdgeConsecutive(const std::vector<MEdge> &e,
     if(it0 == c.end())
       c[v0] = std::make_pair(v1, (MVertex *)NULL);
     else {
-      if(it0->second.second == NULL) {
-        it0->second.second = v1;
-      }
+      if(it0->second.second == NULL) { it0->second.second = v1; }
       else {
-        Msg::Error("Wrong topology for a list of edges");
+        Msg::Debug("A list of edges has points that are adjacent to 3 edges");
+        return false;
       }
     }
     if(it1 == c.end())
       c[v1] = std::make_pair(v0, (MVertex *)NULL);
     else {
-      if(it1->second.second == NULL) {
-        it1->second.second = v0;
-      }
+      if(it1->second.second == NULL) { it1->second.second = v0; }
       else {
-        Msg::Error("Wrong topology for a list of edges ");
+        Msg::Debug("Wrong topology for a list of edges");
+        Msg::Debug("Node %d is adjacent to more than 2 nodes %d %d",
+                   v1->getNum(),it1->second.first->getNum(),
+                   it1->second.second->getNum());
+        return false;
       }
     }
   }
@@ -132,6 +133,7 @@ bool SortEdgeConsecutive(const std::vector<MEdge> &e,
         c.find(current);
       if(it == c.end() || it->first == NULL) {
         Msg::Error("Impossible to find %d", current->getNum());
+        return false;
       }
       MVertex *v1 = it->second.first;
       MVertex *v2 = it->second.second;
@@ -145,9 +147,7 @@ bool SortEdgeConsecutive(const std::vector<MEdge> &e,
         break;
       }
       prev = temp;
-      if(current == start) {
-        v.push_back(current);
-      }
+      if(current == start) { v.push_back(current); }
     } while(current != start && current != NULL);
     vs.push_back(v);
   }
