@@ -1,15 +1,15 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _MEDGE_HASH_H_
-#define _MEDGE_HASH_H_
+#ifndef MEDGE_HASH_H
+#define MEDGE_HASH_H
 
 #include "MEdge.h"
 #include "Hash.h"
 
-struct Hash_Edge : public std::unary_function<MEdge, size_t> {
+struct MEdgeHash : public std::unary_function<MEdge, size_t> {
   size_t operator()(const MEdge &e) const
   {
     const MVertex *v[2];
