@@ -11,7 +11,6 @@
 #include "fullMatrix.h"
 #include "bezierBasis.h"
 #include "BasisFactory.h"
-#include "FuncSpaceData.h"
 
 void MElementBB(void *a, double *min, double *max)
 {
@@ -35,10 +34,7 @@ void MElementBB(void *a, double *min, double *max)
     fullMatrix<double> nodesXYZ(e->getNumVertices(), 3);
     e->getNodesCoord(nodesXYZ);
 
-    fullMatrix<double> bezNodes(e->getNumVertices(), 3);
-
-    const bezierBasis *bez = BasisFactory::getBezierBasis(FuncSpaceData(e));
-    bez->lag2Bez(nodesXYZ, bezNodes);
+    bezierCoeff bezNodes(e->getFuncSpaceData(), nodesXYZ);
     min[0] = max[0] = bezNodes(0, 0);
     min[1] = max[1] = bezNodes(0, 1);
     min[2] = max[2] = bezNodes(0, 2);
@@ -116,7 +112,6 @@ MElementOctree::MElementOctree(GModel *m) : _gm(m)
         Octree_Insert(entities[i]->getMeshElement(j), _octree);
     }
   }
-  // exit(1);
   Octree_Arrange(_octree);
 }
 
@@ -126,7 +121,6 @@ MElementOctree::MElementOctree(const std::vector<MElement *> &v)
   SBoundingBox3d bb;
   for(std::size_t i = 0; i < v.size(); i++) {
     for(std::size_t j = 0; j < v[i]->getNumVertices(); j++) {
-      // if (!_gm) _gm = v[i]->getVertex(j)->onWhat()->model();
       bb += SPoint3(v[i]->getVertex(j)->x(), v[i]->getVertex(j)->y(),
                     v[i]->getVertex(j)->z());
     }
