@@ -1,13 +1,13 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 //
 // Contributor(s):
 //   Frederic Duboeuf
 
-#ifndef _MSUBELEMENT_H_
-#define _MSUBELEMENT_H_
+#ifndef MSUBELEMENT_H
+#define MSUBELEMENT_H
 
 #include "GmshMessage.h"
 #include "MElement.h"
@@ -87,8 +87,8 @@ public:
                              double jac[3][3]) const;
   virtual double getPrimaryJacobian(double u, double v, double w,
                                     double jac[3][3]) const;
-  virtual int getNumShapeFunctions() const;
-  virtual int getNumPrimaryShapeFunctions() const;
+  virtual std::size_t getNumShapeFunctions() const;
+  virtual std::size_t getNumPrimaryShapeFunctions() const;
   virtual const MVertex *getShapeFunctionNode(int i) const;
   virtual MVertex *getShapeFunctionNode(int i);
   virtual void xyz2uvw(double xyz[3], double uvw[3]) const;
@@ -194,8 +194,8 @@ public:
                              double jac[3][3]) const;
   virtual double getPrimaryJacobian(double u, double v, double w,
                                     double jac[3][3]) const;
-  virtual int getNumShapeFunctions() const;
-  virtual int getNumPrimaryShapeFunctions() const;
+  virtual std::size_t getNumShapeFunctions() const;
+  virtual std::size_t getNumPrimaryShapeFunctions() const;
   virtual const MVertex *getShapeFunctionNode(int i) const;
   virtual MVertex *getShapeFunctionNode(int i);
   virtual void xyz2uvw(double xyz[3], double uvw[3]) const;
@@ -301,8 +301,8 @@ public:
                              double jac[3][3]) const;
   virtual double getPrimaryJacobian(double u, double v, double w,
                                     double jac[3][3]) const;
-  virtual int getNumShapeFunctions() const;
-  virtual int getNumPrimaryShapeFunctions() const;
+  virtual std::size_t getNumShapeFunctions() const;
+  virtual std::size_t getNumPrimaryShapeFunctions() const;
   virtual const MVertex *getShapeFunctionNode(int i) const;
   virtual MVertex *getShapeFunctionNode(int i);
   virtual void xyz2uvw(double xyz[3], double uvw[3]) const;
@@ -408,8 +408,8 @@ public:
                              double jac[3][3]) const;
   virtual double getPrimaryJacobian(double u, double v, double w,
                                     double jac[3][3]) const;
-  virtual int getNumShapeFunctions() const;
-  virtual int getNumPrimaryShapeFunctions() const;
+  virtual std::size_t getNumShapeFunctions() const;
+  virtual std::size_t getNumPrimaryShapeFunctions() const;
   virtual const MVertex *getShapeFunctionNode(int i) const;
   virtual MVertex *getShapeFunctionNode(int i);
   virtual void xyz2uvw(double xyz[3], double uvw[3]) const;
