@@ -143,11 +143,13 @@ public:
   }
   virtual bool getParameter(int i, double &par) const
   {
+    if(i != 0) return false;
     par = _u;
     return true;
   }
   virtual bool setParameter(int i, double par)
   {
+    if (i != 0  ) return false;
     _u = par;
     return true;
   }
@@ -172,20 +174,31 @@ public:
   }
   virtual bool getParameter(int i, double &par) const
   {
-    par = (i ? _v : _u);
-    return true;
+    if(i == 0) {
+      par = _u;
+      return true;
+    }
+    else if(i == 1) {
+      par = _v;
+      return true;
+    }
+    return false;
   }
   virtual bool setParameter(int i, double par)
   {
-    if(!i)
+    if(i == 0) {
       _u = par;
-    else
+      return true;
+    }
+    else if(i == 1) {
       _v = par;
-    return true;
+      return true;
+    }
+    return false;
   }
 };
 
-class MVertexLessThanLexicographic {
+class MVertexPtrLessThanLexicographic {
   static double tolerance;
 
 public:
@@ -193,13 +206,27 @@ public:
   bool operator()(const MVertex *v1, const MVertex *v2) const;
 };
 
-struct MVertexLessThanNum {
+struct MVertexPtrLessThan {
   bool operator()(const MVertex *v1, const MVertex *v2) const
   {
     return v1->getNum() < v2->getNum();
   }
 };
 
+struct MVertexPtrEqual {
+  bool operator()(const MVertex *v1, const MVertex *v2) const
+  {
+    return v1->getNum() == v2->getNum();
+  }
+};
+
+struct MVertexPtrHash {
+  size_t operator()(const MVertex *v) const
+  {
+    return v->getNum();
+  }
+};
+
 bool reparamMeshEdgeOnFace(MVertex *v1, MVertex *v2, GFace *gf, SPoint2 &param1,
                            SPoint2 &param2);
 bool reparamMeshVertexOnFace(MVertex const *v, const GFace *gf, SPoint2 &param,
