@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _OCC_REGION_H_
-#define _OCC_REGION_H_
+#ifndef OCC_REGION_H
+#define OCC_REGION_H
 
 #include "GmshConfig.h"
 #include "GRegion.h"
@@ -25,7 +25,6 @@ public:
   virtual GeomType geomType() const;
   ModelType getNativeType() const { return OpenCascadeModel; }
   void *getNativePtr() const { return (void *)&s; }
-  TopoDS_Solid getTopoDS_Shape() { return s; }
   void writeBREP(const char *filename);
 };
 
