@@ -21,6 +21,10 @@ discreteRegion::discreteRegion(GModel *model, int num) : GRegion(model, num)
   Tree_Add(model->getGEOInternals()->Volumes, &v);
 }
 
+discreteRegion::discreteRegion(GModel *model) : GRegion(model, 0)
+{
+}
+
 void discreteRegion::setBoundFaces(const std::set<int> &tagFaces)
 {
   for(std::set<int>::const_iterator it = tagFaces.begin(); it != tagFaces.end();
@@ -45,7 +49,7 @@ void discreteRegion::setBoundFaces(const std::vector<int> &tagFaces,
     tags.insert(tagFaces.begin(), tagFaces.end());
     setBoundFaces(tags);
   }
-  for(unsigned int i = 0; i != tagFaces.size(); i++) {
+  for(std::size_t i = 0; i != tagFaces.size(); i++) {
     GFace *face = model()->getFaceByTag(tagFaces[i]);
     if(face) {
       l_faces.push_back(face);
@@ -59,14 +63,14 @@ void discreteRegion::setBoundFaces(const std::vector<int> &tagFaces,
 }
 
 void discreteRegion::findFaces(
-  std::map<MFace, std::vector<int>, Less_Face> &map_faces)
+  std::map<MFace, std::vector<int>, MFaceLessThan> &map_faces)
 {
-  std::set<MFace, Less_Face> bound_faces;
-  for(unsigned int elem = 0; elem < getNumMeshElements(); elem++) {
+  std::set<MFace, MFaceLessThan> bound_faces;
+  for(std::size_t elem = 0; elem < getNumMeshElements(); elem++) {
     MElement *e = getMeshElement(elem);
     for(int iFace = 0; iFace < e->getNumFaces(); iFace++) {
       MFace tmp_face = e->getFace(iFace);
-      std::set<MFace, Less_Face>::iterator itset = bound_faces.find(tmp_face);
+      std::set<MFace, MFaceLessThan>::iterator itset = bound_faces.find(tmp_face);
       if(itset == bound_faces.end())
         bound_faces.insert(tmp_face);
       else
@@ -75,9 +79,9 @@ void discreteRegion::findFaces(
   }
 
   // for the boundary faces, associate the tag of the discrete face
-  for(std::set<MFace, Less_Face>::iterator itv = bound_faces.begin();
+  for(std::set<MFace, MFaceLessThan>::iterator itv = bound_faces.begin();
       itv != bound_faces.end(); ++itv) {
-    std::map<MFace, std::vector<int>, Less_Face>::iterator itmap =
+    std::map<MFace, std::vector<int>, MFaceLessThan>::iterator itmap =
       map_faces.find(*itv);
     if(itmap == map_faces.end()) {
       std::vector<int> tagRegions;
@@ -97,7 +101,8 @@ void discreteRegion::remesh()
 #if defined(HAVE_MESH)
 
   bool classify = false;
-  insertVerticesInRegion(this, 2000000000, classify);
+  insertVerticesInRegion(this, CTX::instance()->mesh.maxIterDelaunay3D,
+                         1., classify);
 
   // not functional yet: need boundaries
   for(int i = 0; i < std::max(CTX::instance()->mesh.optimize,
