@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _DISCRETE_REGION_H_
-#define _DISCRETE_REGION_H_
+#ifndef DISCRETE_REGION_H
+#define DISCRETE_REGION_H
 
 #include "GModel.h"
 #include "GRegion.h"
@@ -13,12 +13,13 @@
 class discreteRegion : public GRegion {
 public:
   discreteRegion(GModel *model, int num);
+  discreteRegion(GModel *model);
   virtual ~discreteRegion() {}
   virtual GeomType geomType() const { return DiscreteVolume; }
   void setBoundFaces(const std::set<int> &tagFaces);
   void setBoundFaces(const std::vector<int> &tagFaces,
                      const std::vector<int> &signFaces);
-  void findFaces(std::map<MFace, std::vector<int>, Less_Face> &map_faces);
+  void findFaces(std::map<MFace, std::vector<int>, MFaceLessThan> &map_faces);
   virtual void remesh();
 };
 
