@@ -10,17 +10,21 @@
 #include "GVertex.h"
 #include "MVertex.h"
 
+class Vertex;
+
 class discreteVertex : public GVertex {
 private:
-  double _x, _y, _z;
+  Vertex *_v;
 public:
   discreteVertex(GModel *m, int num, double x = 0., double y = 0.,
                  double z = 0.);
+  discreteVertex(GModel *m);
   virtual ~discreteVertex();
   virtual GPoint point() const;
   virtual double x() const;
   virtual double y() const;
   virtual double z() const;
+  virtual void setPosition(GPoint &p);
 };
 
 #endif
