@@ -24,8 +24,14 @@ public:
     : discreteFace(model, num), _partitions(), _parentEntity(NULL)
   {
   }
+  partitionFace(GModel *model,
+                const std::vector<unsigned int> &partitions)
+    : discreteFace(model), _partitions(partitions), _parentEntity(NULL)
+  {
+  }
   virtual ~partitionFace() {}
   virtual GeomType geomType() const { return PartitionSurface; }
+  virtual bool haveParametrization() { return false; }
   virtual void setParentEntity(GEntity *f) { _parentEntity = f; }
   virtual GEntity *getParentEntity() { return _parentEntity; }
   virtual void setPartitions(std::vector<unsigned int> &partitions)
@@ -43,7 +49,7 @@ public:
   virtual unsigned int numPartitions() const { return _partitions.size(); }
 };
 
-struct Less_partitionFace
+struct partitionFacePtrLessThan
   : public std::binary_function<partitionFace *, partitionFace *, bool> {
   bool operator()(const partitionFace *e1, const partitionFace *e2) const
   {
