@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _PARTITION_REGION_H_
-#define _PARTITION_REGION_H_
+#ifndef PARTITION_REGION_H
+#define PARTITION_REGION_H
 
 #include "GModel.h"
 #include "discreteRegion.h"
@@ -24,6 +24,11 @@ public:
     : discreteRegion(model, num), _partitions(), _parentEntity(NULL)
   {
   }
+  partitionRegion(GModel *model,
+                  const std::vector<unsigned int> &partitions)
+    : discreteRegion(model), _partitions(partitions), _parentEntity(NULL)
+  {
+  }
   virtual ~partitionRegion() {}
   virtual GeomType geomType() const { return PartitionVolume; }
   virtual void setParentEntity(GEntity *r) { _parentEntity = r; }
