@@ -38,7 +38,9 @@ double BDS_Face_Validity(GFace *gf, BDS_Face *f)
     Msg::Error("Null point in face validity");
     return 0.;
   }
-  if(pts[0]->degenerated + pts[1]->degenerated + pts[2]->degenerated < 2) {
+  if((pts[0]->degenerated ? 1 : 0) + (pts[1]->degenerated ? 1 : 0) +
+       (pts[2]->degenerated ? 1 : 0) <
+     2) {
     double qa1 = qmTriangle::gamma(pts[0], pts[1], pts[2]);
     return qa1 * _cos_N(pts[0], pts[1], pts[2], gf);
   }
@@ -48,6 +50,7 @@ double BDS_Face_Validity(GFace *gf, BDS_Face *f)
 void outputScalarField(std::vector<BDS_Face *> &t, const char *iii, int param,
                        GFace *gf)
 {
+  Msg::Info("Writing debug file '%s'", iii);
   if(gf && 0) {
     FILE *view_c = Fopen("param_mesh_as_it_is_in_3D.pos", "w");
     if(!view_c) {
@@ -62,11 +65,16 @@ void outputScalarField(std::vector<BDS_Face *> &t, const char *iii, int param,
       if(!(*tit)->deleted) {
         (*tit)->getNodes(pts);
         for(int j = 0; j < 3; j++) {
-          double U1 = pts[j]->degenerated ? pts[(j + 1) % 3]->u : pts[j]->u;
-          double U2 =
-            pts[(j + 1) % 3]->degenerated ? pts[j]->u : pts[(j + 1) % 3]->u;
-          SPoint2 p1(U1, pts[j]->v);
-          SPoint2 p2(U2, pts[(j + 1) % 3]->v);
+          double U1 =
+            pts[j]->degenerated == 1 ? pts[(j + 1) % 3]->u : pts[j]->u;
+          double U2 = pts[(j + 1) % 3]->degenerated == 1 ? pts[j]->u :
+                                                           pts[(j + 1) % 3]->u;
+          double V1 =
+            pts[j]->degenerated == 2 ? pts[(j + 1) % 3]->v : pts[j]->v;
+          double V2 = pts[(j + 1) % 3]->degenerated == 2 ? pts[j]->v :
+                                                           pts[(j + 1) % 3]->v;
+          SPoint2 p1(U1, V1);
+          SPoint2 p2(U2, V2);
           SPoint2 prev = p1;
           for(int k = 1; k < 30; k++) {
             double t = (double)k / 29;
@@ -106,26 +114,46 @@ void outputScalarField(std::vector<BDS_Face *> &t, const char *iii, int param,
                 (double)pts[1]->iD, (double)pts[2]->iD);
       }
       if(param && gf) {
-        if(pts[0]->degenerated + pts[1]->degenerated + pts[2]->degenerated >
+        // FIXME --- LOOK AT THE VALUE OG DEGENERATED
+        if((pts[0]->degenerated ? 1 : 0) + (pts[1]->degenerated ? 1 : 0) +
+             (pts[2]->degenerated ? 1 : 0) >
            1) {}
-        else if(pts[0]->degenerated)
+        else if(pts[0]->degenerated == 1)
           fprintf(f, "SQ(%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%g,%g,%g,%g};\n",
                   pts[1]->u, pts[1]->v, 0.0, pts[2]->u, pts[2]->v, 0.0,
                   pts[2]->u, pts[0]->v, 0.0, pts[1]->u, pts[0]->v, 0.0,
                   (double)pts[1]->iD, (double)pts[2]->iD, (double)pts[0]->iD,
                   (double)pts[0]->iD);
-        else if(pts[1]->degenerated)
+        else if(pts[1]->degenerated == 1)
           fprintf(f, "SQ(%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%g,%g,%g,%g};\n",
                   pts[2]->u, pts[2]->v, 0.0, pts[0]->u, pts[0]->v, 0.0,
                   pts[0]->u, pts[1]->v, 0.0, pts[2]->u, pts[1]->v, 0.0,
                   (double)pts[2]->iD, (double)pts[0]->iD, (double)pts[1]->iD,
                   (double)pts[1]->iD);
-        else if(pts[2]->degenerated)
+        else if(pts[2]->degenerated == 1)
           fprintf(f, "SQ(%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%g,%g,%g,%g};\n",
                   pts[0]->u, pts[0]->v, 0.0, pts[1]->u, pts[1]->v, 0.0,
                   pts[1]->u, pts[2]->v, 0.0, pts[0]->u, pts[2]->v, 0.0,
                   (double)pts[0]->iD, (double)pts[1]->iD, (double)pts[2]->iD,
                   (double)pts[2]->iD);
+        else if(pts[0]->degenerated == 2)
+          fprintf(f, "SQ(%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%g,%g,%g,%g};\n",
+                  pts[1]->u, pts[1]->v, 0.0, pts[2]->u, pts[2]->v, 0.0,
+                  pts[0]->u, pts[2]->v, 0.0, pts[0]->u, pts[1]->v, 0.0,
+                  (double)pts[1]->iD, (double)pts[2]->iD, (double)pts[0]->iD,
+                  (double)pts[0]->iD);
+        else if(pts[1]->degenerated == 2)
+          fprintf(f, "SQ(%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%g,%g,%g,%g};\n",
+                  pts[2]->u, pts[2]->v, 0.0, pts[0]->u, pts[0]->v, 0.0,
+                  pts[1]->u, pts[0]->v, 0.0, pts[1]->u, pts[2]->v, 0.0,
+                  (double)pts[2]->iD, (double)pts[0]->iD, (double)pts[1]->iD,
+                  (double)pts[1]->iD);
+        else if(pts[2]->degenerated == 2)
+          fprintf(f, "SQ(%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%g,%g,%g,%g};\n",
+                  pts[0]->u, pts[0]->v, 0.0, pts[1]->u, pts[1]->v, 0.0,
+                  pts[2]->u, pts[1]->v, 0.0, pts[2]->u, pts[0]->v, 0.0,
+                  (double)pts[0]->iD, (double)pts[1]->iD, (double)pts[2]->iD,
+                  (double)pts[2]->iD);
         else {
           fprintf(f,
                   "ST(%22.15E,%22.15E,%22.15E,%22.15E,%22.15E,%22.15E,%22.15E,%"
@@ -179,20 +207,34 @@ static double surface_triangle_param(BDS_Point *p1, BDS_Point *p2,
   }
 
   double c;
-  if(p1->degenerated + p2->degenerated + p3->degenerated > 1)
+  if((p1->degenerated ? 1 : 0) + (p2->degenerated ? 1 : 0) +
+       (p3->degenerated ? 1 : 0) >
+     1)
     c = 0; // vector_triangle_parametric(p1, p2, p3, c);
-  else if(p1->degenerated) {
+  else if(p1->degenerated == 1) {
     double du = fabs(p3->u - p2->u);
     c = 2 * fabs(0.5 * (p3->v + p2->v) - p1->v) * du;
   }
-  else if(p2->degenerated) {
+  else if(p2->degenerated == 1) {
     double du = fabs(p3->u - p1->u);
     c = 2 * fabs(0.5 * (p3->v + p1->v) - p2->v) * du;
   }
-  else if(p3->degenerated) {
+  else if(p3->degenerated == 1) {
     double du = fabs(p2->u - p1->u);
     c = 2 * fabs(0.5 * (p2->v + p1->v) - p3->v) * du;
   }
+  else if(p1->degenerated == 2) {
+    double dv = fabs(p3->v - p2->v);
+    c = 2 * fabs(0.5 * (p3->u + p2->u) - p1->u) * dv;
+  }
+  else if(p2->degenerated == 2) {
+    double dv = fabs(p3->v - p1->v);
+    c = 2 * fabs(0.5 * (p3->u + p1->u) - p2->u) * dv;
+  }
+  else if(p3->degenerated == 2) {
+    double dv = fabs(p2->v - p1->v);
+    c = 2 * fabs(0.5 * (p2->u + p1->u) - p3->u) * dv;
+  }
   else
     c = vector_triangle_parametric(p1, p2, p3);
   return (0.5 * c);
@@ -684,7 +726,7 @@ BDS_Mesh::~BDS_Mesh()
   DESTROOOY(triangles.begin(), triangles.end());
 }
 
-bool BDS_Mesh::split_edge(BDS_Edge *e, BDS_Point *mid)
+bool BDS_Mesh::split_edge(BDS_Edge *e, BDS_Point *mid, bool check_area_param)
 {
   /*
         p1
@@ -708,26 +750,38 @@ bool BDS_Mesh::split_edge(BDS_Edge *e, BDS_Point *mid)
   e->oppositeof(op);
   if(!op[0] || !op[1]) return false;
 
-  int CHECK1 = -1, CHECK2 = 46;
+  const int CHECK1 = -1, CHECK2 = -1;
 
   if(p1->iD == CHECK1 && p2->iD == CHECK2)
     printf("splitting edge %d %d opp %d %d new %d\n", p1->iD, p2->iD, op[0]->iD,
            op[1]->iD, mid->iD);
-
-  double ori0 = fabs(surface_triangle_param(p2, p1, op[0])) +
-                fabs(surface_triangle_param(p2, p1, op[1]));
-  double ori1 = fabs(surface_triangle_param(mid, p1, op[1]));
-  double ori2 = fabs(surface_triangle_param(mid, op[1], p2));
-  double ori3 = fabs(surface_triangle_param(mid, p2, op[0]));
-  double ori4 = fabs(surface_triangle_param(mid, op[0], p1));
-
-  double eps = 1.e-2;
-  if(ori1 < eps * ori0 || ori2 < eps * ori0 || ori3 < eps * ori0 ||
-     ori4 < eps * ori0) {
-    // printf("%g %g %g %g %g\n",ori0,ori1,ori2,ori3,ori4);
-    // return false;
+  if(check_area_param) {
+    double area0 = fabs(surface_triangle_param(p2, p1, op[0])) +
+      fabs(surface_triangle_param(p2, p1, op[1]));
+    double area1 = fabs(surface_triangle_param(mid, p1, op[1])) +
+      fabs(surface_triangle_param(mid, op[1], p2)) +
+      fabs(surface_triangle_param(mid, p2, op[0])) +
+      fabs(surface_triangle_param(mid, op[0], p1));
+    // heuristic - abort if area changed too much
+    if(area1 > 1.1 * area0 || area1 < 0.9 * area0){
+      return false;
+    }
   }
 
+  /*
+  double ori1 = fabs(vector_triangle_parametric(mid, p1, op[1]));
+  double ori2 = fabs(vector_triangle_parametric(mid, op[1], p2));
+  double ori3 = fabs(vector_triangle_parametric(mid, p2, op[0]));
+  double ori4 = fabs(vector_triangle_parametric(mid, op[0], p1));
+
+  //
+  double eps = 1.e-8;
+  printf("%g %g %g %g %g\n",ori0,ori1,ori2,ori3,ori4);
+  if(ori1 < eps  || ori2 < eps  || ori3 < eps  ||
+     ori4 < eps ) {
+    return false;
+  }
+  */
   if(p1->iD == CHECK1 && p2->iD == CHECK2)
     printf("%d %d %d %d\n", p1->iD, p2->iD, op[0]->iD, op[1]->iD);
 
@@ -1189,6 +1243,13 @@ bool BDS_Mesh::collapse_edge_parametric(BDS_Edge *e, BDS_Point *p, bool force)
     if(e->g->classif_degree == 2 && p->g != e->g) return false;
   }
 
+  const int CHECK1 = -1, CHECK2 = -1;
+
+  if(e->p1->iD == CHECK1 && e->p2->iD == CHECK2) {
+    printf("collapsing edge %p %p onto %p\n", e->p1, e->p2, p);
+    printf("collapsing edge %d %d onto %d\n", e->p1->iD, e->p2->iD, p->iD);
+  }
+
   if(!force) {
     for(size_t i = 0; i < e->p1->edges.size(); i++) {
       for(size_t j = 0; j < e->p2->edges.size(); j++) {
@@ -1270,7 +1331,8 @@ bool BDS_Mesh::collapse_edge_parametric(BDS_Edge *e, BDS_Point *p, bool force)
   // if(!force && nt == 2) return false;
 
   if(!force && fabs(area_old - area_new) > 1.e-12 * (area_old + area_new)) {
-    // printf("%g %g\n", fabs(area_old - area_new), 1.e-12 * (area_old + area_new));
+    // printf("%g %g\n", fabs(area_old - area_new), 1.e-12 * (area_old +
+    // area_new));
     return false;
   }
   {
@@ -1324,14 +1386,18 @@ static inline bool validityOfCavity(const BDS_Point *p,
                                     const std::vector<BDS_Point *> &nbg)
 {
   double p_[2] = {p->u, p->v};
-  double q_[2] = {nbg[0]->degenerated ? nbg[1]->u : nbg[0]->u, nbg[0]->v};
-  double r_[2] = {nbg[1]->degenerated ? nbg[0]->u : nbg[1]->u, nbg[1]->v};
+  double q_[2] = {nbg[0]->degenerated == 1 ? nbg[1]->u : nbg[0]->u,
+                  nbg[0]->degenerated == 2 ? nbg[1]->v : nbg[0]->v};
+  double r_[2] = {nbg[1]->degenerated == 1 ? nbg[0]->u : nbg[1]->u,
+                  nbg[1]->degenerated == 2 ? nbg[0]->v : nbg[1]->v};
   double sign = robustPredicates::orient2d(p_, q_, r_);
   for(size_t i = 1; i < nbg.size(); ++i) {
     BDS_Point *p0 = nbg[i];
     BDS_Point *p1 = nbg[(i + 1) % nbg.size()];
-    double qq_[2] = {p0->degenerated ? p1->u : p0->u, p0->v};
-    double rr_[2] = {p1->degenerated ? p0->u : p1->u, p1->v};
+    double qq_[2] = {p0->degenerated == 1 ? p1->u : p0->u,
+                     p0->degenerated == 2 ? p1->v : p0->v};
+    double rr_[2] = {p1->degenerated == 1 ? p0->u : p1->u,
+                     p1->degenerated == 2 ? p0->v : p1->v};
     double sign_ = robustPredicates::orient2d(p_, qq_, rr_);
     if(sign * sign_ <= 0) return false;
   }
@@ -1344,10 +1410,15 @@ static inline bool getOrderedNeighboringVertices(BDS_Point *p,
                                                  int CHECK)
 {
   if(p->iD == CHECK) {
+    printf("LISTING THE TRIANGLES\n");
     for(size_t i = 0; i < ts.size(); i++) {
       BDS_Point *pts[4];
       ts[i]->getNodes(pts);
-      //      printf("TR %d : %d %d %d\n",i,pts[0]->iD,pts[1]->iD,pts[2]->iD);
+      printf("TR %lu : %p %p %p\n", i, pts[0], pts[1], pts[2]);
+      printf("TR %lu : %d %d - %d %d - %d %d\n", i, ts[i]->e1->p1->iD,
+             ts[i]->e1->p2->iD, ts[i]->e2->p1->iD, ts[i]->e2->p2->iD,
+             ts[i]->e3->p1->iD, ts[i]->e3->p2->iD);
+      //     printf("TR %d : %d %d %d\n",i,pts[0]->iD,pts[1]->iD,pts[2]->iD);
     }
   }
 
@@ -1410,6 +1481,7 @@ static inline double getTutteEnergy(const BDS_Point *p,
 {
   double E = 0;
   double MAX, MIN;
+  if(nbg.empty()) return 1.e22;
   for(size_t i = 0; i < nbg.size(); ++i) {
     const double dx = p->X - nbg[i]->X;
     const double dy = p->Y - nbg[i]->Y;
@@ -1494,19 +1566,32 @@ static inline void computeSomeKindOfKernel(const BDS_Point *p,
   kernel.clear();
   lc.clear();
   for(size_t i = 0; i < nbg.size(); i++) {
-    if(nbg[i]->degenerated) {
+    if(nbg[i]->degenerated == 1) {
       kernel.push_back(SPoint2(p->u, nbg[i]->v));
       kernel.push_back(SPoint2(nbg[(i + 1) % nbg.size()]->u, nbg[i]->v));
 
       lc.push_back(nbg[i]->lc());
       lc.push_back(nbg[i]->lc());
     }
-    else if(nbg[(i + 1) % nbg.size()]->degenerated) {
+    else if(nbg[i]->degenerated == 2) {
+      kernel.push_back(SPoint2(nbg[i]->u, p->v));
+      kernel.push_back(SPoint2(nbg[i]->u, nbg[(i + 1) % nbg.size()]->v));
+
+      lc.push_back(nbg[i]->lc());
+      lc.push_back(nbg[i]->lc());
+    }
+    else if(nbg[(i + 1) % nbg.size()]->degenerated == 1) {
       kernel.push_back(SPoint2(nbg[i]->u, nbg[i]->v));
       kernel.push_back(SPoint2(nbg[i]->u, nbg[(i + 1) % nbg.size()]->v));
       lc.push_back(nbg[i]->lc());
       lc.push_back(nbg[i]->lc());
     }
+    else if(nbg[(i + 1) % nbg.size()]->degenerated == 2) {
+      kernel.push_back(SPoint2(nbg[i]->u, nbg[i]->v));
+      kernel.push_back(SPoint2(nbg[(i + 1) % nbg.size()]->u, nbg[i]->v));
+      lc.push_back(nbg[i]->lc());
+      lc.push_back(nbg[i]->lc());
+    }
     else {
       kernel.push_back(SPoint2(nbg[i]->u, nbg[i]->v));
       lc.push_back(nbg[i]->lc());
@@ -1664,6 +1749,7 @@ static inline bool minimizeTutteEnergyProj(BDS_Point *p, double E_unmoved,
   p->Z = oldZ;
   p->u = oldU;
   p->v = oldV;
+  if(p->iD == check) printf("NO WAY\n");
   return false;
 }
 
@@ -1679,6 +1765,7 @@ static inline bool minimizeTutteEnergyParam(BDS_Point *p, double E_unmoved,
   double RATIO2;
   getCentroidUV(p, gf, kernel, lc, U, V, LC);
   GPoint gp = gf->point(U, V);
+  if(!gp.succeeded()) return false;
   p->X = gp.x();
   p->Y = gp.y();
   p->Z = gp.z();
@@ -1717,13 +1804,21 @@ bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, double threshold)
 
   int CHECK = -1;
 
+  if(p->iD == CHECK)
+    printf("VERTEX %d TRYING TO MOVE from its initial position %g %g\n", CHECK,
+           p->u, p->v);
+
   std::vector<BDS_Point *> nbg;
   std::vector<double> lc;
   std::vector<SPoint2> kernel;
   std::vector<BDS_Face *> ts = p->getTriangles();
 
+  if(p->iD == CHECK) printf("%d adjacent triangles\n", (int)ts.size());
+
   if(!getOrderedNeighboringVertices(p, nbg, ts, CHECK)) return false;
 
+  if(p->iD == CHECK) printf("%d adjacent vertices\n", (int)nbg.size());
+
   double RATIO;
   double E_unmoved = getTutteEnergy(p, nbg, RATIO);
   if(RATIO > threshold) return false;
@@ -1734,19 +1829,16 @@ bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, double threshold)
                                CHECK)) {
     if(!minimizeTutteEnergyProj(p, E_unmoved, RATIO, nbg, kernel, lc, gf,
                                 CHECK)) {
-      //      __COUNT3++;
       return false;
     }
     else {
       p->config_modified = true;
       E_unmoved = getTutteEnergy(p, nbg, RATIO);
       minimizeTutteEnergyProj(p, E_unmoved, RATIO, nbg, kernel, lc, gf, CHECK);
-      //      __COUNT2++;
     }
   }
   else {
     p->config_modified = true;
-    //    __COUNT1++;
   }
 
   return true;
