@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "GModel.h"
 #include "MLine.h"
@@ -13,6 +13,7 @@
 #include "meshGFace.h"
 #include "GmshMessage.h"
 #include "Field.h"
+#include "Context.h"
 
 #if defined(HAVE_POST)
 #include "PView.h"
@@ -48,7 +49,7 @@ static void addExtrudeNormals(std::vector<T *> &elements, int invert,
 
   if(octree && !gouraud) { // get extrusion direction from post-processing view
     std::set<MVertex *> verts;
-    for(unsigned int i = 0; i < elements.size(); i++) {
+    for(std::size_t i = 0; i < elements.size(); i++) {
       if(!ExtrudeParams::calcLayerScaleFactor[index]) {
         for(std::size_t j = 0; j < elements[i]->getNumVertices(); j++)
           verts.insert(elements[i]->getVertex(j));
@@ -59,7 +60,7 @@ static void addExtrudeNormals(std::vector<T *> &elements, int invert,
 
         double aveLength = skipScaleCalc ? 1.0 : GetAveEdgeLength(elem_verts);
 
-        for(unsigned int j = 0; j < elem_verts.size(); j++) {
+        for(std::size_t j = 0; j < elem_verts.size(); j++) {
           verts.insert(elem_verts[j]);
           // if scaleLastLayer selection, but not doing gouraud, then still
           // scale the last layer...  This might create weird behavior for the
@@ -82,7 +83,7 @@ static void addExtrudeNormals(std::vector<T *> &elements, int invert,
     }
   }
   else { // get extrusion direction from Gouraud-shaded element normals
-    for(unsigned int i = 0; i < elements.size(); i++) {
+    for(std::size_t i = 0; i < elements.size(); i++) {
       MElement *ele = elements[i];
       SVector3 n(0, 0, 0);
       if(ele->getDim() == 2)
@@ -105,7 +106,7 @@ static void addExtrudeNormals(std::vector<T *> &elements, int invert,
           aveLength = 1.0;
         else
           aveLength = GetAveEdgeLength(elem_verts);
-        for(unsigned int j = 0; j < elem_verts.size(); j++) {
+        for(std::size_t j = 0; j < elem_verts.size(); j++) {
           ExtrudeParams::normals[index]->add(
             elem_verts[j]->x(), elem_verts[j]->y(), elem_verts[j]->z(), 3, nn);
           if(aveLength != 0.0)
@@ -182,7 +183,7 @@ static void addExtrudeNormals(std::set<T *> &entities,
   }
 
   // enforce coherent normals at some points if necessary
-  for(unsigned int i = 0; i < ExtrudeParams::normalsCoherence.size(); i++) {
+  for(std::size_t i = 0; i < ExtrudeParams::normalsCoherence.size(); i++) {
     SPoint3 &p(ExtrudeParams::normalsCoherence[i]);
     double n0[3], n1[3];
     ExtrudeParams::normals[0]->get(p.x(), p.y(), p.z(), 3, n0);
@@ -225,7 +226,7 @@ static void addExtrudeNormals(std::set<T *> &entities,
       if(octrees.size()) { // scale normals by scalar views
         for(smooth_data::iter it = ExtrudeParams::normals[i]->begin();
             it != ExtrudeParams::normals[i]->end(); it++) {
-          for(unsigned int j = 0; j < octrees.size(); j++) {
+          for(std::size_t j = 0; j < octrees.size(); j++) {
             double d;
             if(octrees[j]->searchScalarWithTol(it->x, it->y, it->z, &d, 0)) {
               for(int k = 0; k < 3; k++) it->vals[k] *= d;
@@ -238,7 +239,7 @@ static void addExtrudeNormals(std::set<T *> &entities,
     }
   }
 
-  for(unsigned int i = 0; i < octrees.size(); i++) delete octrees[i];
+  for(std::size_t i = 0; i < octrees.size(); i++) delete octrees[i];
 }
 
 static void checkDepends(GModel *m, GFace *f, std::set<GFace *> &dep)
@@ -260,7 +261,7 @@ FixErasedExtrScaleFlags(GModel *m, std::map<int, bool> &faceSkipScaleCalc,
                         std::map<int, bool> &edgeSkipScaleCalc)
 {
   unsigned int num_changed = 0;
-  std::set<GRegion *, GEntityLessThan>::iterator itreg;
+  std::set<GRegion *, GEntityPtrLessThan>::iterator itreg;
   // fix all extruded faces bordering ScaleLast regions
   for(itreg = m->firstRegion(); itreg != m->lastRegion(); itreg++) {
     ExtrudeParams *r_ep = (*itreg)->meshAttributes.extrude;
@@ -431,14 +432,22 @@ int Mesh2DWithBoundaryLayers(GModel *m)
       otherFaces.insert(*it);
 
   // mesh source surfaces (and dependencies)
-  for(int i = 0; i < 10; i++) { // FIXME: should check PENDING status instead!
+  int nIter = 0;
+  while(1) {
+    int nPending = 0;
     for(std::set<GFace *>::iterator it = sourceFacesDependencies.begin();
-        it != sourceFacesDependencies.end(); it++)
-      (*it)->mesh(false);
+        it != sourceFacesDependencies.end(); it++) {
+      if((*it)->meshStatistics.status == GFace::PENDING) {
+        (*it)->mesh(true);
+        nPending++;
+      }
+    }
+    if(!nPending) break;
+    if(nIter++ > CTX::instance()->mesh.maxRetries) break;
   }
   for(std::set<GFace *>::iterator it = sourceFaces.begin();
       it != sourceFaces.end(); it++)
-    (*it)->mesh(false);
+    (*it)->mesh(true);
 
   // make sure the source surfaces for the boundary layers are oriented
   // correctly (normally we do this only after the 3D mesh is done; but here
@@ -462,7 +471,8 @@ int Mesh2DWithBoundaryLayers(GModel *m)
       ExtrudeParams *ep = ge->meshAttributes.extrude;
       if(ep && ep->mesh.ExtrudeMesh && ep->geo.Mode == EXTRUDED_ENTITY) {
         GVertex *vsrc, *vdest;
-        if(ge->getBeginVertex()->geomType() == GEntity::BoundaryLayerPoint) {
+        if(ge->getBeginVertex() &&
+           ge->getBeginVertex()->geomType() == GEntity::BoundaryLayerPoint) {
           vsrc = ge->getEndVertex();
           vdest = ge->getBeginVertex();
         }
@@ -470,12 +480,13 @@ int Mesh2DWithBoundaryLayers(GModel *m)
           vsrc = ge->getBeginVertex();
           vdest = ge->getEndVertex();
         }
-        GPoint p = vsrc->point();
-
-        ep->Extrude(ep->mesh.NbLayer - 1,
-                    ep->mesh.NbElmLayer[ep->mesh.NbLayer - 1], p.x(), p.y(),
-                    p.z());
-        vdest->setPosition(p);
+        if(vsrc && vdest){
+          GPoint p = vsrc->point();
+          ep->Extrude(ep->mesh.NbLayer - 1,
+                      ep->mesh.NbElmLayer[ep->mesh.NbLayer - 1], p.x(), p.y(),
+                      p.z());
+          vdest->setPosition(p);
+        }
       }
     }
   }
@@ -485,7 +496,7 @@ int Mesh2DWithBoundaryLayers(GModel *m)
   std::for_each(otherFaces.begin(), otherFaces.end(), deMeshGFace());
   for(std::set<GEdge *>::iterator it = otherEdges.begin();
       it != otherEdges.end(); it++)
-    (*it)->mesh(false);
+    (*it)->mesh(true);
 
   // mesh the curves bounding the boundary layers by extrusion using the smooth
   // normal field
@@ -509,7 +520,7 @@ int Mesh2DWithBoundaryLayers(GModel *m)
   // mesh non-source surfaces
   for(std::set<GFace *>::iterator it = otherFaces.begin();
       it != otherFaces.end(); it++)
-    (*it)->mesh(false);
+    (*it)->mesh(true);
 
   // mesh the surfaces bounding the boundary layers by extrusion using the
   // smooth normal field
