@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _FIELD_H_
-#define _FIELD_H_
+#ifndef FIELD_H
+#define FIELD_H
 
 #include <string>
 #include <map>
@@ -69,13 +69,13 @@ public:
   std::string getTypeName()
   {
     switch(getType()) {
-    case FIELD_OPTION_INT: return "integer"; break;
-    case FIELD_OPTION_DOUBLE: return "float"; break;
-    case FIELD_OPTION_BOOL: return "boolean"; break;
-    case FIELD_OPTION_PATH: return "path"; break;
-    case FIELD_OPTION_STRING: return "string"; break;
-    case FIELD_OPTION_LIST: return "list"; break;
-    case FIELD_OPTION_LIST_DOUBLE: return "list_double"; break;
+    case FIELD_OPTION_INT: return "integer";
+    case FIELD_OPTION_DOUBLE: return "float";
+    case FIELD_OPTION_BOOL: return "boolean";
+    case FIELD_OPTION_PATH: return "path";
+    case FIELD_OPTION_STRING: return "string";
+    case FIELD_OPTION_LIST: return "list";
+    case FIELD_OPTION_LIST_DOUBLE: return "list_double";
     default: return "unknown";
     }
   }
@@ -118,7 +118,7 @@ public:
 #if defined(HAVE_POST)
   void putOnView(PView *view, int comp = -1);
 #endif
-  void putOnNewView();
+  void putOnNewView(int viewTag = -1);
   virtual std::string getDescription() { return ""; }
   FieldOption *getOption(const std::string &optionName);
 };
@@ -152,14 +152,14 @@ public:
   inline void setBackgroundFieldId(int id) { _background_field = id; };
   inline void addBoundaryLayerFieldId(int id)
   {
-    for(unsigned int i = 0; i < _boundaryLayer_fields.size(); ++i) {
+    for(std::size_t i = 0; i < _boundaryLayer_fields.size(); ++i) {
       if(_boundaryLayer_fields[i] == id) return;
     }
     _boundaryLayer_fields.push_back(id);
   }
   inline void addBoundaryLayerFieldId(std::vector<int> &tags)
   {
-    for(unsigned int i = 0; i < tags.size(); ++i)
+    for(std::size_t i = 0; i < tags.size(); ++i)
       addBoundaryLayerFieldId(tags[i]);
   }
   inline int getBackgroundField() { return _background_field; }
@@ -181,6 +181,7 @@ private:
   std::list<double> hwall_n_nodes;
   std::list<int> nodes_id, edges_id;
   std::list<int> edges_id_saved, nodes_id_saved, fan_nodes_id;
+  std::list<int> excluded_faces_id;
   void operator()(DistanceField *cc, double dist, double x, double y, double z,
                   SMetric3 &metr, GEntity *ge);
 
