@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _FIELD_PYTHON_H_
-#define _FIELD_PYTHON_H_
+#ifndef FIELD_PYTHON_H
+#define FIELD_PYTHON_H
 
 #include "Field.h"
 #include "Python.h"
