@@ -283,6 +283,7 @@ public:
   }
   aBunchOfStuff(std::size_t s) : _current(0), _nbAlloc(s)
   {
+    if(!_nbAlloc) _nbAlloc = 1;
     _all.push_back(new T[_nbAlloc]);
   }
   ~aBunchOfStuff()
@@ -479,7 +480,7 @@ int HilbertSortB::Split(Vert **vertices, int arraysize, int GrayCode0,
         if(vertices[j]->point()[axis] < split) break;
       }
       // Is the partition finished?
-      if(i == (j + 1)) break;
+      if(i >= (j + 1)) break;
       // Swap i-th and j-th vertices.
       swapvert = vertices[i];
       vertices[i] = vertices[j];
@@ -496,7 +497,7 @@ int HilbertSortB::Split(Vert **vertices, int arraysize, int GrayCode0,
         if(vertices[j]->point()[axis] > split) break;
       }
       // Is the partition finished?
-      if(i == (j + 1)) break;
+      if(i >= (j + 1)) break;
       // Swap i-th and j-th vertices.
       swapvert = vertices[i];
       vertices[i] = vertices[j];
