@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _MESH_GFACE_DELAUNAY_INSERTIONFACE_H_
-#define _MESH_GFACE_DELAUNAY_INSERTIONFACE_H_
+#ifndef MESH_GFACE_DELAUNAY_INSERTIONFACE_H
+#define MESH_GFACE_DELAUNAY_INSERTIONFACE_H
 
 #include "MTriangle.h"
 #include "MQuadrangle.h"
@@ -26,7 +26,7 @@ struct bidimMeshData {
   std::vector<SMetric3> vMetricsBGM;
   std::map<MVertex *, MVertex *> *equivalence;
   std::map<MVertex *, SPoint2> *parametricCoordinates;
-  std::set<MEdge, Less_Edge> internalEdges; // embedded edges
+  std::set<MEdge, MEdgeLessThan> internalEdges; // embedded edges
   //  std::set<MVertex*> internalVertices; // embedded vertices
   inline void addVertex(MVertex *mv, double u, double v, double size,
                         double sizeBGM)
@@ -133,7 +133,7 @@ public:
 };
 
 class compareTri3Ptr {
-  Less_Face lf;
+  MFaceLessThan lf;
 
 public:
   inline bool operator()(const MTri3 *a, const MTri3 *b) const
@@ -164,8 +164,9 @@ void bowyerWatsonParallelogramsConstrained(
   GFace *gf, const std::set<MVertex *> &constr_vertices,
   std::map<MVertex *, MVertex *> *equivalence = 0,
   std::map<MVertex *, SPoint2> *parametricCoordinates = 0);
-void buildCrossField(
-  GFace *gf, std::map<MVertex *, MVertex *> *equivalence = 0,
+void buildBackgroundMesh(
+  GFace *gf, bool crossFieldClosestPoint = false,
+  std::map<MVertex *, MVertex *> *equivalence = 0,
   std::map<MVertex *, SPoint2> *parametricCoordinates = 0);
 
 void delaunayMeshIn2D(std::vector<MVertex *> &, std::vector<MTriangle *> &,
