@@ -86,8 +86,17 @@ static void computeEdgeLoops(const GFace *gf,
                              std::vector<MVertex *> &all_mvertices,
                              std::vector<int> &indices)
 {
-  std::vector<GEdge *> const &edges = gf->edges();
-  std::vector<int> const &ori = gf->orientations();
+  std::vector<GEdge *> const &e = gf->edges();
+  std::vector<int> const &o = gf->orientations();
+  std::vector<GEdge *> edges;
+  std::vector<int> ori;
+  for(std::size_t i = 0; i < e.size(); i++){
+    if(!e[i]->degenerate(0)){ // skip degenerate curves
+      edges.push_back(e[i]);
+      ori.push_back(i < o.size() ? o[i] : 1);
+    }
+  }
+
   std::vector<GEdge *>::const_iterator it = edges.begin();
   std::vector<int>::const_iterator ito = ori.begin();
 
@@ -142,7 +151,7 @@ int MeshTransfiniteSurface(GFace *gf)
 {
   if(gf->meshAttributes.method != MESH_TRANSFINITE) return 0;
 
-  Msg::Info("Meshing surface %d (transfinite)", gf->tag());
+  Msg::Info("Meshing surface %d (Transfinite)", gf->tag());
 
   // make sure that all bounding edges have begin/end points: everything in here
   // depends on it
@@ -159,8 +168,8 @@ int MeshTransfiniteSurface(GFace *gf)
   std::vector<MVertex *> corners;
   findTransfiniteCorners(gf, corners);
   if(corners.size() != 3 && corners.size() != 4) {
-    Msg::Error("Surface %d is transfinite but has %d corners", gf->tag(),
-               corners.size());
+    Msg::Error("Surface %d is transfinite but has %d corner%s", gf->tag(),
+               corners.size(), corners.size() > 1 ? "s" : "");
     return 0;
   }
 
@@ -169,8 +178,9 @@ int MeshTransfiniteSurface(GFace *gf)
   computeEdgeLoops(gf, d_vertices, indices);
 
   if(indices.size() != 2) {
-    Msg::Error("Surface %d is transfinite but has %d holes", gf->tag(),
-               indices.size() - 2);
+    int nh = indices.size() - 2;
+    Msg::Error("Surface %d is transfinite but has %d hole%s", gf->tag(),
+               nh, nh > 1 ? "s" : "");
     return 0;
   }
 
@@ -243,6 +253,7 @@ int MeshTransfiniteSurface(GFace *gf)
     }
   }
 
+
   std::vector<double> lengths_i;
   lengths_i.reserve(L);
 
@@ -390,6 +401,7 @@ int MeshTransfiniteSurface(GFace *gf)
     numSmooth = gf->meshAttributes.transfiniteSmoothing;
 
   if(corners.size() == 4 && numSmooth) {
+    printf("AAAAAAAAAa\n");
     std::vector<std::vector<double> > u(L + 1), v(L + 1);
     for(int i = 0; i <= L; i++) {
       u[i].resize(H + 1);
