@@ -65,7 +65,7 @@ public:
   GRegion *_gr;
   GFace *_f[2];
   double max_angle, min_angle;
-  int _N_SUBNORMALS;
+  std::size_t N_SUBNORMALS;
 
   void computeType(double angle)
   {
@@ -82,7 +82,7 @@ public:
   type getType() const { return _t; }
 
   blyr_ridge(GEdge *ge, GRegion *gr, GFace *f0, GFace *f1)
-    : _ge(ge), _gr(gr), _N_SUBNORMALS(0)
+    : _ge(ge), _gr(gr), N_SUBNORMALS(0)
   {
     _f[0] = f0;
     _f[1] = f1;
@@ -189,11 +189,11 @@ public:
   blyr_manager(GRegion *gr, std::vector<GFace *> &bls, double t)
     : _thickness(t), _gr(gr), _faces(bls)
   {
-    std::map<MFace, SVector3, Less_Face> t_normals;
+    std::map<MFace, SVector3, MFaceLessThan> t_normals;
     for(size_t i = 0; i < _gr->tetrahedra.size(); i++) {
       for(int j = 0; j < 4; j++) {
         MFace f = _gr->tetrahedra[i]->getFace(j);
-        std::map<MFace, SVector3, Less_Face>::iterator it = t_normals.find(f);
+        std::map<MFace, SVector3, MFaceLessThan>::iterator it = t_normals.find(f);
         if(it == t_normals.end()) {
           SVector3 n = f.normal();
           MVertex *v = _gr->tetrahedra[i]->getVertex(3 - j);
@@ -260,7 +260,7 @@ public:
     for(size_t i = 0; i < bls.size(); i++) {
       for(size_t j = 0; j < bls[i]->triangles.size(); j++) {
         MTriangle *t = bls[i]->triangles[j];
-        std::map<MFace, SVector3, Less_Face>::iterator it =
+        std::map<MFace, SVector3, MFaceLessThan>::iterator it =
           t_normals.find(t->getFace(0));
         SVector3 n;
         if(it == t_normals.end())
@@ -298,7 +298,7 @@ public:
         MLine *l = ge->lines[j];
         MVertex *l0 = l->getVertex(0);
         MVertex *l1 = l->getVertex(1);
-        MVertex *op0, *op1;
+        MVertex *op1 = 0;
         SVector3 N[2];
         std::set<blyr_mvertex>::iterator it = _vertices.find(l->getVertex(0));
         for(size_t k = 0; k < it->_triangles.size(); k++) {
@@ -309,7 +309,6 @@ public:
           if((v0 == l0 && v1 == l1) || (v0 == l1 && v1 == l0)) {
             if(gf == f0) {
               N[0] = it->_normals[k];
-              op0 = v2;
             }
             if(gf == f1) {
               N[1] = it->_normals[k];
@@ -319,7 +318,6 @@ public:
           if((v0 == l0 && v2 == l1) || (v0 == l1 && v2 == l0)) {
             if(gf == f0) {
               N[0] = it->_normals[k];
-              op0 = v1;
             }
             if(gf == f1) {
               N[1] = it->_normals[k];
@@ -329,7 +327,6 @@ public:
           if((v1 == l0 && v2 == l1) || (v1 == l1 && v2 == l0)) {
             if(gf == f0) {
               N[0] = it->_normals[k];
-              op0 = v0;
             }
             if(gf == f1) {
               N[1] = it->_normals[k];
@@ -338,29 +335,29 @@ public:
           }
         }
         double alpha = angle(N[0], N[1]);
-        //	printf("%g %g %g vs %g %g %g\n",N[0].x(),N[0].y(),N[0].z(),
-        //	       N[1].x(),N[1].y(),N[1].z());
-        SVector3 dir(0.5 * (l0->x() + l1->x()) - op1->x(),
-                     0.5 * (l0->y() + l1->y()) - op1->y(),
-                     0.5 * (l0->z() + l1->z()) - op1->z());
-        dir.normalize();
-        // sign < 0 ---> re-intrant corner
-        double sign = dot(dir, N[0]);
+        if(op1){
+          SVector3 dir(0.5 * (l0->x() + l1->x()) - op1->x(),
+                       0.5 * (l0->y() + l1->y()) - op1->y(),
+                       0.5 * (l0->z() + l1->z()) - op1->z());
+          dir.normalize();
+          // sign < 0 ---> re-intrant corner
+          double sign = dot(dir, N[0]);
+          if(sign < 0) alpha = -alpha;
+        }
 
-        if(sign < 0) alpha = -alpha;
         _ridges[i].max_angle = std::max(alpha, _ridges[i].max_angle);
         _ridges[i].min_angle = std::min(alpha, _ridges[i].min_angle);
         _ridges[i].computeType(_threshold_angle);
       }
       // nice "outer" ridge
       if(_ridges[i].min_angle > 0 && _ridges[i].max_angle > 0) {
-        while(_ridges[i].max_angle / (_ridges[i]._N_SUBNORMALS + 1) >
+        while(_ridges[i].max_angle / (_ridges[i].N_SUBNORMALS + 1) >
               _threshold_angle) {
-          _ridges[i]._N_SUBNORMALS++;
+          _ridges[i].N_SUBNORMALS++;
         }
       }
       if(_ridges[i].min_angle < 0 && _ridges[i].max_angle < 0) {
-        _ridges[i]._N_SUBNORMALS = 0;
+        _ridges[i].N_SUBNORMALS = 0;
       }
     }
   }
@@ -400,15 +397,15 @@ public:
               _ridges[k]._f[1] == _unique[j]) ||
              (_ridges[k]._f[1] == _unique[i] &&
               _ridges[k]._f[0] == _unique[j])) {
-            num_subnormals = _ridges[k]._N_SUBNORMALS;
+            num_subnormals = _ridges[k].N_SUBNORMALS;
           }
         }
 
         SVector3 n0 = v._n_per_vertex[i];
         SVector3 n1 = v._n_per_vertex[j];
         std::vector<MVertex *> fan;
-        for(int i = 0; i < num_subnormals; i++) {
-          double u = (double)(i + 1) / (num_subnormals + 1);
+        for(int k = 0; k < num_subnormals; k++) {
+          double u = (double)(k + 1) / (num_subnormals + 1);
           SVector3 n = n0 * (1. - u) + n1 * u;
           n.normalize();
           MVertex *new_v =
@@ -586,7 +583,7 @@ public:
       GPoint p = f->closestPoint(newp, initialGuess);
       vs[i] = new MFaceVertex(p.x(), p.y(), p.z(), f, p.u(), p.v());
       f->mesh_vertices.push_back(vs[i]);
-      ridge->_N_SUBNORMALS = 1;
+      ridge->N_SUBNORMALS = 1;
       v._v_per_face.push_back(vs[i]);
       v._n_per_vertex.push_back(n);
       v._f_per_normal.push_back(f);
@@ -946,11 +943,13 @@ public:
           _externals.empty() || ridge->getType() == blyr_ridge::EXTERNAL;
         if(create_vertices_on_edge) {
           double t = 0.0;
-          if(v == ge->getBeginVertex()->mesh_vertices[0]) {
+          if(ge->getBeginVertex() &&
+             v == ge->getBeginVertex()->mesh_vertices[0]) {
             SVector3 tgt = ge->firstDer(bounds.low());
             t = bounds.low() + thk / tgt.norm();
           }
-          else if(v == ge->getEndVertex()->mesh_vertices[0]) {
+          else if(ge->getEndVertex() &&
+                  v == ge->getEndVertex()->mesh_vertices[0]) {
             SVector3 tgt = ge->firstDer(bounds.high());
             t = bounds.high() - thk / tgt.norm();
           }
@@ -1197,7 +1196,7 @@ public:
 
       //      printf("ridge %d %d\n",f0->tag(),f1->tag());
 
-      if(r._N_SUBNORMALS) {
+      if(r.N_SUBNORMALS) {
         for(size_t j = 0; j < r._ge->lines.size(); j++) {
           MLine *l = r._ge->lines[j];
           MVertex *v0 = l->getVertex(0);
@@ -1239,14 +1238,14 @@ public:
             }
           }
 
-          //	  printf("%d %d %d\n",fan0.size(),fan1.size(),r._N_SUBNORMALS);
-          if(fan0.size() == r._N_SUBNORMALS && fan1.size() == r._N_SUBNORMALS) {
-            for(int k = 0; k <= r._N_SUBNORMALS; k++) {
+          // printf("%d %d %d\n",fan0.size(),fan1.size(),r.N_SUBNORMALS);
+          if(fan0.size() == r.N_SUBNORMALS && fan1.size() == r.N_SUBNORMALS) {
+            for(std::size_t k = 0; k <= r.N_SUBNORMALS; k++) {
               MVertex *v00 = (k == 0 ? o00 : fan0[k - 1]);
               MVertex *v10 = (k == 0 ? o10 : fan1[k - 1]);
-              MVertex *v01 = (k == r._N_SUBNORMALS ? o01 : fan0[k]);
-              MVertex *v11 = (k == r._N_SUBNORMALS ? o11 : fan1[k]);
-              //	      printf("%p %p %p %p\n",v00,v01,v10,v11);
+              MVertex *v01 = (k == r.N_SUBNORMALS ? o01 : fan0[k]);
+              MVertex *v11 = (k == r.N_SUBNORMALS ? o11 : fan1[k]);
+              // printf("%p %p %p %p\n",v00,v01,v10,v11);
               _gr->prisms.push_back(new MPrism(v0, v00, v01, v1, v10, v11));
             }
           }
