@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <set>
 #include "GmshConfig.h"
@@ -34,7 +34,7 @@ void carveHole(std::vector<T *> &elements, double distance, ANNkd_tree *kdtree)
   ANNidxArray index = new ANNidx[1];
   ANNdistArray dist = new ANNdist[1];
   std::vector<T *> temp;
-  for(unsigned int i = 0; i < elements.size(); i++) {
+  for(std::size_t i = 0; i < elements.size(); i++) {
     for(std::size_t j = 0; j < elements[i]->getNumVertices(); j++) {
       MVertex *v = elements[i]->getVertex(j);
       double xyz[3] = {v->x(), v->y(), v->z()};
@@ -55,12 +55,12 @@ void carveHole(std::vector<T *> &elements, double distance, ANNkd_tree *kdtree)
 }
 
 template <class T>
-void addFaces(std::vector<T *> &elements, std::set<MFace, Less_Face> &faces)
+void addFaces(std::vector<T *> &elements, std::set<MFace, MFaceLessThan> &faces)
 {
-  for(unsigned int i = 0; i < elements.size(); i++) {
+  for(std::size_t i = 0; i < elements.size(); i++) {
     for(int j = 0; j < elements[i]->getNumFaces(); j++) {
       MFace f = elements[i]->getFace(j);
-      std::set<MFace, Less_Face>::iterator it = faces.find(f);
+      std::set<MFace, MFaceLessThan>::iterator it = faces.find(f);
       if(it == faces.end())
         faces.insert(f);
       else
@@ -78,7 +78,7 @@ void carveHole(GRegion *gr, int num, double distance,
 
   // add all points from carving surfaces into kdtree
   int numnodes = 0;
-  for(unsigned int i = 0; i < surfaces.size(); i++) {
+  for(std::size_t i = 0; i < surfaces.size(); i++) {
     GFace *gf = m->getFaceByTag(surfaces[i]);
     if(!gf) {
       Msg::Error("Unknown carving surface %d", surfaces[i]);
@@ -89,9 +89,9 @@ void carveHole(GRegion *gr, int num, double distance,
 
   ANNpointArray kdnodes = annAllocPts(numnodes, 3);
   int k = 0;
-  for(unsigned int i = 0; i < surfaces.size(); i++) {
+  for(std::size_t i = 0; i < surfaces.size(); i++) {
     GFace *gf = m->getFaceByTag(surfaces[i]);
-    for(unsigned int j = 0; j < gf->mesh_vertices.size(); j++) {
+    for(std::size_t j = 0; j < gf->mesh_vertices.size(); j++) {
       kdnodes[k][0] = gf->mesh_vertices[j]->x();
       kdnodes[k][1] = gf->mesh_vertices[j]->y();
       kdnodes[k][2] = gf->mesh_vertices[j]->z();
@@ -117,7 +117,7 @@ void carveHole(GRegion *gr, int num, double distance,
   // generate discrete boundary mesh of the carved hole
   GFace *gf = m->getFaceByTag(num);
   if(!gf) return;
-  std::set<MFace, Less_Face> faces;
+  std::set<MFace, MFaceLessThan> faces;
   std::vector<GFace *> f = gr->faces();
   for(std::vector<GFace *>::iterator it = f.begin(); it != f.end(); it++) {
     addFaces((*it)->triangles, faces);
@@ -129,7 +129,7 @@ void carveHole(GRegion *gr, int num, double distance,
   addFaces(gr->pyramids, faces);
 
   std::set<MVertex *> verts;
-  for(std::set<MFace, Less_Face>::iterator it = faces.begin();
+  for(std::set<MFace, MFaceLessThan>::iterator it = faces.begin();
       it != faces.end(); it++) {
     for(std::size_t i = 0; i < it->getNumVertices(); i++) {
       it->getVertex(i)->setEntity(gf);
