@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _MESH_GREGION_DELAUNAY_INSERTION_H_
-#define _MESH_GREGION_DELAUNAY_INSERTION_H_
+#ifndef MESH_GREGION_DELAUNAY_INSERTION_H
+#define MESH_GREGION_DELAUNAY_INSERTION_H
 
 #include <list>
 #include <set>
@@ -16,7 +16,7 @@
 #include "qualityMeasures.h"
 #include "robustPredicates.h"
 
-//#define _GMSH_PRE_ALLOCATE_STRATEGY_ 1
+//#define GMSH_PRE_ALLOCATE_STRATEGY 1
 class GRegion;
 class GFace;
 class GModel;
@@ -215,10 +215,10 @@ public:
   }
 };
 
-void connectTets(std::list<MTet4 *> &, const std::set<MFace, Less_Face> * = 0);
-void connectTets(std::vector<MTet4 *> &, const std::set<MFace, Less_Face> * = 0);
+void connectTets(std::list<MTet4 *> &, const std::set<MFace, MFaceLessThan> * = 0);
+void connectTets(std::vector<MTet4 *> &, const std::set<MFace, MFaceLessThan> * = 0);
 void delaunayMeshIn3D(std::vector<MVertex *> &, std::vector<MTetrahedron *> &);
-void insertVerticesInRegion(GRegion *gr, int maxVert = 2000000000,
+void insertVerticesInRegion(GRegion *gr, int maxIter, double worstTetRadiusTarget,
                             bool _classify = true, splitQuadRecovery *sqr = 0);
 void bowyerWatsonFrontalLayers(GRegion *gr, bool hex);
 
@@ -238,7 +238,7 @@ public:
 
 private:
   container allTets;
-#ifdef _GMSH_PRE_ALLOCATE_STRATEGY_
+#ifdef GMSH_PRE_ALLOCATE_STRATEGY
   MTet4 *allSlots;
   int s_last, s_alloc;
   std::stack<MTet4 *> emptySlots;
@@ -262,7 +262,7 @@ private:
 public:
   MTet4Factory(int _size = 1000000)
   {
-#ifdef _GMSH_PRE_ALLOCATE_STRATEGY_
+#ifdef GMSH_PRE_ALLOCATE_STRATEGY
     s_last = 0;
     s_alloc = _size;
     allSlots = new MTet4[s_alloc];
@@ -270,14 +270,14 @@ public:
   }
   ~MTet4Factory()
   {
-#ifdef _GMSH_PRE_ALLOCATE_STRATEGY_
+#ifdef GMSH_PRE_ALLOCATE_STRATEGY
     delete[] allSlots;
 #endif
   }
   MTet4 *Create(MTetrahedron *t, std::vector<double> &sizes,
                 std::vector<double> &sizesBGM)
   {
-#ifdef _GMSH_PRE_ALLOCATE_STRATEGY_
+#ifdef GMSH_PRE_ALLOCATE_STRATEGY
     MTet4 *t4 = getAnEmptySlot();
 #else
     MTet4 *t4 = new MTet4;
@@ -288,7 +288,7 @@ public:
   MTet4 *Create(MTetrahedron *t, std::vector<double> &sizes,
                 std::vector<double> &sizesBGM, double lc1, double lc2)
   {
-#ifdef _GMSH_PRE_ALLOCATE_STRATEGY_
+#ifdef GMSH_PRE_ALLOCATE_STRATEGY
     MTet4 *t4 = getAnEmptySlot();
 #else
     MTet4 *t4 = new MTet4;
@@ -301,7 +301,7 @@ public:
   {
     if(t->tet()) delete t->tet();
     t->tet() = 0;
-#ifdef _GMSH_PRE_ALLOCATE_STRATEGY_
+#ifdef GMSH_PRE_ALLOCATE_STRATEGY
     emptySlots.push(t);
     t->setDeleted(true);
 #else
