@@ -1,9 +1,11 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <set>
+#include "GmshConfig.h"
+#include "GmshMessage.h"
 #include "GModel.h"
 #include "MTriangle.h"
 #include "MQuadrangle.h"
@@ -15,8 +17,11 @@
 #include "meshGFace.h"
 #include "meshGRegion.h"
 #include "Context.h"
-#include "GmshMessage.h"
+#include "MVertexRTree.h"
+
+#if defined(HAVE_QUADTRI)
 #include "QuadTriExtruded3D.h"
+#endif
 
 static void addTetrahedron(MVertex *v1, MVertex *v2, MVertex *v3, MVertex *v4,
                            GRegion *to)
@@ -162,7 +167,7 @@ static void extrudeMesh(GFace *from, GRegion *to, MVertexRTree &pos)
   mesh_vertices.insert(mesh_vertices.end(), seam.begin(), seam.end());
 
   // create extruded vertices
-  for(unsigned int i = 0; i < mesh_vertices.size(); i++) {
+  for(std::size_t i = 0; i < mesh_vertices.size(); i++) {
     MVertex *v = mesh_vertices[i];
     for(int j = 0; j < ep->mesh.NbLayer; j++) {
       for(int k = 0; k < ep->mesh.NbElmLayer[j]; k++) {
@@ -177,15 +182,17 @@ static void extrudeMesh(GFace *from, GRegion *to, MVertexRTree &pos)
     }
   }
 
+#if defined(HAVE_QUADTRI)
   if(ep && ep->mesh.ExtrudeMesh && ep->mesh.QuadToTri && ep->mesh.Recombine) {
     meshQuadToTriRegion(to, pos);
     return;
   }
+#endif
 
   // create elements (note that it would be faster to access the *interior*
   // nodes by direct indexing, but it's just simpler to query everything by
   // position)
-  for(unsigned int i = 0; i < from->triangles.size(); i++) {
+  for(std::size_t i = 0; i < from->triangles.size(); i++) {
     for(int j = 0; j < ep->mesh.NbLayer; j++) {
       for(int k = 0; k < ep->mesh.NbElmLayer[j]; k++) {
         std::vector<MVertex *> verts;
@@ -200,7 +207,7 @@ static void extrudeMesh(GFace *from, GRegion *to, MVertexRTree &pos)
     Msg::Error("Cannot extrude quadrangles without Recombine");
   }
   else {
-    for(unsigned int i = 0; i < from->quadrangles.size(); i++) {
+    for(std::size_t i = 0; i < from->quadrangles.size(); i++) {
       for(int j = 0; j < ep->mesh.NbLayer; j++) {
         for(int k = 0; k < ep->mesh.NbElmLayer[j]; k++) {
           std::vector<MVertex *> verts;
@@ -226,8 +233,10 @@ static void insertAllVertices(GRegion *gr, MVertexRTree &pos)
     std::vector<GEdge *>::const_iterator ite = edges.begin();
     while(ite != edges.end()) {
       pos.insert((*ite)->mesh_vertices);
-      pos.insert((*ite)->getBeginVertex()->mesh_vertices);
-      pos.insert((*ite)->getEndVertex()->mesh_vertices);
+      if((*ite)->getBeginVertex())
+        pos.insert((*ite)->getBeginVertex()->mesh_vertices);
+      if((*ite)->getEndVertex())
+         pos.insert((*ite)->getEndVertex()->mesh_vertices);
       ++ite;
     }
     ++itf;
@@ -244,7 +253,7 @@ void meshGRegionExtruded::operator()(GRegion *gr)
 
   if(!ep || !ep->mesh.ExtrudeMesh || ep->geo.Mode != EXTRUDED_ENTITY) return;
 
-  Msg::Info("Meshing volume %d (extruded)", gr->tag());
+  Msg::Info("Meshing volume %d (Extruded)", gr->tag());
 
   // destroy the mesh if it exists
   deMeshGRegion dem;
@@ -295,38 +304,40 @@ static void deleteEdge(MVertex *v1, MVertex *v2,
 
 // subdivide the 3 lateral faces of each prism
 static void phase1(GRegion *gr, MVertexRTree &pos,
-                   std::set<std::pair<MVertex *, MVertex *> > &edges)
+                   std::set<std::pair<MVertex *, MVertex *> > &edges,
+                   int ntry)
 {
   ExtrudeParams *ep = gr->meshAttributes.extrude;
   GFace *from = gr->model()->getFaceByTag(std::abs(ep->geo.Source));
   if(!from) return;
 
-  for(unsigned int i = 0; i < from->triangles.size(); i++) {
+  for(std::size_t i = 0; i < from->triangles.size(); i++) {
     for(int j = 0; j < ep->mesh.NbLayer; j++) {
       for(int k = 0; k < ep->mesh.NbElmLayer[j]; k++) {
         std::vector<MVertex *> v;
         if(getExtrudedVertices(from->triangles[i], ep, j, k, pos, v) == 6) {
-#if 0 // old
-          if(!edgeExists(v[0], v[4], edges))
-            createEdge(v[1], v[3], edges);
-          if(!edgeExists(v[4], v[2], edges))
-            createEdge(v[1], v[5], edges);
-          if(!edgeExists(v[3], v[2], edges))
-            createEdge(v[0], v[5], edges);
-#else // new from Michel Benhamou
-          if(v[1] < v[0])
-            createEdge(v[1], v[3], edges);
-          else
-            createEdge(v[0], v[4], edges);
-          if(v[1] < v[2])
-            createEdge(v[1], v[5], edges);
-          else
-            createEdge(v[4], v[2], edges);
-          if(v[0] < v[2])
-            createEdge(v[0], v[5], edges);
-          else
-            createEdge(v[3], v[2], edges);
-#endif
+          if(ntry == 1){
+            if(!edgeExists(v[0], v[4], edges))
+              createEdge(v[1], v[3], edges);
+            if(!edgeExists(v[4], v[2], edges))
+              createEdge(v[1], v[5], edges);
+            if(!edgeExists(v[3], v[2], edges))
+              createEdge(v[0], v[5], edges);
+          }
+          else{ // from Michel Benhamou
+            if(v[1]->getNum() < v[0]->getNum())
+              createEdge(v[1], v[3], edges);
+            else
+              createEdge(v[0], v[4], edges);
+            if(v[1]->getNum() < v[2]->getNum())
+              createEdge(v[1], v[5], edges);
+            else
+              createEdge(v[4], v[2], edges);
+            if(v[0]->getNum() < v[2]->getNum())
+              createEdge(v[0], v[5], edges);
+            else
+              createEdge(v[3], v[2], edges);
+          }
         }
       }
     }
@@ -343,7 +354,7 @@ static void phase2(GRegion *gr, MVertexRTree &pos,
   GFace *from = gr->model()->getFaceByTag(std::abs(ep->geo.Source));
   if(!from) return;
 
-  for(unsigned int i = 0; i < from->triangles.size(); i++) {
+  for(std::size_t i = 0; i < from->triangles.size(); i++) {
     for(int j = 0; j < ep->mesh.NbLayer; j++) {
       for(int k = 0; k < ep->mesh.NbElmLayer[j]; k++) {
         std::vector<MVertex *> v;
@@ -407,7 +418,7 @@ static void phase3(GRegion *gr, MVertexRTree &pos,
   GFace *from = gr->model()->getFaceByTag(std::abs(ep->geo.Source));
   if(!from) return;
 
-  for(unsigned int i = 0; i < from->triangles.size(); i++) {
+  for(std::size_t i = 0; i < from->triangles.size(); i++) {
     MTriangle *tri = from->triangles[i];
     for(int j = 0; j < ep->mesh.NbLayer; j++) {
       for(int k = 0; k < ep->mesh.NbElmLayer[j]; k++) {
@@ -462,10 +473,13 @@ static void phase3(GRegion *gr, MVertexRTree &pos,
 
 int SubdivideExtrudedMesh(GModel *m)
 {
-  // get all non-recombined extruded regions and vertices; also,
-  // create a vector of quadToTri regions that have NOT been meshed
-  // yet
-  std::vector<GRegion *> regions, regions_quadToTri;
+  // get all non-recombined extruded regions and vertices; also, create a vector
+  // of quadToTri regions that have NOT been meshed yet
+  std::vector<GRegion *> regions;
+#if defined(HAVE_QUADTRI)
+  std::vector<GRegion *> regions_quadToTri;
+#endif
+
   MVertexRTree pos(CTX::instance()->geom.tolerance * CTX::instance()->lc);
   for(GModel::riter it = m->firstRegion(); it != m->lastRegion(); it++) {
     ExtrudeParams *ep = (*it)->meshAttributes.extrude;
@@ -474,93 +488,130 @@ int SubdivideExtrudedMesh(GModel *m)
       regions.push_back(*it);
       insertAllVertices(*it, pos);
     }
+#if defined(HAVE_QUADTRI)
     // create vector of valid quadToTri regions...not all will necessarily be
     // meshed here.
     if(ep && ep->mesh.ExtrudeMesh && ep->geo.Mode == EXTRUDED_ENTITY &&
        ep->mesh.Recombine && ep->mesh.QuadToTri) {
       regions_quadToTri.push_back(*it);
     }
+#endif
   }
 
   if(regions.empty()) return 0;
+
   Msg::Info("Subdividing extruded mesh");
 
-  // create edges on lateral sides of "prisms"
   std::set<std::pair<MVertex *, MVertex *> > edges;
-  for(unsigned int i = 0; i < regions.size(); i++)
-    phase1(regions[i], pos, edges);
 
-  // swap lateral edges to make them "tet-compatible"
-  int j = 0, swap;
-  std::set<std::pair<MVertex *, MVertex *> > edges_swap;
-  do {
-    swap = 0;
-    for(unsigned int i = 0; i < regions.size(); i++)
-      phase2(regions[i], pos, edges, edges_swap, swap);
-    Msg::Info("Swapping %d", swap);
-    if(j && j == swap) {
-      Msg::Error("Unable to subdivide extruded mesh: change surface mesh or");
-      Msg::Error("recombine extrusion instead");
-      return -1;
-    }
-    j = swap;
-  } while(swap);
+  for(int ntry = 1; ntry <= 2; ntry++) {
+    // create edges on lateral sides of "prisms"
+    for(std::size_t i = 0; i < regions.size(); i++)
+      phase1(regions[i], pos, edges, ntry);
+    // swap lateral edges to make them "tet-compatible"
+    int j = 0, swap;
+    std::set<std::pair<MVertex *, MVertex *> > edges_swap;
+    do {
+      swap = 0;
+      for(std::size_t i = 0; i < regions.size(); i++)
+        phase2(regions[i], pos, edges, edges_swap, swap);
+      Msg::Info("Swapping %d", swap);
+      if(j && j == swap) {
+        if(ntry == 1) {
+          Msg::Info("Subdivision failed, trying alternative split");
+          edges.clear();
+          break;
+        }
+        else{
+          Msg::Error("Unable to subdivide extruded mesh: change surface mesh or");
+          Msg::Error("recombine extrusion instead");
+          return -1;
+        }
+      }
+      j = swap;
+    } while(swap);
+    if(!swap) break;
+  }
 
   // delete volume elements and create tetrahedra instead
-  for(unsigned int i = 0; i < regions.size(); i++) {
+  for(std::size_t i = 0; i < regions.size(); i++) {
     GRegion *gr = regions[i];
-
-    for(unsigned int i = 0; i < gr->tetrahedra.size(); i++)
+    for(std::size_t i = 0; i < gr->tetrahedra.size(); i++)
       delete gr->tetrahedra[i];
     gr->tetrahedra.clear();
-    for(unsigned int i = 0; i < gr->hexahedra.size(); i++)
+    for(std::size_t i = 0; i < gr->hexahedra.size(); i++)
       delete gr->hexahedra[i];
     gr->hexahedra.clear();
-    for(unsigned int i = 0; i < gr->prisms.size(); i++) delete gr->prisms[i];
+    for(std::size_t i = 0; i < gr->prisms.size(); i++)
+      delete gr->prisms[i];
     gr->prisms.clear();
-    for(unsigned int i = 0; i < gr->pyramids.size(); i++)
+    for(std::size_t i = 0; i < gr->pyramids.size(); i++)
       delete gr->pyramids[i];
     gr->pyramids.clear();
     phase3(gr, pos, edges);
+  }
 
-    // re-Extrude bounding surfaces using edges as constraint
-    std::vector<GFace *> faces = gr->faces();
-    for(std::vector<GFace *>::iterator it = faces.begin(); it != faces.end();
-        it++) {
-      ExtrudeParams *ep = (*it)->meshAttributes.extrude;
+  // remesh bounding surfaces, to make them compatible with the volume mesh
+  std::set<GFace*> faces;
+  for(std::size_t i = 0; i < regions.size(); i++) {
+    GRegion *gr = regions[i];
+    std::vector<GFace *> f = gr->faces();
+    for(std::size_t i = 0; i < f.size(); i++){
+      ExtrudeParams *ep = f[i]->meshAttributes.extrude;
+      // TODO: this does not yet handle swapping of edges in COPIED_ENTITY
+      // surfaces, whose mesh is copied during extrusion (the "top"
+      // surface). PS: we will need to distinguish the old boundary layer case
+      // if we include these "copied" meshes
       if(ep && ep->mesh.ExtrudeMesh && ep->geo.Mode == EXTRUDED_ENTITY &&
          !ep->mesh.Recombine) {
-        GFace *gf = *it;
-        Msg::Info("Remeshing surface %d", gf->tag());
-        for(unsigned int i = 0; i < gf->triangles.size(); i++)
-          delete gf->triangles[i];
-        gf->triangles.clear();
-        for(unsigned int i = 0; i < gf->quadrangles.size(); i++)
-          delete gf->quadrangles[i];
-        gf->quadrangles.clear();
-        MeshExtrudedSurface(gf, &edges);
+        f[i]->meshStatistics.status = GFace::PENDING;
+        faces.insert(f[i]);
       }
     }
   }
+  int nIter = 0;
+  while(1) {
+    int nPending = 0;
+    for(std::set<GFace *>::iterator it = faces.begin(); it != faces.end();
+        it++) {
+      GFace *gf = *it;
+      if(gf->meshStatistics.status == GFace::PENDING){
+        Msg::Info("Remeshing surface %d", gf->tag());
+        for(std::size_t i = 0; i < gf->triangles.size(); i++)
+          delete gf->triangles[i];
+        gf->triangles.clear();
+        for(std::size_t i = 0; i < gf->quadrangles.size(); i++)
+          delete gf->quadrangles[i];
+        gf->quadrangles.clear();
+        MeshExtrudedSurface(gf, &edges);
+        nPending++;
+      }
+    }
+    if(!nPending) break;
+    if(nIter++ > 10){
+      Msg::Warning("Could not remesh all subdivided surfaces");
+      break;
+    }
+  }
 
-  // now mesh the QuadToTri regions. Everything can be done locally
-  // for each quadToTri region, but still use edge set from above just
-  // to make sure laterals get remeshed properly (
-  // QuadToTriEdgeGenerator detects if the neighbor has been meshed or
-  // if a lateral surface should remain static for any other reason).
-  // If this function detects allNonGlobalSharedLaterals, it won't
-  // mesh the region (should already be done in ExtrudeMesh).
-  for(unsigned int i = 0; i < regions_quadToTri.size(); i++) {
+#if defined(HAVE_QUADTRI)
+  // now mesh the QuadToTri regions. Everything can be done locally for each
+  // quadToTri region, but still use edge set from above just to make sure
+  // laterals get remeshed properly ( QuadToTriEdgeGenerator detects if the
+  // neighbor has been meshed or if a lateral surface should remain static for
+  // any other reason).  If this function detects allNonGlobalSharedLaterals, it
+  // won't mesh the region (should already be done in ExtrudeMesh).
+  for(std::size_t i = 0; i < regions_quadToTri.size(); i++) {
     GRegion *gr = regions_quadToTri[i];
     MVertexRTree pos_local(CTX::instance()->geom.tolerance *
                            CTX::instance()->lc);
     insertAllVertices(gr, pos_local);
     meshQuadToTriRegionAfterGlobalSubdivide(gr, &edges, pos_local);
   }
+#endif
 
-  // carve holes if any
-  // TODO: update extrusion information
-  for(unsigned int i = 0; i < regions.size(); i++) {
+  // carve holes if any (TODO: update extrusion information)
+  for(std::size_t i = 0; i < regions.size(); i++) {
     GRegion *gr = regions[i];
     ExtrudeParams *ep = gr->meshAttributes.extrude;
     if(ep->mesh.Holes.size()) {
@@ -569,7 +620,9 @@ int SubdivideExtrudedMesh(GModel *m)
         carveHole(gr, it->first, it->second.first, it->second.second);
     }
   }
-  for(unsigned int i = 0; i < regions_quadToTri.size(); i++) {
+
+#if defined(HAVE_QUADTRI)
+  for(std::size_t i = 0; i < regions_quadToTri.size(); i++) {
     GRegion *gr = regions_quadToTri[i];
     ExtrudeParams *ep = gr->meshAttributes.extrude;
     if(ep->mesh.Holes.size()) {
@@ -578,6 +631,7 @@ int SubdivideExtrudedMesh(GModel *m)
         carveHole(gr, it->first, it->second.first, it->second.second);
     }
   }
+#endif
 
   return 1;
 }
