@@ -1,13 +1,15 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 //
 // Contributor(s):
 //   Trevor S. Strickler
 //
 
 #include <map>
+#include "GmshConfig.h"
+#include "GmshMessage.h"
 #include "meshGFace.h"
 #include "GFace.h"
 #include "GRegion.h"
@@ -16,8 +18,10 @@
 #include "MHexahedron.h"
 #include "MPrism.h"
 #include "Context.h"
-#include "GmshMessage.h"
+
+#if defined(HAVE_QUADTRI)
 #include "QuadTriTransfinite3D.h"
+#endif
 
 /*
   Transfinite volume meshes
@@ -139,23 +143,23 @@ transfiniteHex(GRegion *gr, MVertex *f1, MVertex *f2, MVertex *f3, MVertex *f4,
 class GOrientedTransfiniteFace {
 private:
   GFace *_gf;
-  int _LL, _HH;
+  int _ll, _hh;
   int _permutation, _index;
   std::vector<MVertex *> _list;
 
 public:
   GOrientedTransfiniteFace()
-    : _gf(0), _LL(0), _HH(0), _permutation(-1), _index(-1)
+    : _gf(0), _ll(0), _hh(0), _permutation(-1), _index(-1)
   {
   }
   GOrientedTransfiniteFace(GFace *gf, std::vector<MVertex *> &corners)
-    : _gf(gf), _LL(0), _HH(0), _permutation(-1), _index(-1)
+    : _gf(gf), _ll(0), _hh(0), _permutation(-1), _index(-1)
   {
-    _LL = gf->transfinite_vertices.size() - 1;
-    if(_LL <= 0) return;
-    _HH = gf->transfinite_vertices[0].size() - 1;
-    if(_HH <= 0) return;
-    Msg::Debug("Face %d: L = %d  H = %d", gf->tag(), _LL, _HH);
+    _ll = gf->transfinite_vertices.size() - 1;
+    if(_ll <= 0) return;
+    _hh = gf->transfinite_vertices[0].size() - 1;
+    if(_hh <= 0) return;
+    Msg::Debug("Face %d: L = %d  H = %d", gf->tag(), _ll, _hh);
 
     // get the corners of the transfinite volume interpolation
     std::vector<MVertex *> s(8);
@@ -180,14 +184,14 @@ public:
     if(_gf->meshAttributes.corners.empty() ||
        _gf->meshAttributes.corners.size() == 4) {
       c[0] = _gf->transfinite_vertices[0][0];
-      c[1] = _gf->transfinite_vertices[_LL][0];
-      c[2] = _gf->transfinite_vertices[_LL][_HH];
-      c[3] = _gf->transfinite_vertices[0][_HH];
+      c[1] = _gf->transfinite_vertices[_ll][0];
+      c[2] = _gf->transfinite_vertices[_ll][_hh];
+      c[3] = _gf->transfinite_vertices[0][_hh];
     }
     else if(_gf->meshAttributes.corners.size() == 3) {
       c[0] = _gf->transfinite_vertices[0][0];
-      c[1] = _gf->transfinite_vertices[_LL][0];
-      c[2] = _gf->transfinite_vertices[_LL][_HH];
+      c[1] = _gf->transfinite_vertices[_ll][0];
+      c[2] = _gf->transfinite_vertices[_ll][_hh];
       c[3] = _gf->transfinite_vertices[0][0];
     }
     else
@@ -211,10 +215,12 @@ public:
       }
     }
     Msg::Debug("Found face index %d  (permutation = %d)", _index, _permutation);
-    for(int i = 0; i <= _LL; i++)
-      for(int j = 0; j <= _HH; j++)
+    for(int i = 0; i <= _ll; i++)
+      for(int j = 0; j <= _hh; j++)
         _list.push_back(_gf->transfinite_vertices[i][j]);
   }
+  // returns the surface
+  GFace *getSurface() { return _gf; }
   // returns the index of the face in the reference hexahedron
   int index() const { return _index; }
   // returns true if the face is recombined
@@ -224,8 +230,8 @@ public:
   }
   // returns the number or points in the transfinite mesh in both
   // parameter directions
-  int getNumU() { return (_permutation % 2) ? _HH + 1 : _LL + 1; }
-  int getNumV() { return (_permutation % 2) ? _LL + 1 : _HH + 1; }
+  int getNumU() { return (_permutation % 2) ? _hh + 1 : _ll + 1; }
+  int getNumV() { return (_permutation % 2) ? _ll + 1 : _hh + 1; }
   // returns the (i,j) vertex in the face, i and j being defined in
   // the coordinate system of the reference transfinite hexahedron
   MVertex *getVertex(int i, int j)
@@ -257,7 +263,7 @@ void findTransfiniteCorners(GRegion *gr, std::vector<MVertex *> &corners)
 {
   if(gr->meshAttributes.corners.size()) {
     // corners have been specified explicitly
-    for(unsigned int i = 0; i < gr->meshAttributes.corners.size(); i++)
+    for(std::size_t i = 0; i < gr->meshAttributes.corners.size(); i++)
       corners.push_back(gr->meshAttributes.corners[i]->mesh_vertices[0]);
   }
   else {
@@ -287,8 +293,8 @@ void findTransfiniteCorners(GRegion *gr, std::vector<MVertex *> &corners)
           it != fedges.end(); it++)
         redges.erase(std::find(redges.begin(), redges.end(), *it));
       findTransfiniteCorners(gf, corners);
-      unsigned int N = corners.size();
-      for(unsigned int i = 0; i < N; i++) {
+      std::size_t N = corners.size();
+      for(std::size_t i = 0; i < N; i++) {
         for(std::vector<GEdge *>::const_iterator it = redges.begin();
             it != redges.end(); it++) {
           if((*it)->getBeginVertex()->mesh_vertices[0] == corners[i]) {
@@ -309,7 +315,7 @@ int MeshTransfiniteVolume(GRegion *gr)
 {
   if(gr->meshAttributes.method != MESH_TRANSFINITE) return 0;
 
-  Msg::Info("Meshing volume %d (transfinite)", gr->tag());
+  Msg::Info("Meshing volume %d (Transfinite)", gr->tag());
 
   std::vector<GFace *> faces = gr->faces();
   if(faces.size() != 5 && faces.size() != 6) {
@@ -318,6 +324,18 @@ int MeshTransfiniteVolume(GRegion *gr)
     return 0;
   }
 
+  // make sure that all bounding edges have begin/end points: everything in here
+  // depends on it
+  const std::vector<GEdge *> &edges = gr->edges();
+  for(std::vector<GEdge *>::const_iterator it = edges.begin();
+      it != edges.end(); it++){
+    if(!(*it)->getBeginVertex() || !(*it)->getEndVertex()){
+      Msg::Error("Transfinite algorithm cannot be applied with curve %d which "
+                 "has no begin or end point", (*it)->tag());
+      return 0;
+    }
+  }
+
   std::vector<MVertex *> corners;
   findTransfiniteCorners(gr, corners);
   if(corners.size() != 6 && corners.size() != 8) {
@@ -335,6 +353,12 @@ int MeshTransfiniteVolume(GRegion *gr)
                  (*it)->tag(), gr->tag());
       return 0;
     }
+    else if(orientedFaces[f.index()].getSurface()) {
+      Msg::Error("Surfaces %d and %d mapped to the same index in transfinite "
+                 "volume %d", orientedFaces[f.index()].getSurface()->tag(),
+                 (*it)->tag(), gr->tag());
+      return 0;
+    }
     orientedFaces[f.index()] = f;
   }
 
@@ -453,10 +477,9 @@ int MeshTransfiniteVolume(GRegion *gr)
     }
   }
 
-  // create elements
-
-  // for QuadTri, get external boundary diagonals for element
-  // subdivision purposes
+#if defined(HAVE_QUADTRI)
+  // for QuadTri, get external boundary diagonals for element subdivision
+  // purposes
   std::set<std::pair<MVertex *, MVertex *> > boundary_diags;
   if(gr->meshAttributes.QuadTri) {
     if(!getTransfiniteBoundaryDiags(gr, &boundary_diags)) {
@@ -467,11 +490,15 @@ int MeshTransfiniteVolume(GRegion *gr)
       return 0;
     }
   }
+#endif
+
+  // create elements
 
   if(faces.size() == 6) {
     for(int i = 0; i < N_i - 1; i++) {
       for(int j = 0; j < N_j - 1; j++) {
         for(int k = 0; k < N_k - 1; k++) {
+#if defined(HAVE_QUADTRI)
           if(gr->meshAttributes.QuadTri) {
             // create vertex array
             std::vector<MVertex *> verts;
@@ -501,6 +528,7 @@ int MeshTransfiniteVolume(GRegion *gr)
             // continue, skipping the rest which is for non-divided elements
             continue;
           }
+#endif
           if(orientedFaces[0].recombined() && orientedFaces[1].recombined() &&
              orientedFaces[2].recombined() && orientedFaces[3].recombined() &&
              orientedFaces[4].recombined() && orientedFaces[5].recombined()) {
@@ -568,6 +596,7 @@ int MeshTransfiniteVolume(GRegion *gr)
   else if(faces.size() == 5) {
     for(int j = 0; j < N_j - 1; j++) {
       for(int k = 0; k < N_k - 1; k++) {
+#if defined(HAVE_QUADTRI)
         if(gr->meshAttributes.QuadTri) {
           // create vertex array
           std::vector<MVertex *> verts;
@@ -591,6 +620,7 @@ int MeshTransfiniteVolume(GRegion *gr)
           // continue, skipping the rest which is for non-divided elements
           continue;
         }
+#endif
         if((orientedFaces[0].recombined() && orientedFaces[1].recombined() &&
             orientedFaces[2].recombined() && orientedFaces[4].recombined() &&
             orientedFaces[5].recombined()) ||
@@ -625,6 +655,7 @@ int MeshTransfiniteVolume(GRegion *gr)
     for(int i = 1; i < N_i - 1; i++) {
       for(int j = 0; j < N_j - 1; j++) {
         for(int k = 0; k < N_k - 1; k++) {
+#if defined(HAVE_QUADTRI)
           if(gr->meshAttributes.QuadTri) {
             // create vertex array
             std::vector<MVertex *> verts;
@@ -652,6 +683,7 @@ int MeshTransfiniteVolume(GRegion *gr)
             // continue, skipping the rest which is for non-divided elements
             continue;
           }
+#endif
           if(orientedFaces[0].recombined() && orientedFaces[1].recombined() &&
              orientedFaces[2].recombined() && orientedFaces[4].recombined() &&
              orientedFaces[5].recombined()) {
