@@ -7,6 +7,7 @@
 //   Brian Helenbrook
 //
 
+#include "GModel.h"
 #include "HighOrder.h"
 #include "MLine.h"
 #include "MTriangle.h"
@@ -17,14 +18,15 @@
 #include "MPyramid.h"
 #include "GmshMessage.h"
 #include "OS.h"
-#include "Context.h"
 #include "meshGFaceOptimize.h"
 
+typedef std::map<MFace, std::vector<MVertex *>, MFaceLessThan> faceContainer;
+
 void subdivide_pyramid(MElement *element, GRegion *gr,
                        faceContainer &faceVertices,
                        std::vector<MHexahedron *> &dwarfs88);
 
-struct MVertexLessThanParam {
+struct MVertexPtrLessThanParam {
   bool operator()(const MVertex *v1, const MVertex *v2) const
   {
     double u1 = 0., u2 = 1.;
@@ -56,7 +58,7 @@ static void setBLData(MVertex *v)
 static bool setBLData(MElement *el)
 {
   // Check whether all low-order nodes are marked as BL nodes (only works in 2D)
-  for(int i = 0; i < el->getNumPrimaryVertices(); i++) {
+  for(std::size_t i = 0; i < el->getNumPrimaryVertices(); i++) {
     MVertex *v = el->getVertex(i);
     bool isBL = false;
     switch(v->onWhat()->dim()) {
@@ -97,7 +99,7 @@ static void Subdivide(GEdge *ge)
 
   // 2nd order meshing destroyed the ordering of the vertices on the edge
   std::sort(ge->mesh_vertices.begin(), ge->mesh_vertices.end(),
-            MVertexLessThanParam());
+            MVertexPtrLessThanParam());
   for(std::size_t i = 0; i < ge->mesh_vertices.size(); i++)
     ge->mesh_vertices[i]->setPolynomialOrder(1);
   ge->deleteVertexArrays();
@@ -485,7 +487,6 @@ void RefineMesh(GModel *m, bool linear, bool splitIntoQuads,
   // Check all 3D elements for negative volume and reverse if needed
   m->setAllVolumesPositive();
 
-  CTX::instance()->mesh.changed = ENT_ALL;
   double t2 = Cpu();
   Msg::StatusBar(true, "Done refining mesh (%g s)", t2 - t1);
 }
@@ -548,8 +549,6 @@ void BarycentricRefineMesh(GModel *m)
     }
   }
 
-  CTX::instance()->mesh.changed = ENT_ALL;
-
   double t2 = Cpu();
   Msg::StatusBar(true, "Done barycentrically refining mesh (%g s)", t2 - t1);
 }
