@@ -8,6 +8,7 @@
 // Segeth ,
 //                 Ivo Dolezel , Chapman and Hall/CRC; Edition : Har/Cdr (2003).
 
+#include <algorithm>
 #include "HierarchicalBasisH1Brick.h"
 
 HierarchicalBasisH1Brick::HierarchicalBasisH1Brick(int order)
@@ -325,7 +326,7 @@ void HierarchicalBasisH1Brick::generateGradientBasis(
     case(6):
     case(7):
       vectorTarget1 = &lkVectorW;
-      dvectorTarget1 = &dlkVectorV;
+      dvectorTarget1 = &dlkVectorW;
       break;
     }
     for(int indexEdgeFunc = 0; indexEdgeFunc < _pOrderEdge[iEdge] - 1;
@@ -420,59 +421,114 @@ void HierarchicalBasisH1Brick::generateGradientBasis(
   }
 }
 
-void HierarchicalBasisH1Brick::orientEdge(int const &flagOrientation,
-                                          int const &edgeNumber,
-                                          std::vector<double> &edgeBasis)
+void HierarchicalBasisH1Brick::orientEdge(
+  int const &flagOrientation, int const &edgeNumber,
+  std::vector<double> &edgeFunctions,
+  const std::vector<double> &eTablePositiveFlag,
+  const std::vector<double> &eTableNegativeFlag)
 {
   if(flagOrientation == -1) {
     int constant1 = 0;
     int constant2 = 0;
-    if(edgeNumber > 11) {
-      throw std::string("edgeNumber  must be : 0<=edgeNumber<=11");
-    }
     for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
     constant2 = constant2 - 1;
     constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
     for(int k = constant1; k <= constant2; k++) {
-      if((k - constant1) % 2 != 0) { edgeBasis[k] = edgeBasis[k] * (-1); }
+      edgeFunctions[k] = eTableNegativeFlag[k];
+    }
+  }
+  else {
+    int constant1 = 0;
+    int constant2 = 0;
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
+    for(int k = constant1; k <= constant2; k++) {
+      edgeFunctions[k] = eTablePositiveFlag[k];
     }
   }
 }
 
-void HierarchicalBasisH1Brick::orientEdgeGrad(
+void HierarchicalBasisH1Brick::orientEdge(
   int const &flagOrientation, int const &edgeNumber,
-  std::vector<std::vector<double> > &gradientEdge)
+  std::vector<std::vector<double> > &edgeFunctions,
+  const std::vector<std::vector<double> > &eTablePositiveFlag,
+  const std::vector<std::vector<double> > &eTableNegativeFlag)
 {
   if(flagOrientation == -1) {
     int constant1 = 0;
     int constant2 = 0;
-    if(edgeNumber > 11) {
-      throw std::string("edgeNumber  must be : 0<=edgeNumber<=11");
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
+    for(int k = constant1; k <= constant2; k++) {
+      edgeFunctions[k][0] = eTableNegativeFlag[k][0];
+      edgeFunctions[k][1] = eTableNegativeFlag[k][1];
+      edgeFunctions[k][2] = eTableNegativeFlag[k][2];
     }
+  }
+  else {
+    int constant1 = 0;
+    int constant2 = 0;
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
+    for(int k = constant1; k <= constant2; k++) {
+      edgeFunctions[k][0] = eTablePositiveFlag[k][0];
+      edgeFunctions[k][1] = eTablePositiveFlag[k][1];
+      edgeFunctions[k][2] = eTablePositiveFlag[k][2];
+    }
+  }
+}
+
+void HierarchicalBasisH1Brick::orientEdgeFunctionsForNegativeFlag(
+  std::vector<double> &edgeFunctions)
+{
+  int constant1 = 0;
+  int constant2 = 0;
+  for(int edgeNumber = 0; edgeNumber < _nedge; edgeNumber++) {
+    constant2 = 0;
+    constant2 = 0;
     for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
     constant2 = constant2 - 1;
     constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
     for(int k = constant1; k <= constant2; k++) {
       if((k - constant1) % 2 != 0) {
-        gradientEdge[k][0] = gradientEdge[k][0] * (-1);
-        gradientEdge[k][1] = gradientEdge[k][1] * (-1);
-        gradientEdge[k][2] = gradientEdge[k][2] * (-1);
+        edgeFunctions[k] = edgeFunctions[k] * (-1);
       }
     }
   }
 }
 
-void HierarchicalBasisH1Brick::orientFace(double const &u, double const &v,
-                                          double const &w, int const &flag1,
-                                          int const &flag2, int const &flag3,
-                                          int const &faceNumber,
-                                          std::vector<double> &faceBasis)
+void HierarchicalBasisH1Brick::orientEdgeFunctionsForNegativeFlag(
+  std::vector<std::vector<double> > &edgeFunctions)
+{
+  int constant1 = 0;
+  int constant2 = 0;
+  for(int edgeNumber = 0; edgeNumber < _nedge; edgeNumber++) {
+    constant2 = 0;
+    constant2 = 0;
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
+    for(int k = constant1; k <= constant2; k++) {
+      if((k - constant1) % 2 != 0) {
+        edgeFunctions[k][0] = edgeFunctions[k][0] * (-1);
+        edgeFunctions[k][1] = edgeFunctions[k][1] * (-1);
+        edgeFunctions[k][2] = edgeFunctions[k][2] * (-1);
+      }
+    }
+  }
+}
+
+void HierarchicalBasisH1Brick::orientOneFace(double const &u, double const &v,
+                                             double const &w, int const &flag1,
+                                             int const &flag2, int const &flag3,
+                                             int const &faceNumber,
+                                             std::vector<double> &faceBasis)
 {
   if(!(flag1 == 1 && flag2 == 1 && flag3 == 1)) {
     int iterator = 0;
-    if(faceNumber > 5) {
-      throw std::string("edgeNumber  must be : 0<=faceNumber<=5");
-    }
     for(int i = 0; i < faceNumber; i++) {
       iterator += (_pOrderFace1[i] - 1) * (_pOrderFace2[i] - 1);
     }
@@ -524,21 +580,21 @@ void HierarchicalBasisH1Brick::orientFace(double const &u, double const &v,
         var2 = v;
         break;
       }
-      std::vector<double> lkVector1(_pOrderFace2[faceNumber] - 1);
-      std::vector<double> lkVector2(_pOrderFace1[faceNumber] - 1);
-      for(int it = 2; it <= _pOrderFace2[faceNumber]; it++) {
+      std::vector<double> lkVector1(_pOrderFace1[faceNumber] - 1);
+      std::vector<double> lkVector2(_pOrderFace2[faceNumber] - 1);
+      for(int it = 2; it <= _pOrderFace1[faceNumber]; it++) {
         lkVector1[it - 2] = OrthogonalPoly::EvalLobatto(it, var1);
       }
-      for(int it = 2; it <= _pOrderFace1[faceNumber]; it++) {
+      for(int it = 2; it <= _pOrderFace2[faceNumber]; it++) {
         lkVector2[it - 2] = OrthogonalPoly::EvalLobatto(it, var2);
       }
 
-      for(int it1 = 2; it1 <= _pOrderFace1[faceNumber]; it1++) {
-        for(int it2 = 2; it2 <= _pOrderFace2[faceNumber]; it2++) {
+      for(int it1 = 2; it1 <= _pOrderFace2[faceNumber]; it1++) {
+        for(int it2 = 2; it2 <= _pOrderFace1[faceNumber]; it2++) {
           int impactFlag1 = 1;
           int impactFlag2 = 1;
-          if(flag1 == -1 && it1 % 2 != 0) { impactFlag1 = -1; }
-          if(flag2 == -1 && it2 % 2 != 0) { impactFlag2 = -1; }
+          if(flag2 == -1 && it1 % 2 != 0) { impactFlag1 = -1; }
+          if(flag1 == -1 && it2 % 2 != 0) { impactFlag2 = -1; }
           faceBasis[iterator] = lambda * lkVector1[it2 - 2] *
                                 lkVector2[it1 - 2] * impactFlag1 * impactFlag2;
           iterator++;
@@ -547,16 +603,13 @@ void HierarchicalBasisH1Brick::orientFace(double const &u, double const &v,
     }
   }
 }
-void HierarchicalBasisH1Brick::orientFaceGrad(
+void HierarchicalBasisH1Brick::orientOneFace(
   double const &u, double const &v, double const &w, int const &flag1,
   int const &flag2, int const &flag3, int const &faceNumber,
-  std::vector<std::vector<double> > &gradientFace)
+  std::vector<std::vector<double> > &gradientFace, std::string typeFunction)
 {
   if(!(flag1 == 1 && flag2 == 1 && flag3 == 1)) {
     int iterator = 0;
-    if(faceNumber > 5) {
-      throw std::string("edgeNumber  must be : 0<=faceNumber<=5");
-    }
     for(int i = 0; i < faceNumber; i++) {
       iterator += (_pOrderFace1[i] - 1) * (_pOrderFace2[i] - 1);
     }
@@ -624,30 +677,26 @@ void HierarchicalBasisH1Brick::orientFaceGrad(
         gradientLambda[2] = 0.5;
         break;
       }
-      std::vector<double> lkVector1(_pOrderFace2[faceNumber] - 1);
-      std::vector<double> lkVector2(_pOrderFace1[faceNumber] - 1);
-      std::vector<std::vector<double> > dlkVector1(_pOrderFace2[faceNumber] - 1,
+      std::vector<double> lkVector1(_pOrderFace1[faceNumber] - 1);
+      std::vector<double> lkVector2(_pOrderFace2[faceNumber] - 1);
+      std::vector<std::vector<double> > dlkVector1(_pOrderFace1[faceNumber] - 1,
                                                    std::vector<double>(3, 0.));
-      std::vector<std::vector<double> > dlkVector2(_pOrderFace1[faceNumber] - 1,
+      std::vector<std::vector<double> > dlkVector2(_pOrderFace2[faceNumber] - 1,
                                                    std::vector<double>(3, 0.));
-      for(int it = 2; it <= _pOrderFace2[faceNumber]; it++) {
-        lkVector1[it - 2] = OrthogonalPoly::EvalLobatto(it, uvw[var1]);
-      }
       for(int it = 2; it <= _pOrderFace1[faceNumber]; it++) {
-        lkVector2[it - 2] = OrthogonalPoly::EvalLobatto(it, uvw[var2]);
-      }
-      for(int it = 2; it <= _pOrderFace2[faceNumber]; it++) {
+        lkVector1[it - 2] = OrthogonalPoly::EvalLobatto(it, uvw[var1]);
         dlkVector1[it - 2][var1] = OrthogonalPoly::EvalDLobatto(it, uvw[var1]);
       }
-      for(int it = 2; it <= _pOrderFace1[faceNumber]; it++) {
+      for(int it = 2; it <= _pOrderFace2[faceNumber]; it++) {
+        lkVector2[it - 2] = OrthogonalPoly::EvalLobatto(it, uvw[var2]);
         dlkVector2[it - 2][var2] = OrthogonalPoly::EvalDLobatto(it, uvw[var2]);
       }
-      for(int it1 = 2; it1 <= _pOrderFace1[faceNumber]; it1++) {
-        for(int it2 = 2; it2 <= _pOrderFace2[faceNumber]; it2++) {
+      for(int it1 = 2; it1 <= _pOrderFace2[faceNumber]; it1++) {
+        for(int it2 = 2; it2 <= _pOrderFace1[faceNumber]; it2++) {
           int impactFlag1 = 1;
           int impactFlag2 = 1;
-          if(flag1 == -1 && it1 % 2 != 0) { impactFlag1 = -1; }
-          if(flag2 == -1 && it2 % 2 != 0) { impactFlag2 = -1; }
+          if(flag2 == -1 && it1 % 2 != 0) { impactFlag1 = -1; }
+          if(flag1 == -1 && it2 % 2 != 0) { impactFlag2 = -1; }
           for(int itVector = 0; itVector < 3; itVector++) {
             gradientFace[iterator][itVector] =
               (gradientLambda[itVector] * lkVector1[it2 - 2] *
@@ -662,3 +711,79 @@ void HierarchicalBasisH1Brick::orientFaceGrad(
     }
   }
 }
+
+void HierarchicalBasisH1Brick::orientFace(
+  int const &flag1, int const &flag2, int const &flag3, int const &faceNumber,
+  const std::vector<double> &quadFaceFunctionsAllOrientation,
+  const std::vector<double> &triFaceFunctionsAllOrientation,
+  std::vector<double> &fTableCopy)
+{
+  int iterator = 0;
+  for(int i = 0; i < faceNumber; i++) {
+    iterator += (_pOrderFace1[i] - 1) * (_pOrderFace2[i] - 1);
+  }
+  int numFaceFunctions =
+    (_pOrderFace1[faceNumber] - 1) * (_pOrderFace2[faceNumber] - 1);
+  int iOrientation = numberOrientationQuadFace(flag1, flag2, flag3);
+  int offset = iOrientation * _nQuadFaceFunction;
+  int offset2 = iterator + numFaceFunctions;
+  for(int i = iterator; i < offset2; i++) {
+    fTableCopy[i] = quadFaceFunctionsAllOrientation[i + offset];
+  }
+}
+void HierarchicalBasisH1Brick::orientFace(
+  int const &flag1, int const &flag2, int const &flag3, int const &faceNumber,
+  const std::vector<std::vector<double> > &quadFaceFunctionsAllOrientation,
+  const std::vector<std::vector<double> > &triFaceFunctionsAllOrientation,
+  std::vector<std::vector<double> > &fTableCopy)
+{
+  int iterator = 0;
+  for(int i = 0; i < faceNumber; i++) {
+    iterator += (_pOrderFace1[i] - 1) * (_pOrderFace2[i] - 1);
+  }
+  int numFaceFunctions =
+    (_pOrderFace1[faceNumber] - 1) * (_pOrderFace2[faceNumber] - 1);
+  int iOrientation = numberOrientationQuadFace(flag1, flag2, flag3);
+  int offset = iOrientation * _nQuadFaceFunction;
+  int offset2 = iterator + numFaceFunctions;
+  for(int i = iterator; i < offset2; i++) {
+    fTableCopy[i][0] = quadFaceFunctionsAllOrientation[i + offset][0];
+    fTableCopy[i][1] = quadFaceFunctionsAllOrientation[i + offset][1];
+    fTableCopy[i][2] = quadFaceFunctionsAllOrientation[i + offset][2];
+  }
+}
+
+void HierarchicalBasisH1Brick::getKeysInfo(std::vector<int> &functionTypeInfo,
+                                           std::vector<int> &orderInfo)
+{
+  for(int i = 0; i < 8; i++) {
+    functionTypeInfo[i] = 0;
+    orderInfo[i] = 1;
+  }
+  int it = 8;
+  for(int numEdge = 0; numEdge < 12; numEdge++) {
+    for(int i = 2; i <= _pOrderEdge[numEdge]; i++) {
+      functionTypeInfo[it] = 1;
+      orderInfo[it] = i;
+      it++;
+    }
+  }
+  for(int numFace = 0; numFace < 6; numFace++) {
+    for(int n1 = 2; n1 <= _pOrderFace1[numFace]; n1++) {
+      for(int n2 = 2; n2 <= _pOrderFace2[numFace]; n2++) {
+        functionTypeInfo[it] = 2;
+        orderInfo[it] = std::max(n1, n2);
+        it++;
+      }
+    }
+  }
+  for(int ipb1 = 2; ipb1 <= _pb1; ipb1++) {
+    for(int ipb2 = 2; ipb2 <= _pb2; ipb2++) {
+      for(int ipb3 = 2; ipb3 <= _pb3; ipb3++) {
+        functionTypeInfo[it] = 3;
+        orderInfo[it] = std::max(std::max(ipb1, ipb2), ipb3);
+        it++;
+      }
+    }
+  }
+}
