@@ -30,12 +30,12 @@
  *       4----------5
  *
  *  Oriented Edges:
- * e0={0, 1}, e1={0, 3}, e2={0, 4}, e3={1, 2}, e4 ={1, 5}, e5={2, 3},e6={2, 6},
- * e7={3, 7},e8={4, 5}, e9= {4, 7}, e10={5, 6}, e11={6, 7}
+ * e0={0, 1}, e1={0, 3}, e2={0, 4}, e3={1, 2}, e4 ={1, 5}, e5={3, 2},e6={2, 6},
+ * e7={3, 7},e8={4, 5}, e9= {4, 7}, e10={5, 6}, e11={7, 6}
  *
  * Oritented Surface:
  *  s0={0, 1, 3, 2}, s1={0, 1, 4, 5}, s2={0, 3, 4, 7},
- *  s3={1, 2, 5, 5}, s4={2, 3, 6, 6}, s5={4, 5, 7, 6}
+ *  s3={1, 2, 5, 6}, s4={3,2,7,6}, s5={4, 5, 7, 6}
  * Local (directional) orders on mesh faces are not allowed to exceed the mini-
  * mum of the (appropriate directional) orders of approximation associated with
  * the interior of the adjacent elements. Local orders of approximation on mesh
@@ -55,25 +55,46 @@ public:
                              std::vector<double> &edgeBasis,
                              std::vector<double> &faceBasis,
                              std::vector<double> &bubbleBasis);
-  virtual void
-  generateGradientBasis(double const &u, double const &v, double const &w,
-                        std::vector<std::vector<double> > &gradientVertex,
-                        std::vector<std::vector<double> > &gradientEdge,
-                        std::vector<std::vector<double> > &gradientFace,
-                        std::vector<std::vector<double> > &gradientBubble);
-  virtual void orientEdge(int const &flagOrientation, int const &edgeNumber,
-                          std::vector<double> &edgeBasis);
-  virtual void orientEdgeGrad(int const &flagOrientation, int const &edgeNumber,
-                              std::vector<std::vector<double> > &gradientEdge);
+  virtual void generateBasis(double const &u, double const &v, double const &w,
+                             std::vector<std::vector<double> > &vertexBasis,
+                             std::vector<std::vector<double> > &edgeBasis,
+                             std::vector<std::vector<double> > &faceBasis,
+                             std::vector<std::vector<double> > &bubbleBasis,
+                             std::string typeFunction = "GradH1Legendre")
+  {
+    generateGradientBasis(u, v, w, vertexBasis, edgeBasis, faceBasis,
+                          bubbleBasis);
+  }
 
-  virtual void orientFace(double const &u, double const &v, double const &w,
-                          int const &flag1, int const &flag2, int const &flag3,
-                          int const &faceNumber,
-                          std::vector<double> &faceBasis);
-  virtual void orientFaceGrad(double const &u, double const &v, double const &w,
-                              int const &flag1, int const &flag2,
-                              int const &flag3, int const &faceNumber,
-                              std::vector<std::vector<double> > &gradientFace);
+  virtual void orientEdge(int const &flagOrientation, int const &edgeNumber,
+                          std::vector<double> &edgeFunctions,
+                          const std::vector<double> &eTablePositiveFlag,
+                          const std::vector<double> &eTableNegativeFlag);
+  virtual void
+  orientEdge(int const &flagOrientation, int const &edgeNumber,
+             std::vector<std::vector<double> > &edgeBasis,
+             const std::vector<std::vector<double> > &eTablePositiveFlag,
+             const std::vector<std::vector<double> > &eTableNegativeFlag);
+
+  virtual void
+  orientEdgeFunctionsForNegativeFlag(std::vector<double> &edgeFunctions);
+  virtual void orientEdgeFunctionsForNegativeFlag(
+    std::vector<std::vector<double> > &edgeFunctions);
+
+  virtual void
+  orientFace(int const &flag1, int const &flag2, int const &flag3,
+             int const &faceNumber,
+             const std::vector<double> &quadFaceFunctionsAllOrientation,
+             const std::vector<double> &triFaceFunctionsAllOrientation,
+             std::vector<double> &fTableCopy);
+
+  virtual void orientFace(
+    int const &flag1, int const &flag2, int const &flag3, int const &faceNumber,
+    const std::vector<std::vector<double> > &quadFaceFunctionsAllOrientation,
+    const std::vector<std::vector<double> > &triFaceFunctionsAllOrientation,
+    std::vector<std::vector<double> > &fTableCopy);
+  virtual void getKeysInfo(std::vector<int> &functionTypeInfo,
+                           std::vector<int> &orderInfo);
 
 private:
   int _pb1; // bubble function order in  direction u
@@ -99,5 +120,19 @@ private:
                    std::vector<std::vector<double> >
                      &gradientLambda); // compute some product and fill the
                                        // vector gradientVertex
+  void generateGradientBasis(double const &u, double const &v, double const &w,
+                             std::vector<std::vector<double> > &gradientVertex,
+                             std::vector<std::vector<double> > &gradientEdge,
+                             std::vector<std::vector<double> > &gradientFace,
+                             std::vector<std::vector<double> > &gradientBubble);
+  virtual void orientOneFace(double const &u, double const &v, double const &w,
+                             int const &flag1, int const &flag2,
+                             int const &flag3, int const &faceNumber,
+                             std::vector<double> &faceBasis);
+  virtual void orientOneFace(double const &u, double const &v, double const &w,
+                             int const &flag1, int const &flag2,
+                             int const &flag3, int const &faceNumber,
+                             std::vector<std::vector<double> > &faceFunctions,
+                             std::string typeFunction = "GradH1Legendre");
 };
 #endif
