@@ -372,71 +372,253 @@ void HierarchicalBasisH1Quad::generateGradientBasis(
   }
 }
 
-void HierarchicalBasisH1Quad::orientEdge(int const &flagOrientation,
-                                         int const &edgeNumber,
-                                         std::vector<double> &edgeBasis)
+void HierarchicalBasisH1Quad::orientEdge(
+  int const &flagOrientation, int const &edgeNumber,
+  std::vector<double> &edgeFunctions,
+  const std::vector<double> &eTablePositiveFlag,
+  const std::vector<double> &eTableNegativeFlag)
 {
   if(flagOrientation == -1) {
-    int constant1;
-    int constant2;
-    switch(edgeNumber) {
-    case(0): {
-      constant1 = 0;
-      constant2 = _pOrderEdge[0] - 2;
-    } break;
-    case(1): {
-      constant1 = _pOrderEdge[0] - 1;
-      constant2 = _pOrderEdge[1] + _pOrderEdge[0] - 3;
-    } break;
-    case(2): {
-      constant1 = _pOrderEdge[0] + _pOrderEdge[1] - 2;
-      constant2 = _pOrderEdge[1] + _pOrderEdge[0] + _pOrderEdge[2] - 4;
-    } break;
-    case(3): {
-      constant1 = _pOrderEdge[0] + _pOrderEdge[1] + _pOrderEdge[2] - 3;
-      constant2 =
-        _pOrderEdge[1] + _pOrderEdge[0] + _pOrderEdge[2] + _pOrderEdge[3] - 5;
-    } break;
-    default: throw std::string("edgeNumber  must be : 0<=edgeNumber<=3");
-    }
+    int constant1 = 0;
+    int constant2 = 0;
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
     for(int k = constant1; k <= constant2; k++) {
-      if((k - constant1) % 2 != 0) { edgeBasis[k] = edgeBasis[k] * (-1); }
+      edgeFunctions[k] = eTableNegativeFlag[k];
+    }
+  }
+  else {
+    int constant1 = 0;
+    int constant2 = 0;
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
+    for(int k = constant1; k <= constant2; k++) {
+      edgeFunctions[k] = eTablePositiveFlag[k];
     }
   }
 }
 
-void HierarchicalBasisH1Quad::orientEdgeGrad(
+void HierarchicalBasisH1Quad::orientEdge(
   int const &flagOrientation, int const &edgeNumber,
-  std::vector<std::vector<double> > &gradientEdge)
+  std::vector<std::vector<double> > &edgeFunctions,
+  const std::vector<std::vector<double> > &eTablePositiveFlag,
+  const std::vector<std::vector<double> > &eTableNegativeFlag)
 {
   if(flagOrientation == -1) {
-    int constant1;
-    int constant2;
-    switch(edgeNumber) {
-    case(0): {
-      constant1 = 0;
-      constant2 = _pOrderEdge[0] - 2;
-    } break;
-    case(1): {
-      constant1 = _pOrderEdge[0] - 1;
-      constant2 = _pOrderEdge[1] + _pOrderEdge[0] - 3;
-    } break;
-    case(2): {
-      constant1 = _pOrderEdge[0] + _pOrderEdge[1] - 2;
-      constant2 = _pOrderEdge[1] + _pOrderEdge[0] + _pOrderEdge[2] - 4;
-    } break;
-    case(3): {
-      constant1 = _pOrderEdge[0] + _pOrderEdge[1] + _pOrderEdge[2] - 3;
-      constant2 =
-        _pOrderEdge[1] + _pOrderEdge[0] + _pOrderEdge[2] + _pOrderEdge[3] - 5;
-    } break;
-    default: throw std::string("edgeNumber  must be : 0<=edgeNumber<=3");
+    int constant1 = 0;
+    int constant2 = 0;
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
+    for(int k = constant1; k <= constant2; k++) {
+      edgeFunctions[k][0] = eTableNegativeFlag[k][0];
+      edgeFunctions[k][1] = eTableNegativeFlag[k][1];
     }
+  }
+  else {
+    int constant1 = 0;
+    int constant2 = 0;
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
+    for(int k = constant1; k <= constant2; k++) {
+      edgeFunctions[k][0] = eTablePositiveFlag[k][0];
+      edgeFunctions[k][1] = eTablePositiveFlag[k][1];
+    }
+  }
+}
+
+void HierarchicalBasisH1Quad::orientEdgeFunctionsForNegativeFlag(
+  std::vector<double> &edgeFunctions)
+{
+  int constant1 = 0;
+  int constant2 = 0;
+  for(int edgeNumber = 0; edgeNumber < _nedge; edgeNumber++) {
+    constant2 = 0;
+    constant2 = 0;
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
     for(int k = constant1; k <= constant2; k++) {
       if((k - constant1) % 2 != 0) {
-        gradientEdge[k][0] = gradientEdge[k][0] * (-1);
-        gradientEdge[k][1] = gradientEdge[k][1] * (-1);
+        edgeFunctions[k] = edgeFunctions[k] * (-1);
       }
     }
   }
 }
+
+void HierarchicalBasisH1Quad::orientEdgeFunctionsForNegativeFlag(
+  std::vector<std::vector<double> > &edgeFunctions)
+{
+  int constant1 = 0;
+  int constant2 = 0;
+  for(int edgeNumber = 0; edgeNumber < _nedge; edgeNumber++) {
+    constant2 = 0;
+    constant2 = 0;
+    for(int i = 0; i <= edgeNumber; i++) { constant2 += _pOrderEdge[i] - 1; }
+    constant2 = constant2 - 1;
+    constant1 = constant2 - _pOrderEdge[edgeNumber] + 2;
+    for(int k = constant1; k <= constant2; k++) {
+      if((k - constant1) % 2 != 0) {
+        edgeFunctions[k][0] = edgeFunctions[k][0] * (-1);
+        edgeFunctions[k][1] = edgeFunctions[k][1] * (-1);
+        edgeFunctions[k][2] = edgeFunctions[k][2] * (-1);
+      }
+    }
+  }
+}
+void HierarchicalBasisH1Quad::orientOneFace(double const &u, double const &v,
+                                            double const &w, int const &flag1,
+                                            int const &flag2, int const &flag3,
+                                            int const &faceNumber,
+                                            std::vector<double> &faceBasis)
+{
+  if(!(flag1 == 1 && flag2 == 1 && flag3 == 1)) {
+    int iterator = 0;
+    if(flag3 == 1) {
+      for(int it1 = 2; it1 <= _pf1; it1++) {
+        for(int it2 = 2; it2 <= _pf2; it2++) {
+          int impactFlag1 = 1;
+          int impactFlag2 = 1;
+          if(flag1 == -1 && it1 % 2 != 0) { impactFlag1 = -1; }
+          if(flag2 == -1 && it2 % 2 != 0) { impactFlag2 = -1; }
+          faceBasis[iterator] = faceBasis[iterator] * impactFlag1 * impactFlag2;
+          iterator++;
+        }
+      }
+    }
+    else {
+      std::vector<double> lkVector1(_pf2 - 1);
+      std::vector<double> lkVector2(_pf1 - 1);
+      for(int it = 2; it <= _pf1; it++) {
+        lkVector1[it - 2] = OrthogonalPoly::EvalLobatto(it, u);
+      }
+      for(int it = 2; it <= _pf2; it++) {
+        lkVector2[it - 2] = OrthogonalPoly::EvalLobatto(it, v);
+      }
+
+      for(int it1 = 2; it1 <= _pf2; it1++) {
+        for(int it2 = 2; it2 <= _pf1; it2++) {
+          int impactFlag1 = 1;
+          int impactFlag2 = 1;
+          if(flag2 == -1 && it1 % 2 != 0) { impactFlag1 = -1; }
+          if(flag1 == -1 && it2 % 2 != 0) { impactFlag2 = -1; }
+          faceBasis[iterator] =
+            lkVector1[it2 - 2] * lkVector2[it1 - 2] * impactFlag1 * impactFlag2;
+          iterator++;
+        }
+      }
+    }
+  }
+}
+
+void HierarchicalBasisH1Quad::orientOneFace(
+  double const &u, double const &v, double const &w, int const &flag1,
+  int const &flag2, int const &flag3, int const &faceNumber,
+  std::vector<std::vector<double> > &gradientFace, std::string typeFunction)
+{
+  if(!(flag1 == 1 && flag2 == 1 && flag3 == 1)) {
+    int iterator = 0;
+    if(flag3 == 1) {
+      for(int it1 = 2; it1 <= _pf1; it1++) {
+        for(int it2 = 2; it2 <= _pf2; it2++) {
+          int impactFlag1 = 1;
+          int impactFlag2 = 1;
+          if(flag1 == -1 && it1 % 2 != 0) { impactFlag1 = -1; }
+          if(flag2 == -1 && it2 % 2 != 0) { impactFlag2 = -1; }
+          gradientFace[iterator][0] =
+            gradientFace[iterator][0] * impactFlag1 * impactFlag2;
+          gradientFace[iterator][1] =
+            gradientFace[iterator][1] * impactFlag1 * impactFlag2;
+
+          iterator++;
+        }
+      }
+    }
+    else {
+      std::vector<double> lkVector1(_pf1 - 1);
+      std::vector<double> lkVector2(_pf2 - 1);
+      std::vector<double> dlkVector1(_pf1 - 1);
+      std::vector<double> dlkVector2(_pf2 - 1);
+      for(int it = 2; it <= _pf1; it++) {
+        lkVector1[it - 2] = OrthogonalPoly::EvalLobatto(it, u);
+        dlkVector1[it - 2] = OrthogonalPoly::EvalDLobatto(it, u);
+      }
+      for(int it = 2; it <= _pf2; it++) {
+        lkVector2[it - 2] = OrthogonalPoly::EvalLobatto(it, v);
+        dlkVector2[it - 2] = OrthogonalPoly::EvalDLobatto(it, v);
+      }
+      for(int it1 = 2; it1 <= _pf2; it1++) {
+        for(int it2 = 2; it2 <= _pf1; it2++) {
+          int impactFlag1 = 1;
+          int impactFlag2 = 1;
+          if(flag2 == -1 && it1 % 2 != 0) { impactFlag1 = -1; }
+          if(flag1 == -1 && it2 % 2 != 0) { impactFlag2 = -1; }
+
+          gradientFace[iterator][0] = dlkVector1[it2 - 2] * lkVector2[it1 - 2] *
+                                      impactFlag1 * impactFlag2;
+          gradientFace[iterator][1] = lkVector1[it2 - 2] * dlkVector2[it1 - 2] *
+                                      impactFlag1 * impactFlag2;
+          iterator++;
+        }
+      }
+    }
+  }
+}
+void HierarchicalBasisH1Quad::orientFace(
+  int const &flag1, int const &flag2, int const &flag3, int const &faceNumber,
+  const std::vector<double> &quadFaceFunctionsAllOrientation,
+  const std::vector<double> &triFaceFunctionsAllOrientation,
+  std::vector<double> &fTableCopy)
+{
+  int iOrientation = numberOrientationQuadFace(flag1, flag2, flag3);
+  int offset = iOrientation * _nQuadFaceFunction;
+  for(int i = 0; i < _nQuadFaceFunction; i++) {
+    fTableCopy[i] = quadFaceFunctionsAllOrientation[i + offset];
+  }
+}
+
+void HierarchicalBasisH1Quad::orientFace(
+  int const &flag1, int const &flag2, int const &flag3, int const &faceNumber,
+  const std::vector<std::vector<double> > &quadFaceFunctionsAllOrientation,
+  const std::vector<std::vector<double> > &triFaceFunctionsAllOrientation,
+  std::vector<std::vector<double> > &fTableCopy)
+{
+  int iOrientation = numberOrientationQuadFace(flag1, flag2, flag3);
+  int offset = iOrientation * _nQuadFaceFunction;
+  for(int i = 0; i < _nQuadFaceFunction; i++) {
+    fTableCopy[i][0] = quadFaceFunctionsAllOrientation[i + offset][0];
+    fTableCopy[i][1] = quadFaceFunctionsAllOrientation[i + offset][1];
+    fTableCopy[i][2] = quadFaceFunctionsAllOrientation[i + offset][2];
+  }
+}
+
+void HierarchicalBasisH1Quad::getKeysInfo(std::vector<int> &functionTypeInfo,
+                                          std::vector<int> &orderInfo)
+{
+  functionTypeInfo[0] = 0;
+  functionTypeInfo[1] = 0;
+  functionTypeInfo[2] = 0;
+  functionTypeInfo[3] = 0;
+  orderInfo[0] = 1;
+  orderInfo[1] = 1;
+  orderInfo[2] = 1;
+  orderInfo[3] = 1;
+  int it = 4;
+  for(int numEdge = 0; numEdge < 4; numEdge++) {
+    for(int i = 2; i <= _pOrderEdge[numEdge]; i++) {
+      functionTypeInfo[it] = 1;
+      orderInfo[it] = i;
+      it++;
+    }
+  }
+  for(int n1 = 2; n1 <= _pf1; n1++) {
+    for(int n2 = 2; n2 <= _pf2; n2++) {
+      functionTypeInfo[it] = 2;
+      orderInfo[it] = std::max(n1, n2);
+      it++;
+    }
+  }
+}
