@@ -1,11 +1,12 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _PARSER_H_
-#define _PARSER_H_
+#ifndef PARSER_H
+#define PARSER_H
 
+#include <algorithm>
 #include <map>
 #include <string>
 #include <vector>
@@ -143,7 +144,7 @@ public:
       str += it_attrib->first + " ";
       char tmp[32];
       if (it_attrib->second.size() > 1) str += "{ ";
-      for (unsigned int i = 0; i < it_attrib->second.size(); i++) {
+      for (std::size_t i = 0; i < it_attrib->second.size(); i++) {
         if (i) str += ", ";
         sprintf(tmp, "%g", it_attrib->second[i]); str += tmp;
       }
@@ -156,7 +157,7 @@ public:
       if (flag_comma) str += ", ";
       str += it_attrib->first + " ";
       if (it_attrib->second.size() > 1) str += "Str[{ ";
-      for (unsigned int i = 0; i < it_attrib->second.size(); i++) {
+      for (std::size_t i = 0; i < it_attrib->second.size(); i++) {
         if (i) str += ", ";
         str += "\"" + it_attrib->second[i] + "\"";
       }
@@ -304,14 +305,9 @@ public:
     const Struct * struct_P = (structs_P)? structs_P->Find(key_name) : NULL;
     if (structs_P && struct_P) {
       switch (struct_P->getMember(key_member, out, index)) {
-      case 0:
-        break;
-      case 1:
-        out = 0.; return 2; // 2: Error: Unknown member of Struct
-        break;
-      case 2:
-        out = 0.; return 3; // 3: // Error: Index out of range
-        break;
+      case 0: break;
+      case 1: out = 0.; return 2; // 2: Error: Unknown member of Struct
+      case 2: out = 0.; return 3; // 3: // Error: Index out of range
       }
     }
     else  {
@@ -328,14 +324,9 @@ public:
     const Struct * struct_P = (structs_P)? structs_P->Find(key_name) : NULL;
     if (structs_P && struct_P) {
       switch (struct_P->getMember(key_member, out, index)) {
-      case 0:
-        break;
-      case 1:
-        out = NULL; return 2; // 2: Error: Unknown member of Struct
-        break;
-      case 2:
-        out = NULL; return 3; // 3: // Error: Index out of range
-        break;
+      case 0: break;
+      case 1: out = NULL; return 2; // 2: Error: Unknown member of Struct
+      case 2: out = NULL; return 3; // 3: // Error: Index out of range
       }
     }
     else  {
@@ -351,11 +342,8 @@ public:
     const Struct * struct_P = (structs_P)? structs_P->Find(key_name) : NULL;
     if (structs_P && struct_P) {
       switch (struct_P->getMember_Dim(key_member, out)) {
-      case 0:
-        break;
-      case 1:
-        out = 0; return 2; // 2: Error: Unknown member of Struct
-        break;
+      case 0: break;
+      case 1: out = 0; return 2; // 2: Error: Unknown member of Struct
       }
     }
     else  {
@@ -371,11 +359,8 @@ public:
     const Struct * struct_P = (structs_P)? structs_P->Find(key_name) : NULL;
     if (structs_P && struct_P) {
       switch (struct_P->getMember_Vector(key_member, out_vector)) {
-      case 0:
-        break;
-      case 1:
-        out_vector = NULL; return 2; // 2: Error: Unknown member of Struct
-        break;
+      case 0: break;
+      case 1: out_vector = NULL; return 2; // 2: Error: Unknown member of Struct
       }
     }
     else  {
@@ -391,11 +376,8 @@ public:
     const Struct * struct_P = (structs_P)? structs_P->Find(key_name) : NULL;
     if (structs_P && struct_P) {
       switch (struct_P->getMember_Vector(key_member, out_vector)) {
-      case 0:
-        break;
-      case 1:
-        out_vector = NULL; return 2; // 2: Error: Unknown member of Struct
-        break;
+      case 0: break;
+      case 1: out_vector = NULL; return 2; // 2: Error: Unknown member of Struct
       }
     }
     else  {
