@@ -424,7 +424,7 @@ PView *GMSH_NearToFarFieldPlugin::execute(PView *v)
   double dPhi = (_phiEnd - _phiStart) / _nbPhi;
   double dTheta = (_thetaEnd - _thetaStart) / _nbThe;
   double ffmin = 1e200, ffmax = -1e200;
-  Msg::ResetProgressMeter();
+  Msg::StartProgressMeter(_nbPhi);
   for(int i = 0; i <= _nbPhi; i++) {
     for(int j = 0; j <= _nbThe; j++) {
       phi[i][j] = _phiStart + i * dPhi;
@@ -447,8 +447,9 @@ PView *GMSH_NearToFarFieldPlugin::execute(PView *v)
       ffmin = std::min(ffmin, farField[i][j]);
       ffmax = std::max(ffmax, farField[i][j]);
     }
-    Msg::ProgressMeter(i, _nbPhi, true, "Computing far field");
+    Msg::ProgressMeter(i, true, "Computing far field");
   }
+  Msg::StopProgressMeter();
   for(std::size_t i = 0; i < allElems.size(); i++) delete allElems[i];
 
   if(_normalize) {
