@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <map>
 #include <stdlib.h>
@@ -19,13 +19,12 @@
 #include "CutSphere.h"
 #include "CutBox.h"
 #include "Skin.h"
-#include "AnalyseCurvedMesh.h"
+#include "AnalyseMeshQuality.h"
 #include "CurvedBndDist.h"
 #include "MathEval.h"
 #include "ExtractElements.h"
 #include "SimplePartition.h"
 #include "Crack.h"
-#include "ThinLayerFixMesh.h"
 #include "HarmonicToTime.h"
 #include "ModulusPhase.h"
 #include "Integrate.h"
@@ -61,7 +60,6 @@
 #include "Scal2Vec.h"
 #include "CutMesh.h"
 #include "NewView.h"
-#include "FaultZone.h"
 #include "MeshSubEntities.h"
 #include "MeshVolume.h"
 #include "CVTRemesh.h"
@@ -69,6 +67,7 @@
 #include "GaussPoints.h"
 #include "VoroMetal.h"
 #include "Summation.h"
+#include "MeshSizeFieldView.h"
 
 // for testing purposes only :-)
 #undef HAVE_DLOPEN
@@ -93,7 +92,7 @@ PluginManager::~PluginManager()
     delete it->second;
 }
 
-GMSH_Plugin *PluginManager::find(std::string pluginName)
+GMSH_Plugin *PluginManager::find(const std::string &pluginName)
 {
   std::map<std::string, GMSH_Plugin *>::iterator it =
     allPlugins.find(pluginName);
@@ -114,8 +113,8 @@ GMSH_SolverPlugin *PluginManager::findSolverPlugin()
   return 0;
 }
 
-void PluginManager::action(std::string pluginName, std::string action,
-                           void *data)
+void PluginManager::action(const std::string &pluginName,
+                           const std::string &action, void *data)
 {
   GMSH_Plugin *plugin = find(pluginName);
   if(!plugin) throw "Unknown plugin name";
@@ -129,8 +128,9 @@ void PluginManager::action(std::string pluginName, std::string action,
     throw "Unknown plugin action";
 }
 
-void PluginManager::setPluginOption(std::string pluginName, std::string option,
-                                    std::string value)
+void PluginManager::setPluginOption(const std::string &pluginName,
+                                    const std::string &option,
+                                    const std::string &value)
 {
   GMSH_Plugin *plugin = find(pluginName);
   if(!plugin) throw "Unknown plugin name";
@@ -145,8 +145,9 @@ void PluginManager::setPluginOption(std::string pluginName, std::string option,
   throw "Unknown plugin option name";
 }
 
-void PluginManager::setPluginOption(std::string pluginName, std::string option,
-                                    double value)
+void PluginManager::setPluginOption(const std::string &pluginName,
+                                    const std::string &option,
+                                    double const value)
 {
   GMSH_Plugin *plugin = find(pluginName);
   if(!plugin) throw "Unknown plugin name";
@@ -260,10 +261,6 @@ void PluginManager::registerDefaultPlugins()
       "SimplePartition", GMSH_RegisterSimplePartitionPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
       "Crack", GMSH_RegisterCrackPlugin()));
-    allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
-      "FaultZone", GMSH_RegisterFaultZonePlugin()));
-    allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
-      "ThinLayerFixMesh", GMSH_RegisterThinLayerFixMeshPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
       "ShowNeighborElements", GMSH_RegisterShowNeighborElementsPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
@@ -276,11 +273,13 @@ void PluginManager::registerDefaultPlugins()
       "Summation", GMSH_RegisterSummationPlugin()));
 #if defined(HAVE_MESH)
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
-      "AnalyseCurvedMesh", GMSH_RegisterAnalyseCurvedMeshPlugin()));
+      "AnalyseMeshQuality", GMSH_RegisterAnalyseMeshQualityPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
       "VoroMetal", GMSH_RegisterVoroMetalPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
       "Tetrahedralize", GMSH_RegisterTetrahedralizePlugin()));
+    allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
+      "MeshSizeFieldView", GMSH_RegisterMeshSizeFieldViewPlugin()));
 #endif
 #if defined(HAVE_REVOROPT)
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
@@ -288,9 +287,9 @@ void PluginManager::registerDefaultPlugins()
 #endif
 #if defined(HAVE_KBIPACK)
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
-      "Homology", GMSH_RegisterHomologyComputationPlugin()));
+      "HomologyComputation", GMSH_RegisterHomologyComputationPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
-      "HomologyPost", GMSH_RegisterHomologyPostProcessingPlugin()));
+      "HomologyPostProcessing", GMSH_RegisterHomologyPostProcessingPlugin()));
 #endif
 #if defined(HAVE_SOLVER)
     allPlugins.insert(std::pair<std::string, GMSH_Plugin *>(
@@ -321,7 +320,7 @@ void PluginManager::registerDefaultPlugins()
 #endif
 }
 
-void PluginManager::addPlugin(std::string fileName)
+void PluginManager::addPlugin(const std::string &fileName)
 {
 #if !defined(HAVE_DLOPEN) || !defined(HAVE_FLTK)
   Msg::Warning("No dynamic plugin loading on this platform");
