@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <set>
 #include "Skin.h"
@@ -137,10 +137,10 @@ public:
       break;
     }
     if(!vec) return;
-    for(unsigned int i = 0; i < x.size(); i++) vec->push_back(x[i]);
-    for(unsigned int i = 0; i < y.size(); i++) vec->push_back(y[i]);
-    for(unsigned int i = 0; i < z.size(); i++) vec->push_back(z[i]);
-    for(unsigned int i = 0; i < v.size(); i++) vec->push_back(v[i]);
+    for(std::size_t i = 0; i < x.size(); i++) vec->push_back(x[i]);
+    for(std::size_t i = 0; i < y.size(); i++) vec->push_back(y[i]);
+    for(std::size_t i = 0; i < z.size(); i++) vec->push_back(z[i]);
+    for(std::size_t i = 0; i < v.size(); i++) vec->push_back(v[i]);
   }
 };
 
@@ -191,13 +191,13 @@ static void getBoundaryFromMesh(GModel *m, int visible)
   int dim = m->getDim();
   std::vector<GEntity *> entities;
   m->getEntities(entities);
-  std::set<MFace, Less_Face> bndFaces;
-  std::set<MEdge, Less_Edge> bndEdges;
-  for(unsigned int i = 0; i < entities.size(); i++) {
+  std::set<MFace, MFaceLessThan> bndFaces;
+  std::set<MEdge, MEdgeLessThan> bndEdges;
+  for(std::size_t i = 0; i < entities.size(); i++) {
     GEntity *ge = entities[i];
     if(ge->dim() != dim) continue;
     if(visible && !ge->getVisibility()) continue;
-    for(unsigned int j = 0; j < ge->getNumMeshElements(); j++) {
+    for(std::size_t j = 0; j < ge->getNumMeshElements(); j++) {
       MElement *e = ge->getMeshElement(j);
       if(dim == 2) {
         for(int i = 0; i < e->getNumEdges(); i++) {
@@ -224,7 +224,7 @@ static void getBoundaryFromMesh(GModel *m, int visible)
     discreteEdge *e =
       new discreteEdge(m, m->getMaxElementaryNumber(1) + 1, 0, 0);
     m->add(e);
-    for(std::set<MEdge, Less_Edge>::iterator it = bndEdges.begin();
+    for(std::set<MEdge, MEdgeLessThan>::iterator it = bndEdges.begin();
         it != bndEdges.end(); it++) {
       e->lines.push_back(new MLine(it->getVertex(0), it->getVertex(1)));
     }
@@ -232,7 +232,7 @@ static void getBoundaryFromMesh(GModel *m, int visible)
   else if(dim == 3) {
     discreteFace *f = new discreteFace(m, m->getMaxElementaryNumber(2) + 1);
     m->add(f);
-    for(std::set<MFace, Less_Face>::iterator it = bndFaces.begin();
+    for(std::set<MFace, MFaceLessThan>::iterator it = bndFaces.begin();
         it != bndFaces.end(); it++) {
       if(it->getNumVertices() == 3)
         f->triangles.push_back(
