@@ -274,8 +274,15 @@ public:
                         bool saveInterpolationMatrices = true,
                         bool forceNodeData = false,
                         bool forceElementData = false);
+  bool readCGNS(const std::pair<std::string, std::string> &solFieldName,
+                const std::string &fileName, int index, int fileIndex,
+                int baseIndex,
+                const std::vector<std::vector<MVertex *> > &vertPerZone,
+                const std::vector<std::vector<MElement *> > &eltPerZone);
   bool readMED(const std::string &fileName, int fileIndex);
   bool writeMED(const std::string &fileName);
+  bool readPCH(const std::string &fileName, int fileIndex);
+
   void importLists(int N[24], std::vector<double> *V[24]);
   stepData<double> *getStepData(int step)
   {
