@@ -12,6 +12,8 @@
 #include "StringUtils.h"
 #include "OS.h"
 #include "Context.h"
+#include "CGNSCommon.h"
+#include "CGNSConventions.h"
 
 bool PViewDataGModel::addData(GModel *model,
                               const std::map<int, std::vector<double> > &data,
@@ -113,7 +115,7 @@ bool PViewDataGModel::readMSH(const std::string &viewName,
 
   _steps[step]->resizeData(numEnt);
 
-  Msg::ResetProgressMeter();
+  Msg::StartProgressMeter(numEnt);
   for(int i = 0; i < numEnt; i++) {
     int num;
     if(binary) {
@@ -156,9 +158,9 @@ bool PViewDataGModel::readMSH(const std::string &viewName,
       _min = std::min(_min, val);
       _max = std::max(_max, val);
     }
-    if(numEnt > 100000) Msg::ProgressMeter(i + 1, numEnt, true, "Reading data");
+    if(numEnt > 100000) Msg::ProgressMeter(i + 1, true, "Reading data");
   }
-
+  Msg::StopProgressMeter();
   if(partition >= 0) _steps[step]->getPartitions().insert(partition);
 
   finalize(false, interpolationScheme);
@@ -265,7 +267,7 @@ bool PViewDataGModel::writeMSH(const std::string &fileName, double version,
           if(_steps[step]->getData(i)) {
             MVertex *v = _steps[step]->getModel()->getMeshVertexByTag(i);
             if(!v) {
-              Msg::Error("Unknown vertex %d in data", i);
+              Msg::Error("Unknown node %d in data", i);
               fclose(fp);
               return false;
             }
@@ -928,7 +930,7 @@ bool PViewDataGModel::writeMED(const std::string &fileName)
     if(_steps[0]->getData(i)) {
       MVertex *v = _steps[0]->getModel()->getMeshVertexByTag(i);
       if(!v) {
-        Msg::Error("Unknown vertex %d in data", i);
+        Msg::Error("Unknown node %d in data", i);
         return false;
       }
       profile.push_back(v->getIndex());
@@ -1033,6 +1035,18 @@ bool PViewDataGModel::writeMED(const std::string &fileName)
 
 #endif
 
+bool PViewDataGModel::readPCH(const std::string &fileName, int fileIndex)
+{
+  Msg::Info("Placeholder for reading punch file '%s'",
+            fileName.c_str());
+
+  std::map<int, std::vector<double> > data;
+  for(int i = 1; i < 200; i++)
+    data[i].push_back(1.234);
+  addData(GModel::current(), data, 0, 0.0, 1, 1);
+
+  return true;
+}
 
 void PViewDataGModel::sendToServer(const std::string &name)
 {
@@ -1068,7 +1082,7 @@ void PViewDataGModel::sendToServer(const std::string &name)
     if(_steps[0]->getData(i)) {
       MVertex *v = _steps[0]->getModel()->getMeshVertexByTag(i);
       if(!v) {
-        Msg::Error("Unknown vertex %d in data", i);
+        Msg::Error("Unknown node %d in data", i);
         return;
       }
       int num = v->getNum();
