@@ -653,7 +653,7 @@ static void addScalarPolygon(PView *p, double **xyz, double **val, bool pre,
 
   if(opt->boundary > 0) {
     const int il[3][2] = {{0, 1}, {1, 2}, {2, 0}};
-    std::map<MEdge, int, Less_Edge> edges;
+    std::map<MEdge, int, MEdgeLessThan> edges;
     std::vector<MVertex *> verts;
     verts.reserve(numNodes);
     for(int i = 0; i < numNodes; i++)
@@ -661,7 +661,7 @@ static void addScalarPolygon(PView *p, double **xyz, double **val, bool pre,
     for(int i = 0; i < numNodes / 3; i++) {
       for(int j = 0; j < 3; j++) {
         MEdge ed(verts[3 * i + il[j][0]], verts[3 * i + il[j][1]]);
-        std::map<MEdge, int, Less_Edge>::iterator ite;
+        std::map<MEdge, int, MEdgeLessThan>::iterator ite;
         for(ite = edges.begin(); ite != edges.end(); ite++)
           if((*ite).first == ed) break;
         if(ite == edges.end())
@@ -672,7 +672,7 @@ static void addScalarPolygon(PView *p, double **xyz, double **val, bool pre,
     }
 
     opt->boundary--;
-    for(std::map<MEdge, int, Less_Edge>::iterator ite = edges.begin();
+    for(std::map<MEdge, int, MEdgeLessThan>::iterator ite = edges.begin();
         ite != edges.end(); ite++) {
       int i = (int)(*ite).second / 100;
       int j = (*ite).second % 100;
@@ -876,7 +876,7 @@ static void addOutlinePolyhedron(PView *p, double **xyz, unsigned int color,
 {
   // FIXME: this code is horribly slow
   const int it[4][3] = {{0, 2, 1}, {0, 1, 3}, {0, 3, 2}, {3, 1, 2}};
-  std::map<MFace, int, Less_Face> triFaces;
+  std::map<MFace, int, MFaceLessThan> triFaces;
   std::vector<MVertex *> verts;
   verts.reserve(numNodes);
   for(int i = 0; i < numNodes; i++)
@@ -885,7 +885,7 @@ static void addOutlinePolyhedron(PView *p, double **xyz, unsigned int color,
     for(int j = 0; j < 4; j++) {
       MFace f(verts[4 * i + it[j][0]], verts[4 * i + it[j][1]],
               verts[4 * i + it[j][2]]);
-      std::map<MFace, int, Less_Face>::iterator ite;
+      std::map<MFace, int, MFaceLessThan>::iterator ite;
       for(ite = triFaces.begin(); ite != triFaces.end(); ite++)
         if((*ite).first == f) break;
       if(ite == triFaces.end())
@@ -894,7 +894,7 @@ static void addOutlinePolyhedron(PView *p, double **xyz, unsigned int color,
         triFaces.erase(ite);
     }
   }
-  for(std::map<MFace, int, Less_Face>::iterator ite = triFaces.begin();
+  for(std::map<MFace, int, MFaceLessThan>::iterator ite = triFaces.begin();
       ite != triFaces.end(); ite++) {
     int i = (int)(*ite).second / 100;
     int j = (*ite).second % 100;
