@@ -3,8 +3,8 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _DISTANCE_TERM_H_
-#define _DISTANCE_TERM_H_
+#ifndef DISTANCE_TERM_H
+#define DISTANCE_TERM_H
 
 #include "helmholtzTerm.h"
 
@@ -32,7 +32,7 @@ public:
       const double weight = GP[i].weight;
       const double detJ = e->getJacobian(u, v, w, jac);
       e->getShapeFunctions(u, v, w, ff);
-      for(int j = 0; j < e->getNumShapeFunctions(); j++) {
+      for(std::size_t j = 0; j < e->getNumShapeFunctions(); j++) {
         m(j) += ff[j] * weight * detJ;
       }
     }
