@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _DOF_MANAGER_H_
-#define _DOF_MANAGER_H_
+#ifndef DOF_MANAGER_H
+#define DOF_MANAGER_H
 
 #include <vector>
 #include <string>
@@ -159,6 +159,14 @@ public:
   {
     fixDof(Dof(ent, type), value);
   }
+  inline void associateDof(long int ent_from, int type_from,
+			   long int ent_to, int type_to)
+  {
+    Dof from (ent_from, type_from);
+    Dof to   (ent_to, type_to);
+    std::pair<Dof,Dof> p = std::make_pair(from,to);
+    associatedWith.insert(p);
+  }
   void fixVertex(MVertex const *v, int iComp, int iField, const dataVec &value)
   {
     fixDof(v->getNum(), Dof::createTypeWithTwoInts(iComp, iField), value);
@@ -204,19 +212,20 @@ public:
   }
   virtual inline void numberDof(Dof key)
   {
+    if(associatedWith.find(key) != associatedWith.end()) return;
     if(fixed.find(key) != fixed.end()) return;
     if(constraints.find(key) != constraints.end()) return;
     if(ghostByDof.find(key) != ghostByDof.end()) return;
 
     std::map<Dof, int>::iterator it = unknown.find(key);
     if(it == unknown.end()) {
-      unsigned int size = unknown.size();
+      std::size_t size = unknown.size();
       unknown[key] = size;
     }
   }
   virtual inline void numberDof(const std::vector<Dof> &R)
   {
-    for(unsigned int i = 0; i < R.size(); i++) this->numberDof(R[i]);
+    for(std::size_t i = 0; i < R.size(); i++) this->numberDof(R[i]);
   }
   inline void numberDof(long int ent, int type) { numberDof(Dof(ent, type)); }
   inline void numberVertex(MVertex *v, int iComp, int iField)
@@ -226,6 +235,11 @@ public:
   virtual inline void getDofValue(std::vector<Dof> &keys,
                                   std::vector<dataVec> &Vals)
   {
+    for(std::size_t i = 0; i < keys.size(); i++) {
+      std::map<Dof, Dof>::iterator it = associatedWith.find(keys[i]);
+      if (it != associatedWith.end())keys[i] = it->second;
+    }
+
     int ndofs = keys.size();
     size_t originalSize = Vals.size();
     Vals.resize(originalSize + ndofs);
@@ -258,6 +272,18 @@ public:
 
   virtual inline void getDofValue(Dof key, dataVec &val) const
   {
+    {      
+      typename std::map<Dof, Dof>::const_iterator it = associatedWith.find(key);
+      if (it != associatedWith.end()){
+	//	  printf("ass to %d\n",it->second.getEntity());
+	std::map<Dof, int>::const_iterator itx = unknown.find(it->second);
+	if(itx != unknown.end()) {
+	  _current->getFromSolution(itx->second, val);
+	  return;
+	}
+	key = it->second;
+      }
+    }
     {
       typename std::map<Dof, dataVec>::const_iterator it = ghostValue.find(key);
       if(it != ghostValue.end()) {
@@ -357,8 +383,8 @@ public:
 
   virtual inline void sparsityDof(const std::vector<Dof> &keys)
   {
-    for(unsigned int itR = 0; itR < keys.size(); itR++) {
-      for(unsigned int itC = 0; itC < keys.size(); itC++) {
+    for(std::size_t itR = 0; itR < keys.size(); itR++) {
+      for(std::size_t itC = 0; itC < keys.size(); itC++) {
         insertInSparsityPattern(keys[itR], keys[itC]);
       }
     }
@@ -395,26 +421,36 @@ public:
   {
     if(_isParallel && !_parallelFinalized) _parallelFinalize();
     if(!_current->isAllocated()) _current->allocate(sizeOfR());
+    printf("coucou\n");
 
+    for(std::size_t i = 0; i < R.size(); i++) {
+      std::map<Dof, Dof>::iterator it = associatedWith.find(R[i]);
+      if (it != associatedWith.end())R[i] = it->second;
+    }
+    for(std::size_t i = 0; i < C.size(); i++) {
+      std::map<Dof, Dof>::iterator it = associatedWith.find(C[i]);
+      if (it != associatedWith.end())C[i] = it->second;
+    }
+    
     std::vector<int> NR(R.size()), NC(C.size());
 
-    for(unsigned int i = 0; i < R.size(); i++) {
+    for(std::size_t i = 0; i < R.size(); i++) {
       std::map<Dof, int>::iterator itR = unknown.find(R[i]);
       if(itR != unknown.end())
         NR[i] = itR->second;
       else
         NR[i] = -1;
     }
-    for(unsigned int i = 0; i < C.size(); i++) {
+    for(std::size_t i = 0; i < C.size(); i++) {
       std::map<Dof, int>::iterator itC = unknown.find(C[i]);
       if(itC != unknown.end())
         NC[i] = itC->second;
       else
         NC[i] = -1;
     }
-    for(unsigned int i = 0; i < R.size(); i++) {
+    for(std::size_t i = 0; i < R.size(); i++) {
       if(NR[i] != -1) {
-        for(unsigned int j = 0; j < C.size(); j++) {
+        for(std::size_t j = 0; j < C.size(); j++) {
           if(NC[j] != -1) {
             _current->addToMatrix(NR[i], NC[j], m(i, j));
           }
@@ -433,7 +469,7 @@ public:
         }
       }
       else {
-        for(unsigned int j = 0; j < C.size(); j++) {
+        for(std::size_t j = 0; j < C.size(); j++) {
           assembleLinConst(R[i], C[j], m(i, j));
         }
       }
@@ -445,15 +481,23 @@ public:
   {
     if(_isParallel && !_parallelFinalized) _parallelFinalize();
     if(!_current->isAllocated()) _current->allocate(sizeOfR());
+    printf("coucou RHS\n");
+
+    for(std::size_t i = 0; i < R.size(); i++) {
+      std::map<Dof, Dof>::iterator it = associatedWith.find(R[i]);
+      if (it != associatedWith.end())R[i] = it->second;
+    }
+
+
     std::vector<int> NR(R.size());
-    for(unsigned int i = 0; i < R.size(); i++) {
+    for(std::size_t i = 0; i < R.size(); i++) {
       std::map<Dof, int>::iterator itR = unknown.find(R[i]);
       if(itR != unknown.end())
         NR[i] = itR->second;
       else
         NR[i] = -1;
     }
-    for(unsigned int i = 0; i < R.size(); i++) {
+    for(std::size_t i = 0; i < R.size(); i++) {
       if(NR[i] != -1) {
         _current->addToRightHandSide(NR[i], m(i));
       }
@@ -477,17 +521,22 @@ public:
   {
     if(_isParallel && !_parallelFinalized) _parallelFinalize();
     if(!_current->isAllocated()) _current->allocate(sizeOfR());
+    for(std::size_t i = 0; i < R.size(); i++) {
+      std::map<Dof, Dof>::iterator it = associatedWith.find(R[i]);
+      if (it != associatedWith.end())R[i] = it->second;
+    }
+
     std::vector<int> NR(R.size());
-    for(unsigned int i = 0; i < R.size(); i++) {
+    for(std::size_t i = 0; i < R.size(); i++) {
       std::map<Dof, int>::iterator itR = unknown.find(R[i]);
       if(itR != unknown.end())
         NR[i] = itR->second;
       else
         NR[i] = -1;
     }
-    for(unsigned int i = 0; i < R.size(); i++) {
+    for(std::size_t i = 0; i < R.size(); i++) {
       if(NR[i] != -1) {
-        for(unsigned int j = 0; j < R.size(); j++) {
+        for(std::size_t j = 0; j < R.size(); j++) {
           if(NR[j] != -1) {
             _current->addToMatrix(NR[i], NR[j], m(i, j));
           }
@@ -506,7 +555,7 @@ public:
         }
       }
       else {
-        for(unsigned int j = 0; j < R.size(); j++) {
+        for(std::size_t j = 0; j < R.size(); j++) {
           assembleLinConst(R[i], R[j], m(i, j));
         }
       }
@@ -656,8 +705,14 @@ public:
     }
   }
 
-  virtual int getDofNumber(const Dof &key)
+  virtual int getDofNumber(const Dof &ky)
   {
+    Dof key = ky;
+    {
+      std::map<Dof, Dof>::iterator it = associatedWith.find(ky);
+      if (it != associatedWith.end())key = it->second;
+    }
+    
     std::map<Dof, int>::iterator it = unknown.find(key);
     if(it == unknown.end()) {
       return -1;
