@@ -1,14 +1,13 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <string.h>
 #include "GmshConfig.h"
 #include "elasticitySolver.h"
 #include "linearSystemCSR.h"
 #include "linearSystemPETSc.h"
-#include "linearSystemGMM.h"
 #include "linearSystemFull.h"
 #include "Numeric.h"
 #include "GModel.h"
@@ -20,6 +19,7 @@
 #include "solverField.h"
 #include "MPoint.h"
 #include "gmshLevelset.h"
+
 #if defined(HAVE_POST)
 #include "PView.h"
 #include "PViewData.h"
@@ -78,7 +78,7 @@ void elasticitySolver::setMesh(const std::string &meshFileName, int dim)
       _tag, VectorLagrangeFunctionSpace::VECTOR_X,
       VectorLagrangeFunctionSpace::VECTOR_Y);
 
-  for(unsigned int i = 0; i < LagrangeMultiplierSpaces.size(); i++)
+  for(std::size_t i = 0; i < LagrangeMultiplierSpaces.size(); i++)
     if(LagrangeMultiplierSpaces[i]) delete LagrangeMultiplierSpaces[i];
   LagrangeMultiplierSpaces.clear();
 }
@@ -120,8 +120,7 @@ void elasticitySolver::solve()
 #if defined(HAVE_PETSC)
   linearSystemPETSc<double> *lsys = new linearSystemPETSc<double>;
 #elif defined(HAVE_GMM)
-  linearSystemGmm<double> *lsys = new linearSystemGmm<double>;
-  lsys->setNoisy(2);
+  linearSystemCSRGmm<double> *lsys = new linearSystemCSRGmm<double>;
 #else
   linearSystemFull<double> *lsys = new linearSystemFull<double>;
 #endif
@@ -133,9 +132,9 @@ void elasticitySolver::solve()
 
   double energ = 0;
   GaussQuadrature Integ_Bulk(GaussQuadrature::GradGrad);
-  for(unsigned int i = 0; i < elasticFields.size(); i++) {
+  for(std::size_t i = 0; i < elasticFields.size(); i++) {
     SolverField<SVector3> Field(pAssembler, LagSpace);
-    IsotropicElasticTerm Eterm(Field, elasticFields[i]._E,
+    IsotropicElasticTerm Eterm(Field, elasticFields[i]._e,
                                elasticFields[i]._nu);
     BilinearTermToScalarTerm Elastic_Energy_Term(Eterm);
     Assemble(Elastic_Energy_Term, elasticFields[i].g->begin(),
@@ -149,9 +148,9 @@ void elasticitySolver::postSolve()
   GaussQuadrature Integ_Bulk(GaussQuadrature::GradGrad);
 
   double energ = 0;
-  for(unsigned int i = 0; i < elasticFields.size(); i++) {
+  for(std::size_t i = 0; i < elasticFields.size(); i++) {
     SolverField<SVector3> Field(pAssembler, LagSpace);
-    IsotropicElasticTerm Eterm(Field, elasticFields[i]._E,
+    IsotropicElasticTerm Eterm(Field, elasticFields[i]._e,
                                elasticFields[i]._nu);
     BilinearTermToScalarTerm Elastic_Energy_Term(Eterm);
     Assemble(Elastic_Energy_Term, elasticFields[i].g->begin(),
@@ -181,7 +180,7 @@ void elasticitySolver::readInputFile(const std::string &fn)
     else if(!strcmp(what, "ElasticDomain")) {
       elasticField field;
       int physical;
-      if(fscanf(f, "%d %lf %lf", &physical, &field._E, &field._nu) != 3) {
+      if(fscanf(f, "%d %lf %lf", &physical, &field._e, &field._nu) != 3) {
         fclose(f);
         return;
       }
@@ -213,7 +212,7 @@ void elasticitySolver::readInputFile(const std::string &fn)
         fclose(f);
         return;
       }
-      field._E = field._nu = 0;
+      field._e = field._nu = 0;
       field.g = new groupOfElements(_dim, physical);
       field._tag = 0;
       elasticFields.push_back(field);
@@ -377,15 +376,15 @@ void elasticitySolver::cutMesh(gLevelset *ls)
 void elasticitySolver::setElasticDomain(int phys, double E, double nu)
 {
   elasticField field;
-  field._E = E;
+  field._e = E;
   field._nu = nu;
   field._tag = _tag;
   field.g = new groupOfElements(_dim, phys);
   elasticFields.push_back(field);
 }
 
-void elasticitySolver::setLagrangeMultipliers(int phys, double tau, SVector3 d,
-                                              int tag,
+void elasticitySolver::setLagrangeMultipliers(int phys, double tau,
+                                              const SVector3 &d, int tag,
                                               simpleFunction<double> *f)
 {
   LagrangeMultiplierField field;
@@ -402,7 +401,7 @@ void elasticitySolver::setLagrangeMultipliers(int phys, double tau, SVector3 d,
 
 void elasticitySolver::changeLMTau(int tag, double tau)
 {
-  for(unsigned int i = 0; i < LagrangeMultiplierFields.size(); i++) {
+  for(std::size_t i = 0; i < LagrangeMultiplierFields.size(); i++) {
     if(LagrangeMultiplierFields[i]._tag == tag) {
       LagrangeMultiplierFields[i]._tau = tau;
     }
@@ -433,12 +432,11 @@ void elasticitySolver::addDirichletBC(int dim, int entityId, int component,
   case 0: diri.onWhat = BoundaryCondition::ON_VERTEX; break;
   case 1: diri.onWhat = BoundaryCondition::ON_EDGE; break;
   case 2: diri.onWhat = BoundaryCondition::ON_FACE; break;
-  default:
-    {
-      delete diri.g;
-      delete diri._f;
-      return;
-    }
+  default: {
+    delete diri.g;
+    delete diri._f;
+    return;
+  }
   }
   allDirichlet.push_back(diri);
 }
@@ -462,12 +460,11 @@ void elasticitySolver::addNeumannBC(int dim, int entityId,
   case 0: neu.onWhat = BoundaryCondition::ON_VERTEX; break;
   case 1: neu.onWhat = BoundaryCondition::ON_EDGE; break;
   case 2: neu.onWhat = BoundaryCondition::ON_FACE; break;
-  default:
-    {
-      delete neu.g;
-      delete neu._f;
-      return;
-    }
+  default: {
+    delete neu.g;
+    delete neu._f;
+    return;
+  }
   }
   allNeumann.push_back(neu);
 }
@@ -483,7 +480,7 @@ void elasticitySolver::addElasticDomain(int physical, double e, double nu)
 {
   elasticField field;
   field._tag = _tag;
-  field._E = e;
+  field._e = e;
   field._nu = nu;
   field.g = new groupOfElements(_dim, physical);
   elasticFields.push_back(field);
@@ -505,15 +502,15 @@ void elasticitySolver::assemble(linearSystem<double> *lsys)
   // numbered afterwards
 
   // Dirichlet conditions
-  for(unsigned int i = 0; i < allDirichlet.size(); i++) {
+  for(std::size_t i = 0; i < allDirichlet.size(); i++) {
     FilterDofComponent filter(allDirichlet[i]._comp);
     FixNodalDofs(*LagSpace, allDirichlet[i].g->begin(),
                  allDirichlet[i].g->end(), *pAssembler, *allDirichlet[i]._f,
                  filter);
   }
   // LagrangeMultipliers
-  for(unsigned int i = 0; i < LagrangeMultiplierFields.size(); ++i) {
-    unsigned int j = 0;
+  for(std::size_t i = 0; i < LagrangeMultiplierFields.size(); ++i) {
+    std::size_t j = 0;
     for(; j < LagrangeMultiplierSpaces.size(); j++)
       if(LagrangeMultiplierSpaces[j]->getId() ==
          LagrangeMultiplierFields[i]._tag)
@@ -523,21 +520,21 @@ void elasticitySolver::assemble(linearSystem<double> *lsys)
                LagrangeMultiplierFields[i].g->end(), *pAssembler);
   }
   // Elastic Fields
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
-    if(elasticFields[i]._E != 0.)
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
+    if(elasticFields[i]._e != 0.)
       NumberDofs(*LagSpace, elasticFields[i].g->begin(),
                  elasticFields[i].g->end(), *pAssembler);
   }
   // Voids
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
-    if(elasticFields[i]._E == 0.)
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
+    if(elasticFields[i]._e == 0.)
       FixVoidNodalDofs(*LagSpace, elasticFields[i].g->begin(),
                        elasticFields[i].g->end(), *pAssembler);
   }
   // Neumann conditions
   GaussQuadrature Integ_Boundary(GaussQuadrature::Val);
 
-  for(unsigned int i = 0; i < allNeumann.size(); i++) {
+  for(std::size_t i = 0; i < allNeumann.size(); i++) {
     LoadTerm<SVector3> Lterm(*LagSpace, allNeumann[i]._f);
     Assemble(Lterm, *LagSpace, allNeumann[i].g->begin(), allNeumann[i].g->end(),
              Integ_Boundary, *pAssembler);
@@ -545,8 +542,8 @@ void elasticitySolver::assemble(linearSystem<double> *lsys)
   // Assemble cross term, laplace term and rhs term for LM
   GaussQuadrature Integ_LagrangeMult(GaussQuadrature::ValVal);
   GaussQuadrature Integ_Laplace(GaussQuadrature::GradGrad);
-  for(unsigned int i = 0; i < LagrangeMultiplierFields.size(); i++) {
-    unsigned int j = 0;
+  for(std::size_t i = 0; i < LagrangeMultiplierFields.size(); i++) {
+    std::size_t j = 0;
     for(; j < LagrangeMultiplierSpaces.size(); j++)
       if(LagrangeMultiplierSpaces[j]->getId() ==
          LagrangeMultiplierFields[i]._tag)
@@ -576,9 +573,9 @@ void elasticitySolver::assemble(linearSystem<double> *lsys)
   }
   // Assemble elastic term for
   GaussQuadrature Integ_Bulk(GaussQuadrature::GradGrad);
-  for(unsigned int i = 0; i < elasticFields.size(); i++) {
+  for(std::size_t i = 0; i < elasticFields.size(); i++) {
     printf("Elastic\n");
-    IsotropicElasticTerm Eterm(*LagSpace, elasticFields[i]._E,
+    IsotropicElasticTerm Eterm(*LagSpace, elasticFields[i]._e,
                                elasticFields[i]._nu);
     Assemble(Eterm, *LagSpace, elasticFields[i].g->begin(),
              elasticFields[i].g->end(), Integ_Bulk, *pAssembler);
@@ -592,8 +589,8 @@ void elasticitySolver::computeEffectiveStiffness(std::vector<double> stiff)
 {
   double st[6] = {0., 0., 0., 0., 0., 0.};
   double volTot = 0.;
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
-    double E = elasticFields[i]._E;
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
+    double E = elasticFields[i]._e;
     double nu = elasticFields[i]._nu;
     SolverField<SVector3> Field(pAssembler, LagSpace);
     for(groupOfElements::elementContainer::const_iterator it =
@@ -651,7 +648,7 @@ void elasticitySolver::computeEffectiveStrain(std::vector<double> strain)
 {
   double st[6] = {0., 0., 0., 0., 0., 0.};
   double volTot = 0.;
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
     SolverField<SVector3> Field(pAssembler, LagSpace);
     for(groupOfElements::elementContainer::const_iterator it =
           elasticFields[i].g->begin();
@@ -702,8 +699,8 @@ double elasticitySolver::computeDisplacementError(simpleFunction<double> *f0,
   double err = 0.;
   std::set<MVertex *> v;
   std::map<MVertex *, MElement *> vCut;
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
-    if(elasticFields[i]._E == 0.) continue;
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
+    if(elasticFields[i]._e == 0.) continue;
     for(groupOfElements::elementContainer::const_iterator it =
           elasticFields[i].g->begin();
         it != elasticFields[i].g->end(); ++it) {
@@ -753,7 +750,7 @@ double elasticitySolver::computeL2Norm(simpleFunction<double> *f0,
 {
   double val = 0.0;
   SolverField<SVector3> solField(pAssembler, LagSpace);
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
     for(groupOfElements::elementContainer::const_iterator it =
           elasticFields[i].g->begin();
         it != elasticFields[i].g->end(); ++it) {
@@ -800,7 +797,7 @@ PView *elasticitySolver::buildErrorView(const std::string postFileName,
   std::map<int, std::vector<double> > data;
 
   SolverField<SVector3> solField(pAssembler, LagSpace);
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
     for(groupOfElements::elementContainer::const_iterator it =
           elasticFields[i].g->begin();
         it != elasticFields[i].g->end(); ++it) {
@@ -841,8 +838,8 @@ PView *elasticitySolver::buildDisplacementView(const std::string postFileName)
   std::cout << "build Displacement View" << std::endl;
   std::set<MVertex *> v;
   std::map<MVertex *, MElement *> vCut;
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
-    if(elasticFields[i]._E == 0.) continue;
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
+    if(elasticFields[i]._e == 0.) continue;
     for(groupOfElements::elementContainer::const_iterator it =
           elasticFields[i].g->begin();
         it != elasticFields[i].g->end(); ++it) {
@@ -895,8 +892,8 @@ PView *elasticitySolver::buildStressesView(const std::string postFileName)
   double volTot = 0.;
   std::cout << "build stresses view" << std::endl;
   std::map<int, std::vector<double> > data;
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
-    double E = elasticFields[i]._E;
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
+    double E = elasticFields[i]._e;
     double nu = elasticFields[i]._nu;
     SolverField<SVector3> Field(pAssembler, LagSpace);
     for(groupOfElements::elementContainer::const_iterator it =
@@ -987,7 +984,7 @@ PView *elasticitySolver::buildStrainView(const std::string postFileName)
 {
   std::cout << "build strain view" << std::endl;
   std::map<int, std::vector<double> > data;
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
     SolverField<SVector3> Field(pAssembler, LagSpace);
     for(groupOfElements::elementContainer::const_iterator it =
           elasticFields[i].g->begin();
@@ -1032,17 +1029,17 @@ PView *elasticitySolver::buildStrainView(const std::string postFileName)
 }
 
 PView *
-elasticitySolver::buildLagrangeMultiplierView(const std::string postFileName,
+elasticitySolver::buildLagrangeMultiplierView(const std::string &postFileName,
                                               int tag)
 {
   std::cout << "build Lagrange Multiplier View" << std::endl;
-  unsigned int t = 0;
+  std::size_t t = 0;
   if(tag != -1)
     for(; t < LagrangeMultiplierSpaces.size(); t++)
       if(LagrangeMultiplierSpaces[t]->getId() == tag) break;
   if(t == LagrangeMultiplierSpaces.size()) return new PView();
   std::set<MVertex *> v;
-  for(unsigned int i = 0; i < LagrangeMultiplierFields.size(); ++i) {
+  for(std::size_t i = 0; i < LagrangeMultiplierFields.size(); ++i) {
     for(groupOfElements::elementContainer::const_iterator it =
           LagrangeMultiplierFields[i].g->begin();
         it != LagrangeMultiplierFields[i].g->end(); ++it) {
@@ -1070,10 +1067,10 @@ PView *elasticitySolver::buildElasticEnergyView(const std::string postFileName)
   std::cout << "build Elastic Energy View" << std::endl;
   std::map<int, std::vector<double> > data;
   GaussQuadrature Integ_Bulk(GaussQuadrature::GradGrad);
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
-    if(elasticFields[i]._E == 0.) continue;
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
+    if(elasticFields[i]._e == 0.) continue;
     SolverField<SVector3> Field(pAssembler, LagSpace);
-    IsotropicElasticTerm Eterm(Field, elasticFields[i]._E,
+    IsotropicElasticTerm Eterm(Field, elasticFields[i]._e,
                                elasticFields[i]._nu);
     BilinearTermToScalarTerm Elastic_Energy_Term(Eterm);
     ScalarTermConstant<double> One(1.0);
@@ -1103,7 +1100,7 @@ PView *elasticitySolver::buildVolumeView(const std::string postFileName)
   double voltot = 0;
   double length = 0;
   GaussQuadrature Integ_Vol(GaussQuadrature::Val);
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
     ScalarTermConstant<double> One(1.0);
     for(groupOfElements::elementContainer::const_iterator it =
           elasticFields[i].g->begin();
@@ -1119,7 +1116,7 @@ PView *elasticitySolver::buildVolumeView(const std::string postFileName)
       data[e->getNum()] = vec;
     }
   }
-  for(unsigned int i = 0; i < LagrangeMultiplierFields.size(); ++i) {
+  for(std::size_t i = 0; i < LagrangeMultiplierFields.size(); ++i) {
     ScalarTermConstant<double> One(1.0);
     for(groupOfElements::elementContainer::const_iterator it =
           LagrangeMultiplierFields[i].g->begin();
@@ -1145,9 +1142,9 @@ PView *elasticitySolver::buildVonMisesView(const std::string postFileName)
   std::cout << "build elastic view" << std::endl;
   std::map<int, std::vector<double> > data;
   GaussQuadrature Integ_Bulk(GaussQuadrature::GradGrad);
-  for(unsigned int i = 0; i < elasticFields.size(); ++i) {
+  for(std::size_t i = 0; i < elasticFields.size(); ++i) {
     SolverField<SVector3> Field(pAssembler, LagSpace);
-    IsotropicElasticTerm Eterm(Field, elasticFields[i]._E,
+    IsotropicElasticTerm Eterm(Field, elasticFields[i]._e,
                                elasticFields[i]._nu);
     BilinearTermToScalarTerm Elastic_Energy_Term(Eterm);
     for(groupOfElements::elementContainer::const_iterator it =
