@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "elasticityTerm.h"
 #include "Numeric.h"
@@ -13,7 +13,7 @@ void elasticityTerm::createData(MElement *e) const
 {
   if(_data.find(e->getTypeForMSH()) != _data.end()) return;
   elasticityDataAtGaussPoint d;
-  int nbSF = e->getNumShapeFunctions();
+  int nbSF = (int)e->getNumShapeFunctions();
   int integrationOrder = 2 * (e->getPolynomialOrder() - 1);
   int npts;
   IntPt *GP;
@@ -37,8 +37,6 @@ void elasticityTerm::createData(MElement *e) const
     d.w.push_back(w);
     d.weight.push_back(weight);
   }
-  //  printf("coucou creation of a data for %d with %d
-  //  points\n",e->getTypeForMSH(),npts);
   _data[e->getTypeForMSH()] = d;
 }
 
@@ -47,12 +45,12 @@ void elasticityTerm::elementMatrix(SElement *se, fullMatrix<double> &m) const
   MElement *e = se->getMeshElement();
   createData(e);
 
-  int nbSF = e->getNumShapeFunctions();
+  int nbSF = (int)e->getNumShapeFunctions();
   elasticityDataAtGaussPoint &d = _data[e->getTypeForMSH()];
   int npts = d.u.size();
   m.setAll(0.);
 
-  double FACT = _E / (1 + _nu);
+  double FACT = _e / (1 + _nu);
   double C11 = FACT * (1 - _nu) / (1 - 2 * _nu);
   double C12 = FACT * _nu / (1 - 2 * _nu);
   double C44 = (C11 - C12) / 2;
@@ -87,7 +85,6 @@ void elasticityTerm::elementMatrix(SElement *se, fullMatrix<double> &m) const
     BT.setAll(0.);
 
     if(se->getShapeEnrichement() == se->getTestEnrichement()) {
-      //      printf("coucou\n");
       for(int j = 0; j < nbSF; j++) {
         BT(j, 0) = B(0, j) = Grads[j][0];
         BT(j, 3) = B(3, j) = Grads[j][1];
@@ -125,13 +122,12 @@ void elasticityTerm::elementMatrix(SElement *se, fullMatrix<double> &m) const
     BTH.gemm(BT, H);
     m.gemm(BTH, B, weight * detJ, 1.);
   }
-  return;
 }
 
 void elasticityTerm::elementVector(SElement *se, fullVector<double> &m) const
 {
   MElement *e = se->getMeshElement();
-  int nbSF = e->getNumShapeFunctions();
+  int nbSF = (int)e->getNumShapeFunctions();
   int integrationOrder = 2 * e->getPolynomialOrder();
   int npts;
   IntPt *GP;
@@ -186,13 +182,13 @@ void elasticityMixedTerm::elementMatrix(SElement *se,
   fullMatrix<double> KGG(_sizeM, _sizeM);
   fullMatrix<double> KPP(_sizeM, _sizeM); // stabilization
 
-  double FACT = _E / ((1 + _nu) * (1. - 2 * _nu));
+  double FACT = _e / ((1 + _nu) * (1. - 2 * _nu));
   double C11 = FACT * (1 - _nu);
   double C12 = FACT * _nu;
   double C44 = FACT * (1 - 2. * _nu) * .5;
-  // double _K = 3*_E / (1 - 2 * _nu);
+  // double _k = 3*_e / (1 - 2 * _nu);
   // FIXME : PLANE STRESS !!!
-  //  FACT = _E / (1-_nu*_nu);
+  //  FACT = _e / (1-_nu*_nu);
   //  C11  = FACT;
   //  C12  = _nu * FACT;
   //  C44 = (1.-_nu)*.5*FACT;
@@ -252,7 +248,7 @@ void elasticityMixedTerm::elementMatrix(SElement *se,
     }
 
     /*
-    const double K3 = weight * detJ * _E/(2*(1+_nu));
+    const double K3 = weight * detJ * _e/(2*(1+_nu));
     for (int j = 0; j < _sizeN; j++){
       for (int k = 0; k < _sizeN; k++){
     const double fa = (Grads[j][0] * Grads[k][0] +
@@ -304,8 +300,8 @@ void elasticityMixedTerm::elementMatrix(SElement *se,
       MT(j, 0) = M(0, j) = SF[j];
     }
 
-    //    printf("BT (%d %d) x H (%d,%d) = BTH(%d,%d)\n",BT.size1(),BT.size2(),
-    //    H.size1(),H.size2(),BTH.size1(),BTH.size2());
+    // printf("BT (%d %d) x H (%d,%d) = BTH(%d,%d)\n",BT.size1(),BT.size2(),
+    // H.size1(),H.size2(),BTH.size1(),BTH.size2());
 
     BTH.setAll(0.);
     BTH.gemm(BT, H);
@@ -315,10 +311,10 @@ void elasticityMixedTerm::elementMatrix(SElement *se,
     }
 
     KUU.gemm(BTH, B, weight * detJ);
-    //    KUP.gemm(BDILT, M, weight * detJ);
-    //    KPG.gemm(MT, M, -weight * detJ);
-    //    KUG.gemm(trBTH, M, weight * detJ/_dimension);
-    //    KGG.gemm(MT, M, weight * detJ * (_K)/(_dimension*_dimension));
+    // KUP.gemm(BDILT, M, weight * detJ);
+    // KPG.gemm(MT, M, -weight * detJ);
+    // KUG.gemm(trBTH, M, weight * detJ/_dimension);
+    // KGG.gemm(MT, M, weight * detJ * (_k)/(_dimension*_dimension));
   }
   /*
           3*_sizeN  _sizeM _sizeM
