@@ -33,6 +33,7 @@ class arg:
         self.julia_pre = ""
         self.julia_post = ""
         self.julia_return = name
+        self.texi = name + ((" = " + self.python_value) if self.python_value else "")
 
 # input types
 
@@ -186,8 +187,9 @@ def ivectorpair(name, value=None, python_value=None, julia_value=None):
     a.python_pre = api_name + ", " + api_name_n + " = _ivectorpair(" + name + ")"
     a.python_arg = api_name + ", " + api_name_n
     a.julia_ctype = "Ptr{Cint}, Csize_t"
-    a.julia_arg = ("convert(Vector{Cint}, collect(Cint, Iterators.flatten(" + name + "))), " +
-                   "2 * length(" + name + ")")
+    a.julia_pre = (api_name + " = collect(Cint, Iterators.flatten(" + name + "))\n    " +
+                   api_name_n + " = length(" + api_name + ")")
+    a.julia_arg = (api_name + ", " + api_name_n)
     return a
 
 def ivectorvectorint(name, value=None, python_value=None, julia_value=None):
@@ -675,6 +677,7 @@ def argcargv():
     a.python_pre = "api_argc_, api_argv_ = _iargcargv(argv)"
     a.julia_ctype = "Cint, Ptr{Ptr{Cchar}}"
     a.julia_arg = "length(argv), argv"
+    a.texi = "(argc = 0)}, @code{argv = []"
     return a
 
 class Module:
@@ -686,11 +689,10 @@ class Module:
         self.submodules = []
 
     def add(self, name, doc, rtype, *args):
-        self.fs.append((rtype, name, args, doc, ''))
+        self.fs.append((rtype, name, args, doc, []))
 
-    # a raw C implementation of the function is available
-    def add_rawc(self, name, doc, rtype, *args):
-        self.fs.append((rtype, name, args, doc, 'rawc'))
+    def add_special(self, name, doc, special, rtype, *args):
+        self.fs.append((rtype, name, args, doc, special))
 
     def add_module(self, name, doc):
         module = Module(name, doc)
@@ -1026,7 +1028,7 @@ def _ovectorvectorint(ptr, size, n):
     return v
 
 def _ovectorvectorsize(ptr, size, n):
-    v = [_ovectorint(pointer(ptr[i].contents), size[i]) for i in range(n.value)]
+    v = [_ovectorsize(pointer(ptr[i].contents), size[i]) for i in range(n.value)]
     lib.{6}Free(size)
     lib.{6}Free(ptr)
     return v
@@ -1186,7 +1188,7 @@ class API:
                         + (",\n" + ' ' * len(fnameapi)).join(
                             list((a.c for a in args + (oint("ierr"), ))))
                         + ");\n")
-                if special != 'rawc':
+                if "rawc" not in special:
                     # *c.cpp
                     fc.write(ns.upper() + "_API " + (rtype.rc_type if rtype else "void"))
                     fc.write(" " + fname + "(" +
@@ -1269,6 +1271,7 @@ class API:
             return a.name + (("=" + a.python_value) if a.python_value else "")
         def write_function(f, fun, modulepath, indent):
             (rtype, name, args, doc, special) = fun
+            if "onlycc++" in special: return
             iargs = list(a for a in args if not a.out)
             oargs = list(a for a in args if a.out)
             f.write("\n")
@@ -1335,6 +1338,7 @@ class API:
             return a.name + ((" = " + a.julia_value) if a.julia_value else "")
         def write_function(f, fun, c_mpath, jl_mpath):
             (rtype, name, args, doc, special) = fun
+            if "onlycc++" in special: return
             iargs = list(a for a in args if not a.out)
             oargs = list(a for a in args if a.out)
             f.write('\n"""\n    ')
@@ -1419,14 +1423,14 @@ class API:
             f.write("@section Namespace @code{" + path + "}: " + module.doc + "\n\n");
             f.write("@ftable @code\n");
             for rtype, name, args, doc, special in module.fs:
-                f.write("@item " + name + "\n");
+                f.write("@item " + path + '/' + name + "\n");
                 tdoc = doc.replace("`", "@code{").replace("'", "}")
                 f.write("\n".join(textwrap.wrap(tdoc, 80)) + "\n\n")
                 f.write("@table @asis\n");
                 iargs = list(a for a in args if not a.out)
                 oargs = list(a for a in args if a.out)
                 f.write("@item " + "Input:\n" +
-                        (", ".join(("@code{" + iarg.name + "}") for iarg in iargs)
+                        (", ".join(("@code{" + iarg.texi + "}") for iarg in iargs)
                          if len(iargs) else "-") + "\n")
                 f.write("@item " + "Output:\n" +
                         (", ".join(("@code{" + oarg.name + "}") for oarg in oargs)
